# -*- coding: utf-8 -*-
#COPYRIGHT 2016 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
from arcpy.arcobjects._base import _ObjectWithoutInitCall, passthrough_attr, pass_parameterized_attr
from arcpy.geoprocessing._base import gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

class Arc_base(object):
    def __init__(self, parent):
        self._parent = parent
        self._arc_object = parent._arc_object

class Base_renderer(Arc_base):
    pass

class UniqueValueRenderer(Base_renderer):
    """The UniqueValueRenderer class represents a unique value renderer."""
    type = 'UniqueValueRenderer'
    colorRamp = passthrough_attr('colorRamp')
    groups = passthrough_attr('itemGroups')
    fields = passthrough_attr('fields')
    defaultSymbol = passthrough_attr('defaultSymbol')
    useDefaultSymbol = passthrough_attr('useDefaultSymbol')

    def __eq__(self, other):
        return other == 'UniqueValueRenderer'

class SimpleRenderer(Base_renderer):
    """The SimpleRenderer class represents a simple renderer that draws all features in a layer with a common symbol.
    """
    type = 'SimpleRenderer'
    label = passthrough_attr('label')
    description = passthrough_attr('description')
    symbol = passthrough_attr('symbol')

    def __eq__(self, other):
        return other == 'SimpleRenderer'

class Graduated_colors_renderer(Base_renderer):
    """The GraduatedColorsRenderer class represents the graduated color renderer definition that shows qualitative
    differences in feature values using a range of color.
    """
    type = 'GraduatedColorsRenderer'
    classificationField = passthrough_attr('field')
    normalizationField = passthrough_attr('normalizationField')
    normalizationType = passthrough_attr('normalizationMethod')
    classificationMethod = passthrough_attr('classification')
    breakCount = passthrough_attr('breakCount')
    classBreaks = passthrough_attr('breaks')
    colorRamp = passthrough_attr('colorRamp')
    intervalSize = passthrough_attr('definedIntervalSize')
    deviationInterval = passthrough_attr('deviationInterval')

    def __repr__(self):
        return '<graduated_colors_renderer object>'

    def __eq__(self, other):
        return other == 'GraduatedColorsRenderer'

class Graduated_symbols_renderer(Base_renderer):
    """The GraduatedSymbolsRenderer class represents the graduated symbols renderer definition that shows qualitative
    differences in feature values using a range of symbol sizes.
    """
    type = 'GraduatedSymbolsRenderer'
    classificationField = passthrough_attr('field')
    normalizationField = passthrough_attr('normalizationField')
    normalizationType = passthrough_attr('normalizationMethod')
    classificationMethod = passthrough_attr('classification')
    breakCount = passthrough_attr('breakCount')
    classBreaks = passthrough_attr('breaks')
    minimumSymbolSize = passthrough_attr('minimumSymbolSize')
    maximumSymbolSize = passthrough_attr('maximumSymbolSize')
    symbolTemplate = passthrough_attr('symbolTemplate')
    backgroundSymbol = passthrough_attr('backgroundSymbol')
    colorRamp = passthrough_attr('colorRamp')
    intervalSize = passthrough_attr('definedIntervalSize')
    deviationInterval = passthrough_attr('deviationInterval')

    def updateSymbolTemplate(self, symbol_template):
        """GraduatedSymbolsRenderer.updateSymbolTemplate ({symbol_template})

              Provides a mechanism to change the renderer's symbol template.
              symbol_template{Object}:
                  A reference to a symbol.
                  The default value is None.
        """
        return convertArcObjectToPythonObject(
            self._arc_object.updateSymbolTemplate(*gp_fixargs((symbol_template,), True)))

    def __repr__(self):
        return '<graduated_symbols_renderer object>'

    def __eq__(self, other):
        return other == 'GraduatedSymbolsRenderer'
