# -*- coding: utf-8 -*-
#COPYRIGHT 2014 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r""""""
__all__ = ['CreateCube', 'EmergingHotSpots']
__alias__ = 'cube'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs, gptoolnotsupported
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptoolnotsupported
@gptooldoc('CreateCube_cube', None)
def CreateCube(in_features=None, output_database=None, time_field=None, time_interval=None, time_step_base=None, ref_time=None, distance_interval=None, reference_cube=None, summary_fields=None, output_trend_layer=None):
    """CreateCube_cube(in_features, output_database, time_field, {time_interval;time_interval...}, {time_step_base}, {ref_time}, {distance_interval}, {reference_cube}, {summary_fields;summary_fields...}, {output_trend_layer})

     INPUTS:
      in_features (Feature Layer):
          Input Features
      time_field (Field):
          Time Field
      time_interval {Value Table}:
          Time Step Interval
      time_step_base {String}:
          Time Step Based On
      ref_time {Date}:
          Reference Time
      distance_interval {Linear unit}:
          Distance Interval
      reference_cube {File}:
          Reference Space-Time Cube
      summary_fields {Value Table}:
          Summary Fields

     OUTPUTS:
      output_database (File):
          Output Space-Time Cube
      output_trend_layer {Raster Layer}:
          Output Trend Layer"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateCube_cube(*gp_fixargs((in_features, output_database, time_field, time_interval, time_step_base, ref_time, distance_interval, reference_cube, summary_fields, output_trend_layer), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('EmergingHotSpots_cube', None)
def EmergingHotSpots(in_cube=None, analy_variable=None, output_features=None, neighbor_distance=None, neighbor_time_steps=None, backward_only=None, polygon_mask=None):
    """EmergingHotSpots_cube(in_cube, analy_variable, output_features, {neighbor_distance}, {neighbor_time_steps}, {backward_only}, {polygon_mask})

     INPUTS:
      in_cube (File):
          Input Space-Time Cube
      analy_variable (String):
          Analysis Variable
      neighbor_distance {Linear unit}:
          Neighborhood Size - Distance
      neighbor_time_steps {Long}:
          Neighborhood Size - Time Steps
      backward_only {Boolean}:
          Backward In Time Only
      polygon_mask {Feature Layer}:
          Polygon Analysis Mask

     OUTPUTS:
      output_features (Feature Class):
          Output Features"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EmergingHotSpots_cube(*gp_fixargs((in_cube, analy_variable, output_features, neighbor_distance, neighbor_time_steps, backward_only, polygon_mask), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject, gptoolnotsupported