# -*- coding: utf-8 -*-
#COPYRIGHT 2014 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
from arcpy._mp import ArcGISProject, LayerFile, Table, constants
from arcpy._mp import Symbology, ColorRamp, ClassBreak, Symbol, Item, ItemGroup
from arcpy._mp import UniqueValueRenderer, SimpleRenderer, Graduated_colors_renderer, Graduated_symbols_renderer
from arcpy.arcobjects._base import _ObjectWithoutInitCall, passthrough_attr
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
from arcpy.geoprocessing._base import gp_fixargs
from arcpy.pdfdocument import PDFDocument, PDFDocumentOpen, PDFDocumentCreate
from arcpy.utils import ArgAdaptor
@constants.maskargs
def CreateWebLayerSDDraft(map_or_layers, out_sddraft, service_name, server_type='MY_HOSTED_SERVICES', service_type='FEATURE_ACCESS', folder_name=None, overwrite_existing_service=False, copy_data_to_server=False, enable_editing=False, allow_exporting=True, enable_sync=False, summary=None, tags=None, description=None, credits=None, use_limitations=None):
    """CreateWebLayerSDDraft(map_or_layers, out_sddraft, service_name,
       {server_type}, {service_type}, {folder_name},
       {overwrite_existing_service}, {copy_data_to_server}, {enable_editing},
       {allow_exporting}, {enable_sync}, {summary}, {tags}, {description},
       {credits}, {use_limitations})

       Converts a map, layer, or list of layers in an ArcGIS Project   to a
       Service Definition Draft ( .sddraft )  file.

         map_or_layers(Object):
       A variable that references a Map object, Layer object, or a list of Layer
       objects. If publishing a list of Layer objects, they must be from the
       same map.

         out_sddraft(String):
       A string that represents the path and file name for the output Service
       Definition Draft ( .sddraft ) file.

         service_name(String):
       A string that represents the name of the service. This is the name people
       will see and use to identify the service. The name can only contain
       alphanumeric characters and underscores. No spaces or special characters
       are allowed. The name cannot be more than 120 characters in length.

         server_type{String}:
       A string representing the server type.
        Currently, the only supported value is MY_HOSTED_SERVICES for ArcGIS
        Online .

         service_type{String}:
       A string representing the service type.

        * FEATURE_ACCESS: FEATURE_ACCESS supports vector querying,
        visualization, and editing.

        * TILED: TILED supports fast map visualization using a collection of
        predrawn map
       images or tiles. These tiles are created and stored on the server
       after you upload your data.

         folder_name{String}:
       A string that represents  a folder name to which you want to publish the
       service definition. If the folder does not currently exist, it will be
       created.  The default folder is the server root level.

         overwrite_existing_service{Boolean}:
       A Boolean that determines whether to overwrite an existing service or
       not.

         copy_data_to_server{Boolean}:
       A Boolean that indicates whether the data referenced in the map or layers
       are copied to the server or not.

         enable_editing{Boolean}:
       A Boolean that determines if editing of feature services is
       enabled. Query capability is always on. Editing is optional.

         allow_exporting{Boolean}:
       A Boolean that determines if users can export the service to
       different formats.

         enable_sync{Boolean}:
       A Boolean that determines if users can work with a local copy of the data
       even when they are offline and
       synchronize changes when they are online.

         summary{String}:
       A string that represents the summary.

         tags{String}:
       A string that represents the tags. Multiple tags can be added or
       separated by a comma or semicolon.

         description{String}:
       A string that represents the description.

         credits{String}:
       A string that represents the credits.

         use_limitations{String}:
       A string that represents the use limitations."""
    import arcgisscripting
    return convertArcObjectToPythonObject(arcgisscripting._mapping.CreateWebLayerSDDraft(*gp_fixargs([map_or_layers, out_sddraft, service_name, server_type, service_type, folder_name, overwrite_existing_service, copy_data_to_server, enable_editing, allow_exporting, enable_sync, summary, tags, description, credits, use_limitations], True)))

