# -*- coding: utf-8 -*-
#COPYRIGHT 2016 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Network Analyst toolbox contains tools that perform network
analysis and network dataset maintenance. With the tools in this
toolbox, you can maintain network datasets that model transportation
networks and perform route, closest facility, service area, origin-
destination cost matrix, vehicle routing problem, and location-
allocation network analyses on transportation networks. Use the tools
in this toolbox whenever you want to perform an analysis on a
transportation network."""
__all__ = ['AddFieldToAnalysisLayer', 'AddLocations', 'BuildNetwork',
           'CalculateLocations', 'CopyTraversedSourceFeatures',
           'CreateNetworkDatasetFromTemplate',
           'CreateTemplateFromNetworkDataset', 'CreateTurnFeatureClass',
           'Directions', 'DissolveNetwork', 'IncreaseMaximumEdges',
           'MakeClosestFacilityAnalysisLayer', 'MakeClosestFacilityLayer',
           'MakeLocationAllocationAnalysisLayer', 'MakeLocationAllocationLayer',
           'MakeODCostMatrixAnalysisLayer', 'MakeODCostMatrixLayer',
           'MakeRouteAnalysisLayer', 'MakeRouteLayer',
           'MakeServiceAreaAnalysisLayer', 'MakeServiceAreaLayer',
           'PopulateAlternateIDFields', 'Solve', 'SolveVehicleRoutingProblem',
           'TurnTableToTurnFeatureClass',
           'UpdateAnalysisLayerAttributeParameter', 'UpdateByAlternateIDFields',
           'UpdateByGeometry', 'UpgradeNetwork']
__alias__ = 'na'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs, gptoolnotsupported
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
from arcpy import _na
from arcpy._na import *
__all__ += _na.__all__

# Analysis toolset
@gptoolnotsupported
@gptooldoc('AddFieldToAnalysisLayer_na', None)
def AddFieldToAnalysisLayer(in_network_analysis_layer=None, sub_layer=None, field_name=None, field_type=None, field_precision=None, field_scale=None, field_length=None, field_alias=None, field_is_nullable=None):
    """AddFieldToAnalysisLayer_na(in_network_analysis_layer, sub_layer, field_name, field_type, {field_precision}, {field_scale}, {field_length}, {field_alias}, {field_is_nullable})

        Adds a field to a sublayer of a network analysis layer.

     INPUTS:
      in_network_analysis_layer (Network Analyst Layer):
          Network analysis layer to which the new field will be added.
      sub_layer (String):
          The sublayer of the network analysis layer to which the new field will
          be added.
      field_name (String):
          The name of the field that will be added to the specified sublayer of
          the network analysis layer.
      field_type (String):
          The field type used in the creation of the new field.

          * LONG-Whole numbers between -2,147,483,648 and 2,147,483,647.

          * TEXT-Any string of characters.

          * FLOAT-Fractional numbers between -3.4E38 and 1.2E38.

          * DOUBLE-Fractional numbers between -2.2E308 and 1.8E308.

          * SHORT-Whole numbers between -32,768 and 32,767.

          * DATE-Date and/or time.

          * BLOB-Long sequence of binary numbers. You need a custom loader or
          viewer or a third-party application to load items into a BLOB field or
          view the contents of a BLOB field.
      field_precision {Long}:
          The number of digits that can be stored in the field. All digits are
          counted no matter what side of the decimal they are on.The parameter
          value is valid only for numeric field types.
      field_scale {Long}:
          The number of decimal places stored in a field. This parameter is only
          used in float and double data field types.
      field_length {Long}:
          The length of the field being added. This sets the maximum number of
          allowable characters for each record of the field. This option is only
          applicable on fields of type text or blob.
      field_alias {String}:
          The alternate name given to the field name. This name is used to give
          more descriptive names to cryptic field names. The field alias
          parameter only applies to geodatabases.
      field_is_nullable {Boolean}:
          Specifies whether the field can contain null values. Null values are
          different from zero or empty fields and are only supported for fields
          in a geodatabase.

          * NON_NULLABLE-The field will not allow null values.

          * NULLABLE-The field will allow null values. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddFieldToAnalysisLayer_na(*gp_fixargs((in_network_analysis_layer, sub_layer, field_name, field_type, field_precision, field_scale, field_length, field_alias, field_is_nullable), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('AddLocations_na', None)
def AddLocations(in_network_analysis_layer=None, sub_layer=None, in_table=None, field_mappings=None, search_tolerance=None, sort_field=None, search_criteria=None, match_type=None, append=None, snap_to_position_along_network=None, snap_offset=None, exclude_restricted_elements=None, search_query=None):
    """AddLocations_na(in_network_analysis_layer, sub_layer, in_table, field_mappings, search_tolerance, {sort_field}, {search_criteria;search_criteria...}, {match_type}, {append}, {snap_to_position_along_network}, {snap_offset}, {exclude_restricted_elements}, {search_query;search_query...})

        Adds network analysis objects to a network analysis layer. The objects
        are added to specific sublayers such as Stops and Barriers. Objects
        are input as features or records.

     INPUTS:
      in_network_analysis_layer (Network Analyst Layer):
          Network analysis layer to which the network analysis objects will be
          added.
      sub_layer (String):
          The sublayer of the network analysis layer to which the network
          analysis objects will be added.
      in_table (Table View):
          The feature class or the table that is the source for the new network
          analysis objects.
      field_mappings (Network Analyst Class FieldMap):
          Sets the values for the properties of the network analysis objects.
          Properties can be set to a constant or mapped to a field from the
          input feature class or table.An  NAClassFieldMappings object obtained
          from NAClassFieldMappings
          class is used to specify the parameter value. The NAClassFieldMappings
          object is a collection of NAClassFieldMap objects that allows you to
          specify the default values or map a field name from the input features
          for the properties of the network analysis object. If the data you are
          loading contains network locations or location ranges based on the
          network dataset used for the analysis, map the network location fields
          from your input features to the network location properties.
          Specifying the network location fields in the field mappings is
          similar to using the Use Network Location fields instead of geometry
          parameter from the tool dialog box.If you specify the field mapping
          for any of the network location
          properties, you need to specify the field mappings for the remaining
          network location properties to avoid a tool execution error.
      search_tolerance (Linear Unit):
          The search tolerance for locating the input features on the network.
          Features that are outside the search tolerance are left unlocated. The
          parameter includes a value and units for the tolerance.The parameter
          is not used when adding locations to the Line Barriers
          or Polygon Barriers sublayers. In such cases, use "#" as the parameter
          value.
      sort_field {Field}:
          A field on which the network analysis objects are sorted as they are
          added to the network analysis layer. The default is the ObjectID field
          on the input feature class or the table.
      search_criteria {Value Table}:
          Specifies which sources in the network dataset will be searched when
          finding locations and what portions of geometry (also known as snap
          types) will be used.The parameter value is specified as a list with
          nested lists. The
          nested list is made up of two values indicating the name and the snap
          type for each network source. The snap type is specified using the
          SHAPE, MIDDLE, END, or NONE keywords.

          * SHAPE-The point will locate on the closest point of an element in
          this network source.

          * MIDDLE-The point will locate on the closest midpoint of an element
          in this network source.

          * END-The point will locate on the closest endpoint of an element in
          this network source.

          * NONE-The point will not locate on elements in this network source.
          For example, when finding locations, the parameter value
          [["Streets","SHAPE"],["Streets_ND_Junctions","NONE"]] specifies that
          the search can locate on the shape of the Streets source but not on
          the Streets_ND_Junctions source.To specify multiple snap types for a
          single network source, use the
          combination of the snap type keywords separated by an underscore. For
          example, MIDDLE_END specifies that the locations can be snapped to the
          middle or end of the network source.When adding line or polygon
          network locations, only the SHAPE snap
          type is used, even if other snap types are specified.Any network
          source not included in this list will use its default snap
          type. It is safest to include all network sources in your list and
          explicitly set the snap type for each.
      match_type {Boolean}:
          * MATCH_TO_CLOSEST-Matches the new network locations to the closest
          network source among all the sources that have a snap type specified
          in the search criteria. This is the default.

          * PRIORITY-Matches the new network locations to the first network
          source having a snap type specified in the search criteria. The
          sources are searched in the priority order and the searching stops
          when the location is found within the search tolerance.
          The parameter is not used when adding locations to the Line Barriers
          or Polygon Barriers sublayers. In such cases, use "#" as the parameter
          value.
      append {Boolean}:
          Specifies whether or not to append new network analysis objects to
          existing objects.

          * APPEND-Adds the new network analysis objects to the existing set of
          objects in the selected sublayer.

          * CLEAR-Deletes the existing network analysis objects and replaces
          them with the new objects.
      snap_to_position_along_network {Boolean}:
          Specifies that you want to snap the network locations along the
          network dataset or at some specified offset from the network dataset.

          * NO_SNAP-The geometries of the network locations are based on the
          geometries of the input features. This is useful if you want to use
          the curb approach which requires that the network locations know which
          side of the edge they are on.

          * SNAP-if you have point features, the point will be snapped to the
          network and you will not be able to use curb approach. This is useful
          if you don't care how a vehicle approaches a stop. If your input
          features are lines or polygons, use this parameter value.
          The parameter is not used when adding locations to the Line Barriers
          or Polygon Barriers sublayers. In such cases, use "#" as the parameter
          value.
      snap_offset {Linear Unit}:
          When snapping a point to the network, you can apply an offset
          distance. An offset distance of zero means the point will be
          coincident with the network feature (typically, a line). To offset the
          point from the network feature, enter an offset distance. The offset
          is in relation to the original point location; that is, if the
          original point was on the left side, its new location will be offset
          to the left. If it was originally on the right side, its new location
          will be offset to the right.The parameter is not used when adding
          locations to the Line Barriers
          or Polygon Barriers sublayers. In such cases, use "#" as the parameter
          value.
      exclude_restricted_elements {Boolean}:
          * EXCLUDE-Specifies that the network locations are only placed on
          traversable portions of the network. This prevents placing network
          locations on elements that you can't reach due to restrictions or
          barriers. Before adding your network locations using this option, make
          sure that you have already added all the restriction barriers to the
          input network analysis layer to get expected results. This parameter
          is not applicable when adding barrier objects. In such cases, use "#"
          as the parameter value.

          * INCLUDE-Specifies that the network locations are placed on all the
          elements of the network. The network locations that are added with
          this option may be unreachable during the solve process if they are
          placed on restricted elements.
      search_query {Value Table}:
          Specifies a query to restrict the search to a subset of the features
          within a source feature class. This is useful if you don't want to
          find features that may be unsuited for a network location. For
          example, if you are loading centroids of polygons and don't want to
          locate on local roads, you can define a query that searches for major
          roads only.The parameter value is specified as a list with nested
          lists. The
          nested list is made up of two values indicating the name and the SQL
          expression for all of  the network sources. The syntax for the SQL
          expression differs slightly depending on the type of the network
          source feature class. For example, if you're querying source feature
          classes stored in file or enterprise geodatabases, shapefiles, or SDC,
          enclose field names in double quotation marks: "CFCC". If you're
          querying source feature classes stored in personal geodatabases,
          enclose fields in square brackets: [CFCC].If you don't want to specify
          a query for a particular source, use "#"
          as the value for the SQL expression or exclude the source name and the
          SQL expression from the parameter value. If you don't want to specify
          a query for all of the network sources, use "#" as the parameter
          value.For example, the parameter value [["Streets","\\"CFCC\\" =
          'A15'"],
          ["Streets_ND_Junctions",""]] specifies an SQL expression for the
          Streets source feature class and no expression for the
          Streets_ND_Junctions source feature class. Note that the double
          quotation marks used to enclose the field name CFCC are escaped using
          backslash characters to avoid a parsing error from the Python
          interpreter."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddLocations_na(*gp_fixargs((in_network_analysis_layer, sub_layer, in_table, field_mappings, search_tolerance, sort_field, search_criteria, match_type, append, snap_to_position_along_network, snap_offset, exclude_restricted_elements, search_query), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('CalculateLocations_na', None)
def CalculateLocations(in_point_features=None, in_network_dataset=None, search_tolerance=None, search_criteria=None, match_type=None, source_ID_field=None, source_OID_field=None, position_field=None, side_field=None, snap_X_field=None, snap_Y_field=None, distance_field=None, snap_Z_field=None, location_field=None, exclude_restricted_elements=None, search_query=None, travel_mode=None):
    """CalculateLocations_na(in_point_features, in_network_dataset, search_tolerance, search_criteria;search_criteria..., {match_type}, {source_ID_field}, {source_OID_field}, {position_field}, {side_field}, {snap_X_field}, {snap_Y_field}, {distance_field}, {snap_Z_field}, {location_field}, {exclude_restricted_elements}, {search_query;search_query...}, {travel_mode})

        Adds fields to the input features that contain the network location of
        the features. The tool is used to store the network location
        information as feature attributes to quickly load the features as
        inputs for a network analysis layer.

     INPUTS:
      in_point_features (Table View):
          The input features for which the network locations will be calculated.
          For line and polygon features, since the network location information
          is stored in a blob field (specified in the Location ranges field
          parameter), only geodatabase feature classes are supported.
      in_network_dataset (Network Dataset Layer):
          The network dataset used to calculate the locations.If a sublayer of a
          network analysis layer is used as input features,
          the parameter must be set to the network dataset referenced by the
          network analysis layer.
      search_tolerance (Linear Unit):
          The search tolerance for locating the input features on the network.
          Features that are outside the search tolerance are left unlocated. The
          parameter includes a value and units for the tolerance.The parameter
          is not used when calculating locations for line or
          polygon features. In such cases, use "#" as the parameter value.
      search_criteria (Value Table):
          Specifies which sources in the network dataset will be searched when
          finding locations and what portions of geometry (also known as snap
          types) will be used.The parameter value is specified as a list with
          nested lists. The
          nested list is made up of two values indicating the name and the snap
          type for each network source. The snap type is specified using the
          SHAPE, MIDDLE, END, or NONE keywords.

          * SHAPE-The point will locate on the closest point of an element in
          this network source.

          * MIDDLE-The point will locate on the closest midpoint of an element
          in this network source.

          * END-The point will locate on the closest endpoint of an element in
          this network source.

          * NONE-The point will not locate on elements in this network source.
          For example, when finding locations, the parameter value
          [["Streets","SHAPE"],["Streets_ND_Junctions","NONE"]] specifies that
          the search can locate on the shape of the Streets source but not on
          the Streets_ND_Junctions source.To specify multiple snap types for a
          single network source, use the
          combination of the snap type keywords separated by an underscore. For
          example, MIDDLE_END specifies that the locations can be snapped to the
          middle or end of the network source.For geodatabase network datasets,
          the snap types can be specified for
          each subtype of the network source (["Streets : Local
          Streets","SHAPE"]).When calculating locations for line or polygon
          features, only the
          SHAPE snap type is used, even if other snap types are specified.Any
          network source not included in this list will use its default snap
          type. It is safest to include all network sources in your list and
          explicitly set the snap type for each.
      match_type {Boolean}:
          * MATCH_TO_CLOSEST-Matches the new network locations to the closest
          network source among all the sources that have a snap type specified
          in the search criteria. This is the default.

          * PRIORITY-Matches the new network locations to the first network
          source having a snap type specified in the search criteria. The
          sources are searched in the priority order and the searching stops
          when the location is found within the search tolerance.
          The parameter is not used when calculating locations for line or
          polygon features. In such cases, use "#" as the parameter value.
      source_ID_field {Field}:
          Name of the field to be created or updated with the source ID of the
          computed network location. A field named SourceID is created or
          updated by default.The parameter is not used when calculating
          locations for line or
          polygon features. In such cases, use "#" as the parameter value.
      source_OID_field {Field}:
          Name of the field to be created or updated with the source OID of the
          computed network location. A field named SourceOID is created or
          updated by default.The parameter is not used when calculating
          locations for line or
          polygon features. In such cases, use "#" as the parameter value.
      position_field {Field}:
          Name of the field to be created or updated with the percent along with
          the computed network location. A field named PosAlong is created or
          updated by default.The parameter is not used when calculating
          locations for line or
          polygon features. In such cases, use "#" as the parameter value.
      side_field {Field}:
          Name of the field to be created or updated with the side of edge on
          which the point feature is located on the computed network location. A
          field named SideOfEdge is created or updated by default.The parameter
          is not used when calculating locations for line or
          polygon features. In such cases, use "#" as the parameter value.
      snap_X_field {Field}:
          Name of the field to be created or updated with the x-coordinate of
          the computed network location. A field named SnapX is created or
          updated by default.The parameter is not used when calculating
          locations for line or
          polygon features. In such cases, use "#" as the parameter value.
      snap_Y_field {Field}:
          Name of the field to be created or updated with the y-coordinate of
          the computed network location. A field named SnapY is created or
          updated by default.The parameter is not used when calculating
          locations for line or
          polygon features. In such cases, use "#" as the parameter value.
      distance_field {Field}:
          Name of the field to be created or updated with the distance of the
          point feature from the computed network location. A field named
          Distance is created or updated by default.The output field is in
          meters.The parameter is not used when calculating locations for line
          or
          polygon features. In such cases, use "#" as the parameter value.
      snap_Z_field {Field}:
          Name of the field to be created or updated with the z-coordinate of
          the computed network location. A field named SnapZ is created or
          updated by default.The parameter is not used when calculating
          locations for line or
          polygon features. In such cases, use "#" as the parameter value.When
          calculating locations for point features, the parameter is used
          only when the input network dataset supports connectivity based on
          z-coordinate values of the network sources. In all other cases, use
          "#" as the parameter value.
      location_field {Field}:
          Name of the field to be created or updated with the location ranges
          of the computed network locations for the line or polygon features. A
          field named Locations is created or updated by default.The parameter
          is used only when the calculating locations for line or
          polygon features. For input point features, use "#" as the parameter
          value.
      exclude_restricted_elements {Boolean}:
          Points will not be located on elements that are restricted in the
          specified travel mode. If no travel mode is specified, restrictions in
          the network's default travel mode are used.

          * EXCLUDE-Specifies that the network locations are only placed on
          traversable portions of the network. This prevents placing network
          locations on elements that you can't reach due to restrictions or
          barriers. Before relocating your network locations using this option,
          make sure that you have already added all the restriction barriers to
          the network analysis layer to get expected results. This is the
          default.

          * INCLUDE-Specifies that the network locations are placed on all the
          elements of the network. The network locations that are relocated with
          this option may be unreachable during the solve process if they are
          placed on restricted elements.
      search_query {Value Table}:
          Specifies a query to restrict the search to a subset of the features
          within a source feature class. This is useful if you don't want to
          find features that may be unsuited for a network location. For
          example, if you are loading centroids of polygons and don't want to
          locate on local roads, you can define a query that searches for major
          roads only.The parameter value is specified as a list with nested
          lists. The
          nested list is made up of two values indicating the name and the SQL
          expression for all of  the network sources. The syntax for the SQL
          expression differs slightly depending on the type of the network
          source feature class. For example, if you're querying source feature
          classes stored in file or enterprise geodatabases, shapefiles, or SDC,
          enclose field names in double quotation marks: "CFCC". If you're
          querying source feature classes stored in personal geodatabases,
          enclose fields in square brackets: [CFCC].If you don't want to specify
          a query for a particular source, use "#"
          as the value for the SQL expression or exclude the source name and the
          SQL expression from the parameter value. If you don't want to specify
          a query for all of the network sources, use "#" as the parameter
          value.For example, the parameter value [["Streets","\\"CFCC\\" =
          'A15'"],
          ["Streets_ND_Junctions",""]] specifies an SQL expression for the
          Streets source feature class and no expression for the
          Streets_ND_Junctions source feature class. Note that the double
          quotation marks used to enclose the field name CFCC are escaped using
          backslash characters to avoid a parsing error from the Python
          interpreter.
      travel_mode {String}:
          Name of the travel mode which will be used in the analysis.If you
          select a travel mode, the travel mode settings, such as
          restrictions and impedance attributes, will be considered when
          calculating location fields. For example, if the closest network edge
          to one of your input points is forbidden to trucks, and your travel
          mode is set for trucking, then Calculate Locations will locate the
          point on the next-closest network edge that is not forbidden for
          trucks.The available travel modes depend on the in_network_dataset.If
          a sublayer of a network analysis layer is used as input features,
          the travel mode parameter must be set to the network analysis layer's
          travel mode."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateLocations_na(*gp_fixargs((in_point_features, in_network_dataset, search_tolerance, search_criteria, match_type, source_ID_field, source_OID_field, position_field, side_field, snap_X_field, snap_Y_field, distance_field, snap_Z_field, location_field, exclude_restricted_elements, search_query, travel_mode), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('CopyTraversedSourceFeatures_na', None)
def CopyTraversedSourceFeatures(input_network_analysis_layer=None, output_location=None, edge_feature_class_name=None, junction_feature_class_name=None, turn_table_name=None):
    """CopyTraversedSourceFeatures_na(input_network_analysis_layer, output_location, edge_feature_class_name, junction_feature_class_name, turn_table_name)

        Creates two feature classes and a table, which together contain
        information about the edges, junctions, and turns that are traversed
        while solving a network analysis layer.

     INPUTS:
      input_network_analysis_layer (Network Analyst Layer):
          The network analysis layer from which traversed source features will
          be copied. If the network analysis layer does not have a valid result,
          the layer will be solved to produce one.
      output_location (Workspace / Feature Dataset):
          The workspace where the output table and two feature classes will be
          saved.
      edge_feature_class_name (String):
          The name of the feature class that will contain information about the
          traversed edge source features. If the solved network analysis layer
          doesn't traverse any edge features, an empty feature class is created.
      junction_feature_class_name (String):
          The name of the feature class that will contain information about the
          traversed junction source features, including system junctions and
          relevant points from the input network analysis layer. If the solved
          network analysis layer doesn't traverse any junctions, an empty
          feature class is created.
      turn_table_name (String):
          The name of the table that will contain information about the
          traversed global turns and turn features that scale cost for the
          underlying edges. If the solved network analysis layer doesn't
          traverse any turns, an empty table is created. Since restricted turns
          are never traversed, they are never included in the output."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CopyTraversedSourceFeatures_na(*gp_fixargs((input_network_analysis_layer, output_location, edge_feature_class_name, junction_feature_class_name, turn_table_name), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('Directions_na', None)
def Directions(in_network_analysis_layer=None, file_type=None, out_directions_file=None, report_units=None, report_time=None, time_attribute=None, language=None, style_name=None, stylesheet=None):
    """Directions_na(in_network_analysis_layer, file_type, out_directions_file, report_units, {report_time}, {time_attribute}, {language}, {style_name}, {stylesheet})

        Generates turn-by-turn directions from a network analysis layer with
        routes. The directions can be written to a file in text, XML, or HTML
        format. If you provide an appropriate stylesheet, the directions can
        be written to any other file format.

     INPUTS:
      in_network_analysis_layer (Network Analyst Layer):
          Network analysis layer for which directions will be generated.
          Directions can be generated only for route, closest facility, and
          vehicle routing problem network analysis layers.
      file_type (String):
          The format of the output directions file. This parameter is ignored if
          the stylesheet parameter has a value.

          * XML-The output directions file will be generated as an XML file.
          Apart from direction strings and the length and time information for
          the routes, the file will also contain information about the maneuver
          type and the turn angle for each direction.

          * TEXT-The output directions file will be generated as a simple TXT
          file containing the direction strings, the length and, optionally, the
          time information for the routes.

          * HTML-The output directions file will be generated as an HTML file
          containing the direction strings, the length and, optionally, the time
          information for the routes.
      report_units (String):
          Specifies the linear units in which the length information will be
          reported in the directions file. For example, even though your
          impedance was in meters, you can show directions in miles.

          * Feet

          * Yards

          * Miles

          * Meters

          * Kilometers

          * NauticalMiles
      report_time {Boolean}:
          * NO_REPORT_TIME-Do not report travel times in the directions file.

          * REPORT_TIME-Report travel times in the directions file. This is the
          default.
      time_attribute {String}:
          The time-based cost attribute to provide travel times in the
          directions. The cost attribute must exist on the network dataset used
          by the input network analysis layer.
      language {String}:
          Choose a language in which to generate driving directions. The
          languages that are shown in the drop-down list depend on which ArcGIS
          language packs are installed on your computer.Note that if you are
          going to publish this tool as part of a service
          on a separate server, the ArcGIS language pack that corresponds with
          the language you choose must be installed on that server for the tool
          to function properly. Also, if a language pack isn't installed on your
          computer, the language won't appear in the drop-down list; however,
          you can type a language code instead of choosing one.
      style_name {String}:
          Choose the name of the formatting style for the directions.

          * NA Desktop-Printable turn-by-turn directions

          * NA Navigation-Turn-by-turn directions designed for an in-vehicle
          navigation device

          * NA Campus-Turn-by-turn walking directions, which are designed for
          pedestrian routes
      stylesheet {File}:
          The stylesheet for generating a formatted output file type (such as a
          PDF, Word, or HTML file). The suffix of the file in the output
          directions file parameter should match the file type that the
          stylesheet generates. The Directions tool overrides the output file
          type parameter if this parameter contains a value.If you want a head
          start on creating your own text and HTML
          stylesheets, copy and edit the stylesheets Network Analyst uses. You
          can find them in the following directory: <ArcGIS installation
          directory>\\ArcGIS\\ArcGIS
          Pro\\Resources\\NetworkAnalyst\\Directions\\Styles. The stylesheet is
          Dir2PHTML.xsl, and the text stylesheet is Dir2PlainText.xsl.

     OUTPUTS:
      out_directions_file (File):
          If you provide a stylesheet in the stylesheet  parameter, make sure
          the file suffix for  out_directions_file matches the file type your
          stylesheet produces."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Directions_na(*gp_fixargs((in_network_analysis_layer, file_type, out_directions_file, report_units, report_time, time_attribute, language, style_name, stylesheet), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeClosestFacilityAnalysisLayer_na', None)
def MakeClosestFacilityAnalysisLayer(network_data_source=None, layer_name=None, travel_mode=None, travel_direction=None, cutoff=None, number_of_facilities_to_find=None, time_of_day=None, time_zone=None, time_of_day_usage=None, line_shape=None, accumulate_attributes=None):
    """MakeClosestFacilityAnalysisLayer_na(network_data_source, {layer_name}, {travel_mode}, {travel_direction}, {cutoff}, {number_of_facilities_to_find}, {time_of_day}, {time_zone}, {time_of_day_usage}, {line_shape}, {accumulate_attributes;accumulate_attributes...})

        Makes a closest facility network analysis layer and sets its analysis
        properties. A closest facility analysis layer is useful in determining
        the closest facility or facilities to an incident based on a specified
        travel mode. The layer can be created using a local network dataset or
        using a service hosted online or in a portal.

     INPUTS:
      network_data_source (Network Dataset Layer / String):
          The network dataset or service on which the network analysis will be
          performed. Use the portal URL for a service.
      layer_name {String}:
          Name of the network analysis layer to create.
      travel_mode {String}:
          Name of the travel mode to use in the analysis. The travel mode
          represents a collection of network settings, such as travel
          restrictions and U-turn policies, that determine how a pedestrian,
          car, truck, or other medium of transportation moves through the
          network. Travel modes are defined on your network data source.
      travel_direction {String}:
          Specifies the direction of travel between facilities and incidents.

          * TO_FACILITIES-Direction of travel is from incidents to facilities.
          Retail stores commonly use this setting, since they are concerned with
          the time it takes the shoppers (incidents) to reach the store
          (facility). This is the default.

          * FROM_FACILITIES-Direction of travel is from facilities to incidents.
          Fire departments commonly use this setting, since they are concerned
          with the time it takes to travel from the fire station (facility) to
          the location of the emergency (incident).
          The direction of travel may influence the facilities found if the
          network contains one-way streets or impedances based on the direction
          of travel. For instance, it might take 10 minutes to drive from a
          particular incident to a particular facility, but the journey might
          take 15 minutes traveling in the other direction, from the facility to
          the incident, because of one-way streets or different traffic
          conditions.
      cutoff {Double}:
          The impedance value at which to stop searching for facilities for a
          given incident in the units of the impedance attribute used by your
          chosen travel_mode. This cutoff can be overridden on a per-incident
          basis by specifying individual cutoff values in the incidents sublayer
          when travel_direction='TO_FACILITIES' or on a per-facility basis by
          specifying individual cutoff values in the facilities sublayer when
          travel_direction='FROM_FACILITIES' By default, no cutoff is used for
          the analysis.
      number_of_facilities_to_find {Long}:
          The number of closest facilities to find per incident. This default
          can be overridden by specifying an individual value for the
          TargetFacilityCount property in the incidents sublayer. The default
          number of facilities to find is one.
      time_of_day {Date}:
          Specifies the time and date at which the routes should begin or end.
          The interpretation of this value depends on whether time_of_day_usage
          is set to be the start time or the end time of the route.If you have
          chosen a traffic-based impedance attribute, the solution
          will be generated given dynamic traffic conditions at the time of day
          specified here. A date and time can be specified as 5/14/2012 10:30
          AM. Instead of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM.
      time_zone {String}:
          Specifies the time zone for the time_of_day parameter.

          * LOCAL_TIME_AT_LOCATIONS      -The time_of_day parameter refers to
          the time zone in which the facilities or incidents are located. This
          is the default.

          * If time_of_day_usage is set to START_TIME and travel_direction is
          FROM_FACILITIES, this is the time zone of the facilities.

          *  If time_of_day_usage is set to START_TIME and travel_direction is
          TO_FACILITIES, this is the time zone of the incidents.

          * If time_of_day_usage is set to END_TIME and travel_direction is
          FROM_FACILITIES, this is the time zone of the incidents.

          * If time_of_day_usage is set to END_TIME and travel_direction is
          TO_FACILITIES, this is the time zone of the facilities.

          * UTC-The time_of_day parameter refers to Coordinated Universal Time
          (UTC). Choose this option if you want to find what's nearest for a
          specific time, such as now, but aren't certain in which time zone the
          facilities or incidents will be located.
      time_of_day_usage {String}:
          Indicates whether the value of the time_of_day parameter represents
          the arrival or departure time for the route or routes.

          * START_TIME-time_of_day is interpreted as the departure time from the
          facility or incident. This is the default.When this setting is chosen,
          time_of_day indicates the solver should find the best route given a
          departure time.

          * END_TIME-time_of_day is interpreted as the arrival time at the
          facility or incident. This option is useful if you want to know what
          time to depart from a location so you arrive at the destination at the
          time specified in time_of_day.
      line_shape {String}:
          Specifies the shape type for the route features that are output by the
          analysis.No matter which output shape type is chosen, the best route
          is always
          determined by the network impedance, never Euclidean distance. This
          means only the route shapes are different, not the underlying
          traversal of the network.

          * ALONG_NETWORK-The output routes will have the exact shape of the
          underlying network sources. Furthermore, the output includes route
          measurements for linear referencing. The measurements increase from
          the first stop and record the cumulative impedance to reach a given
          position.

          * NO_LINES-No shape will be generated for the output routes.

          * STRAIGHT_LINES-The output route shape will be a single straight line
          between the stops.
      accumulate_attributes {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulated attributes are purely for reference; the solver only uses
          the cost attribute used by your designated travel mode when solving
          your analysis.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is populated in the network analysis output features.This
          parameter is not available if the network data source is a
          service."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeClosestFacilityAnalysisLayer_na(*gp_fixargs((network_data_source, layer_name, travel_mode, travel_direction, cutoff, number_of_facilities_to_find, time_of_day, time_zone, time_of_day_usage, line_shape, accumulate_attributes), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeClosestFacilityLayer_na', None)
def MakeClosestFacilityLayer(in_network_dataset=None, out_network_analysis_layer=None, impedance_attribute=None, travel_from_to=None, default_cutoff=None, default_number_facilities_to_find=None, accumulate_attribute_name=None, UTurn_policy=None, restriction_attribute_name=None, hierarchy=None, hierarchy_settings=None, output_path_shape=None, time_of_day=None, time_of_day_usage=None):
    """MakeClosestFacilityLayer_na(in_network_dataset, out_network_analysis_layer, impedance_attribute, {travel_from_to}, {default_cutoff}, {default_number_facilities_to_find}, {accumulate_attribute_name;accumulate_attribute_name...}, {UTurn_policy}, {restriction_attribute_name;restriction_attribute_name...}, {hierarchy}, {hierarchy_settings}, {output_path_shape}, {time_of_day}, {time_of_day_usage})

        Makes a closest facility network analysis layer and sets its analysis
        properties. A closest facility analysis layer is useful in determining
        the closest facility or facilities to an incident based on a specified
        network cost.This is a deprecated tool. This functionality has been
        replaced by the
        Make Closest Facility Analysis Layer tool.

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset on which the closest facility analysis will be
          performed.
      out_network_analysis_layer (String):
          Name of the closest facility network analysis layer to create.
      impedance_attribute (String):
          The cost attribute to be used as impedance in the analysis.
      travel_from_to {String}:
          Specifies the direction of travel between facilities and incidents.

          * TRAVEL_FROM-Direction of travel is from facilities to incidents.
          Fire departments commonly use the this setting, since they are
          concerned with the time it takes to travel from the fire station
          (facility) to the location of the emergency (incident).

          * TRAVEL_TO-Direction of travel is from incidents to facilities.
          Retail stores commonly use this setting, since they are concerned with
          the time it takes the shoppers (incidents) to reach the store
          (facility).
          Using this option can find different facilities on a network with one-
          way restrictions and different impedances based on direction of
          travel. For instance, a facility may be a 10-minute drive from the
          incident while traveling from the incident to the facility, but while
          traveling from the facility to the incident, it may be a 15-minute
          journey because of different travel time in that direction.
      default_cutoff {Double}:
          Default impedance value at which to stop searching for facilities for
          a given incident. This default can be overridden by specifying the
          cutoff value on incidents when the direction of travel is from
          incidents to facilities or by specifying the cutoff value on
          facilities when the direction of travel is from facilities to
          incidents.
      default_number_facilities_to_find {Long}:
          Default number of closest facilities to find per incident. The default
          can be overridden by specifying a value for the TargetFacilityCount
          property on the incidents.
      accumulate_attribute_name {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulation attributes are purely for reference; the solver only uses
          the cost attribute specified by the Impedance Attribute parameter to
          calculate the route.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is added to the routes that are output by the solver.
      UTurn_policy {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges connect to the junction,
          which is known as junction valency. The acceptable values for this
          parameter are listed below; each is followed by a description of its
          meaning in terms of junction valency.

          * ALLOW_UTURNS-U-turns are permitted at junctions with any number of
          connected edges. This is the default value.

          * NO_UTURNS-U-turns are prohibited at all junctions, regardless of
          junction valency. Note, however, that U-turns are still permitted at
          network locations even when this setting is chosen; however, you can
          set the individual network locations' CurbApproach property to
          prohibit U-turns there as well.

          * ALLOW_DEAD_ENDS_ONLY-U-turns are prohibited at all junctions, except
          those that have only one adjacent edge (a dead end).

          * ALLOW_DEAD_ENDS_AND_INTERSECTIONS_ONLY-U-turns are prohibited at
          junctions where exactly two adjacent edges meet but are permitted at
          intersections (junctions with three or more adjacent edges) and dead
          ends (junctions with exactly one adjacent edge). Often, networks have
          extraneous junctions in the middle of road segments. This option
          prevents vehicles from making U-turns at these locations.
          If you need a more precisely defined U-turn policy, consider adding a
          global turn delay evaluator to a network cost attribute, or adjusting
          its settings if one exists, and pay particular attention to the
          configuration of reverse turns. Also, look at setting the CurbApproach
          property of your network locations.
      restriction_attribute_name {String}:
          List of restriction attributes to apply during the analysis.
      hierarchy {Boolean}:
          * USE_HIERARCHY-Use the hierarchy attribute for the analysis. Using a
          hierarchy results in the solver preferring higher-order edges to
          lower-order edges. Hierarchical solves are faster, and they can be
          used to simulate the preference of a driver who chooses to travel on
          freeways over local roads when possible-even if that means a longer
          trip. This option is valid only if the input network dataset has a
          hierarchy attribute.

          * NO_HIERARCHY-Do not use the hierarchy attribute for the analysis.
          Not using a hierarchy yields an exact route for the network dataset.
          The parameter is not used if a hierarchy attribute is not defined on
          the network dataset used to perform the analysis. In such cases, use
          "#" as the parameter value.
      hierarchy_settings {Network Analyst Hierarchy Settings}:
          Prior to version 10, this parameter allowed you to change the
          hierarchy ranges for your analysis from the default hierarchy ranges
          established in the network dataset. At version 10, this parameter is
          no longer supported and should be specified as an empty string. If you
          wish to change the hierarchy ranges for your analysis, update the
          default hierarchy ranges in the network dataset.
      output_path_shape {String}:
          Specifies the shape type for the route features that are output by the
          analysis.

          * TRUE_LINES_WITH_MEASURES-The output routes will have the exact shape
          of the underlying network sources. Furthermore, the output includes
          route measurements for linear referencing. The measurements increase
          from the first stop and record the cumulative impedance to reach a
          given position.

          * TRUE_LINES_WITHOUT_MEASURES-The output routes will have the exact
          shape of the underlying network sources.

          * STRAIGHT_LINES-The output route shape will be a single straight line
          between each paired incident and facility.

          * NO_LINES-No shape will be generated for the output routes.
          No matter which output shape type is chosen, the best route is always
          determined by the network impedance, never Euclidean distance. This
          means only the route shapes are different, not the underlying
          traversal of the network.
      time_of_day {Date}:
          Specifies the time and date at which the routes should begin or end.
          The interpretation of this value depends on whether Time of Day Usage
          is set to be the start time or the end time of the route.If you have
          chosen a traffic-based impedance attribute, the solution
          will be generated given dynamic traffic conditions at the time of day
          specified here. A date and time can be specified as 5/14/2012 10:30
          AM. Instead of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM.
      time_of_day_usage {String}:
          Indicates whether the value of the Time of Day parameter represents
          the arrival or departure time for the route or routes.

          * START_TIME-Time of Day is interpreted as the departure time from the
          facility or incident.When this setting is chosen, Time of Day
          indicates the solver should find the best route given a departure
          time.

          * END_TIME-Time of Day is interpreted as the arrival time at the
          facility or incident. This option is useful if you want to know what
          time to depart from a location so that you arrive at the destination
          at the time specified in Time of Day.

          * NOT_USED-When Time of Day doesn't have a value, this setting is the
          only choice. When Time of Day has a value, this setting isn't
          available."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeClosestFacilityLayer_na(*gp_fixargs((in_network_dataset, out_network_analysis_layer, impedance_attribute, travel_from_to, default_cutoff, default_number_facilities_to_find, accumulate_attribute_name, UTurn_policy, restriction_attribute_name, hierarchy, hierarchy_settings, output_path_shape, time_of_day, time_of_day_usage), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeLocationAllocationAnalysisLayer_na', None)
def MakeLocationAllocationAnalysisLayer(network_data_source=None, layer_name=None, travel_mode=None, travel_direction=None, problem_type=None, cutoff=None, number_of_facilities_to_find=None, decay_function_type=None, decay_function_parameter_value=None, target_market_share=None, capacity=None, time_of_day=None, time_zone=None, line_shape=None, accumulate_attributes=None):
    """MakeLocationAllocationAnalysisLayer_na(network_data_source, {layer_name}, {travel_mode}, {travel_direction}, {problem_type}, {cutoff}, {number_of_facilities_to_find}, {decay_function_type}, {decay_function_parameter_value}, {target_market_share}, {capacity}, {time_of_day}, {time_zone}, {line_shape}, {accumulate_attributes;accumulate_attributes...})

        Makes a location-allocation network analysis layer and sets its
        analysis properties. A location-allocation analysis layer is useful
        for choosing a given number of facilities from a set of potential
        locations such that a demand will be allocated to facilities in an
        optimal and efficient manner. The layer can be created using a local
        network dataset or using a service hosted online or in a portal.

     INPUTS:
      network_data_source (Network Dataset Layer / String):
          The network dataset or service on which the network analysis will be
          performed. Use the portal URL for a service.
      layer_name {String}:
          Name of the network analysis layer to create.
      travel_mode {String}:
          Name of the travel mode to use in the analysis. The travel mode
          represents a collection of network settings, such as travel
          restrictions and U-turn policies, that determine how a pedestrian,
          car, truck, or other medium of transportation moves through the
          network. Travel modes are defined on your network data source.
      travel_direction {String}:
          Specifies the direction of travel between facilities and demand points
          when calculating the network costs.

          * FROM_FACILITIES-Direction of travel is from facilities to demand
          points. This is the default. Fire departments commonly use the this
          setting, since they are concerned with the time it takes to travel
          from the fire station to the location of the emergency.

          * TO_FACILITIES-Direction of travel is from demand points to
          facilities. Retail stores commonly use this setting, since they are
          concerned with the time it takes the shoppers to reach the store.
          Using this option can affect the allocation of the demand points to
          the facilities on a network with one-way restrictions and different
          impedances based on direction of travel. For instance, it may take 15
          minutes to drive from the demand point to the facility but only 10
          minutes when driving from the facility to the demand point.
      problem_type {String}:
          The problem type that will be solved. The choice of the problem type
          depends on the kind of facility being located. Different kinds of
          facilities have different priorities and constraints.

          * MINIMIZE_IMPEDANCE-This option solves the warehouse location
          problem. It selects a set of facilities such that the total sum of
          weighted impedances (demand at a location times the impedance to the
          closest facility) is minimized. This problem type is often known as
          the P-Median problem. This is the default problem type.

          * MAXIMIZE_COVERAGE-This option solves the fire station location
          problem. It chooses facilities such that all or the greatest amount of
          demand is within a specified impedance cutoff.

          * MAXIMIZE_CAPACITATED_COVERAGE-This option solves the location
          problem where facilities have a finite capacity. It chooses facilities
          such that all or the greatest amount of demand can be served without
          exceeding the capacity of any facility. In addition to honoring
          capacity, it selects facilities such that the total sum of weighted
          impedance (demand allocated to a facility multiplied by the impedance
          to or from the facility) is minimized.

          * MINIMIZE_FACILITIES-This option solves the fire station location
          problem. It chooses the minimum number of facilities needed to cover
          all or the greatest amount of demand within a specified impedance
          cutoff.

          * MAXIMIZE_ATTENDANCE-This option solves the neighborhood store
          location problem where the proportion of demand allocated to the
          nearest chosen facility falls with increasing distance. The set of
          facilities that maximize the total allocated demand is chosen. Demand
          further than the specified impedance cutoff does not affect the chosen
          set of facilities.

          * MAXIMIZE_MARKET_SHARE-This option solves the competitive facility
          location problem. It chooses facilities to maximize market share in
          the presence of competitive facilities. Gravity model concepts are
          used to determine the proportion of demand allocated to each facility.
          The set of facilities that maximizes the total allocated demand is
          chosen.

          * TARGET_MARKET_SHARE-This option solves the competitive facility
          location problem. It chooses facilities to reach a specified target
          market share in the presence of competitive facilities. Gravity model
          concepts are used to determine the proportion of demand allocated to
          each facility. The minimum number of facilities needed to reach the
          specified target market share is chosen.
      cutoff {Double}:
          The maximum impedance at which a demand point can be allocated to a
          facility in the units of the impedance attribute used by your chosen
          Travel Mode. The maximum impedance is measured by the least-cost path
          along the network. If a demand point is outside the cutoff, it is left
          unallocated. This property might be used to model the maximum distance
          that people are willing to travel to visit your stores or the maximum
          time that is permitted for a fire department to reach anyone in the
          community. This cutoff can be overridden on a per-demand-point basis
          by
          specifying individual cutoff values in the demand points sublayer in
          the Cutoff_[Impedance] property. For example, you might find that
          people in rural areas are willing to travel up to 10 miles to reach a
          facility while urbanites are only willing to travel up to 2 miles. You
          can model this behavior by setting the Cutoff value of the analysis
          layer to 10 and setting the Cutoff_Miles value of each demand point in
          an urban areas to 2.By default, no cutoff is used for the analysis.
      number_of_facilities_to_find {Long}:
          Specifies the number of facilities that the solver should locate. By
          default, this parameter is set to 1.The facilities with a FacilityType
          value of Required are always part
          of the solution when there are more facilities to find than required
          facilities; any excess facilities to choose are picked from candidate
          facilities.Any facilities that have a FacilityType value of Chosen
          before solving
          are treated as candidate facilities at solve time.The parameter value
          is not considered for the MINIMIZE_FACILITIES
          problem type since the solver determines the minimum number of
          facilities to locate to maximize coverage.The parameter value is
          overridden for the TARGET_MARKET_SHARE problem
          type because the solver searches for the minimum number of facilities
          required to capture the specified market share.
      decay_function_type {String}:
          This sets the equation for transforming the network cost between
          facilities and demand points. This property, coupled with the Decay
          Function Parameter Value, specifies how severely the network impedance
          between facilities and demand points influences the solver's choice of
          facilities.

          * LINEAR-The transformed network impedance between the facility and
          the demand point is the same as the shortest-path network impedance
          between them. With this option, the impedance parameter is always set
          to 1. This is the default.

          * POWER-The transformed network impedance between the facility and the
          demand point is equal to the shortest-path network impedance raised to
          the power specified by the impedance parameter. Use this option with a
          positive impedance parameter to specify higher weight to nearby
          facilities.

          * EXPONENTIAL-The transformed network impedance between the facility
          and the demand point is equal to the mathematical constant e raised to
          the power specified by the shortest-path network impedance multiplied
          with the impedance parameter. Use this option with a positive
          impedance parameter to specify a very high weight to nearby
          facilities.Exponential transformations are commonly used in
          conjunction with an impedance cutoff.
          Demand points have an ImpedanceTransformation property, which, if set,
          overrides the Decay Function Parameter Value property of the analysis
          layer on a per-demand-point basis. You might determine that the decay
          function should be different for urban and rural residents. You can
          model this by setting the impedance transformation for the analysis
          layer to match that of rural residents and setting the impedance
          transformation for the individual demand points located in urban areas
          to match that of urbanites.
      decay_function_parameter_value {Double}:
          Provides a parameter value to the equations specified in the
          decay_function_type parameter. The parameter value is ignored when the
          decay function is of type LINEAR. For POWER and EXPONENTIAL decay
          functions, the value should be nonzero.Demand points have an
          ImpedanceTransformation property, which, if set,
          overrides the decay_function_parameter_value property of the analysis
          layer on a per-demand-point basis. You might determine that the decay
          function should be different for urban and rural residents. You can
          model this by setting the impedance transformation for the analysis
          layer to match that of rural residents and setting the impedance
          transformation for the individual demand points located in urban areas
          to match that of urbanites.
      target_market_share {Double}:
          Specifies the target market share in percentage to solve for when the
          problem_type parameter is set to TARGET_MARKET_SHARE. It is the
          percentage of the total demand weight that you want your solution
          facilities to capture. The solver chooses the minimum number of
          facilities required to capture the target market share specified by
          this numeric value.
      capacity {Double}:
          Specifies the default capacity of facilities when the problem_type
          parameter is set to MAXIMIZE_CAPACITATED_COVERAGE. This parameter is
          ignored for all other problem types.Facilities have a Capacity
          property, which, if set to a nonnull value,
          overrides the capacity parameter for that facility.
      time_of_day {Date}:
          Indicates the time and date of departure. The departure time can be
          from facilities or demand points, depending on whether Travel
          Direction is from demand to facility or facility to demand.If you have
          chosen a traffic-based impedance attribute, the solution
          will be generated given dynamic traffic conditions at the time of day
          specified here. A date and time can be specified as 5/14/2012 10:30
          AM. Instead of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM.
      time_zone {String}:
          Specifies the time zone of the Time of Day parameter.

          * LOCAL_TIME_AT_LOCATIONS-The Time of Day parameter refers to the time
          zone in which the facilities or demand points are located. If Travel
          Direction is facilities to demand points, this is the time zone of the
          facilities. If Travel Direction is demand points to facilities, this
          is the time zone of the demand points. This is the default.

          * UTC-The Time of Day parameter refers to Coordinated Universal Time
          (UTC). Choose this option if you want to choose the best location for
          a specific time, such as now, but aren't certain in which time zone
          the facilities or demand points will be located.
      line_shape {String}:
          * NO_LINES-No shape will be generated for the output of the analysis.
          This is useful if you are solving a very large problem and are
          interested only in solution table and are not interested in
          visualizing your results in a map.

          * STRAIGHT_LINES-The output line shapes will be straight lines
          connecting the solution facilities to their allocated demand points.
          This is the default.
          No matter which output shape type is chosen, the best route is always
          determined by the network impedance, never Euclidean distance. This
          means only the route shapes are different, not the underlying
          traversal of the network.
      accumulate_attributes {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulated attributes are purely for reference; the solver only uses
          the cost attribute used by your designated travel mode when solving
          your analysis.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is populated in the network analysis output features.This
          parameter is not available if the network data source is a
          service."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeLocationAllocationAnalysisLayer_na(*gp_fixargs((network_data_source, layer_name, travel_mode, travel_direction, problem_type, cutoff, number_of_facilities_to_find, decay_function_type, decay_function_parameter_value, target_market_share, capacity, time_of_day, time_zone, line_shape, accumulate_attributes), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeLocationAllocationLayer_na', None)
def MakeLocationAllocationLayer(in_network_dataset=None, out_network_analysis_layer=None, impedance_attribute=None, loc_alloc_from_to=None, loc_alloc_problem_type=None, number_facilities_to_find=None, impedance_cutoff=None, impedance_transformation=None, impedance_parameter=None, target_market_share=None, accumulate_attribute_name=None, UTurn_policy=None, restriction_attribute_name=None, hierarchy=None, output_path_shape=None, default_capacity=None, time_of_day=None):
    """MakeLocationAllocationLayer_na(in_network_dataset, out_network_analysis_layer, impedance_attribute, {loc_alloc_from_to}, {loc_alloc_problem_type}, {number_facilities_to_find}, {impedance_cutoff}, {impedance_transformation}, {impedance_parameter}, {target_market_share}, {accumulate_attribute_name;accumulate_attribute_name...}, {UTurn_policy}, {restriction_attribute_name;restriction_attribute_name...}, {hierarchy}, {output_path_shape}, {default_capacity}, {time_of_day})

        Makes a location-allocation network analysis layer and sets its
        analysis properties. A location-allocation analysis layer is useful
        for choosing a given number of facilities from a set of potential
        locations such that a demand will be allocated to facilities in an
        optimal and efficient manner.This is a deprecated tool. This
        functionality has been replaced by the
        Make Location-Allocation Analysis Layer tool.

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset on which the location-allocation analysis will be
          performed.
      out_network_analysis_layer (String):
          Name of the location-allocation network analysis layer to create.
      impedance_attribute (String):
          The cost attribute to be used as impedance in the analysis.
      loc_alloc_from_to {String}:
          Specifies the direction of travel between facilities and demand points
          when calculating the network costs.

          * FACILITY_TO_DEMAND-Direction of travel is from facilities to demand
          points. Fire departments commonly use the this setting, since they are
          concerned with the time it takes to travel from the fire station to
          the location of the emergency.

          * DEMAND_TO_FACILITY-Direction of travel is from demand points to
          facilities. Retail stores commonly use this setting, since they are
          concerned with the time it takes the shoppers to reach the store.
          Using this option can affect the allocation of the demand points to
          the facilities on a network with one-way restrictions and different
          impedances based on direction of travel. For instance, a facility may
          be a 15-minute drive from the demand point to the facility, but only a
          10-minute trip when traveling from the facility to the demand point.
      loc_alloc_problem_type {String}:
          The problem type that will be solved. The choice of the problem type
          depends on the kind of facility being located. Different kinds of
          facilities have different priorities and constraints.

          * MINIMIZE_IMPEDANCE-This option solves the warehouse location
          problem. It selects a set of facilities such that the total sum of
          weighted impedances (demand at a location times the impedance to the
          closest facility) is minimized. This problem type is often known as
          the P-Median problem.

          * MAXIMIZE_COVERAGE-This option solves the fire station location
          problem. It chooses facilities such that all or the greatest amount of
          demand is within a specified impedance cutoff.

          * MAXIMIZE_CAPACITATED_COVERAGE-This option solves the location
          problem where facilities have a finite capacity. It chooses facilities
          such that all or the greatest amount of demand can be served without
          exceeding the capacity of any facility. In addition to honoring
          capacity, it selects facilities such that the total sum of weighted
          impedance (demand allocated to a facility multiplied by the impedance
          to or from the facility) is minimized.

          * MINIMIZE_FACILITIES-This option solves the fire station location
          problem. It chooses the minimum number of facilities needed to cover
          all or the greatest amount of demand within a specified impedance
          cutoff.

          * MAXIMIZE_ATTENDANCE-This option solves the neighborhood store
          location problem where the proportion of demand allocated to the
          nearest chosen facility falls with increasing distance. The set of
          facilities that maximize the total allocated demand is chosen. Demand
          further than the specified impedance cutoff does not affect the chosen
          set of facilities.

          * MAXIMIZE_MARKET_SHARE-This option solves the competitive facility
          location problem. It chooses facilities to maximize market share in
          the presence of competitive facilities. Gravity model concepts are
          used to determine the proportion of demand allocated to each facility.
          The set of facilities that maximizes the total allocated demand is
          chosen.

          * TARGET_MARKET_SHARE-This option solves the competitive facility
          location problem. It chooses facilities to reach a specified target
          market share in the presence of competitive facilities. Gravity model
          concepts are used to determine the proportion of demand allocated to
          each facility. The minimum number of facilities needed to reach the
          specified target market share is chosen.
      number_facilities_to_find {Long}:
          Specifies the number of facilities that the solver should locate.The
          facilities with a FacilityType value of Required are always part
          of the solution when there are more facilities to find than required
          facilities; any excess facilities to choose are picked from candidate
          facilities.Any facilities that have a FacilityType value of Chosen
          before solving
          are treated as candidate facilities at solve time.The parameter value
          is not considered for the MINIMIZE_FACILITIES
          problem type since the solver determines the minimum number of
          facilities to locate to maximize coverage.The parameter value is
          overridden for the TARGET_MARKET_SHARE problem
          type because the solver searches for the minimum number of facilities
          required to capture the specified market share.
      impedance_cutoff {Double}:
          Impedance Cutoff specifies the maximum impedance at which a demand
          point can be allocated to a facility. The maximum impedance is
          measured by the least-cost path along the network. If a demand point
          is outside the cutoff, it is left unallocated. This property might be
          used to model the maximum distance that people are willing to travel
          to visit your stores or the maximum time that is permitted for a fire
          department to reach anyone in the community.Demand points have a
          Cutoff_[Impedance] property, which, if set,
          overrides the Impedance Cutoff property of the analysis layer. You
          might find that people in rural areas are willing to travel up to 10
          miles to reach a facility, while urbanites are only willing to travel
          up to 2 miles. You can model this behavior by setting the impedance
          cutoff value of the analysis layer to 10 and setting the Cutoff_Miles
          value of the demand points in urban areas to 2.
      impedance_transformation {String}:
          This sets the equation for transforming the network cost between
          facilities and demand points. This property, coupled with the
          Impedance Parameter, specifies how severely the network impedance
          between facilities and demand points influences the solver's choice of
          facilities.

          * LINEAR-The transformed network impedance between the facility and
          the demand point is the same as the shortest-path network impedance
          between them. With this option, the impedance parameter is always set
          to one. This is the default.

          * POWER-The transformed network impedance between the facility and the
          demand point is equal to the shortest-path network impedance raised to
          the power specified by the impedance parameter. Use this option with a
          positive impedance parameter to specify higher weight to nearby
          facilities.

          * EXPONENTIAL-The transformed network impedance between the facility
          and the demand point is equal to the mathematical constant e raised to
          the power specified by the shortest-path network impedance multiplied
          with the impedance parameter. Use this option with a positive
          impedance parameter to specify a very high weight to nearby
          facilities.Exponential transformations are commonly used in
          conjunction with an impedance cutoff.
          Demand points have an ImpedanceTransformation property, which, if set,
          overrides the Impedance Transformation property of the analysis layer.
          You might determine the impedance transformation should be different
          for urban and rural residents. You can model this by setting the
          impedance transformation for the analysis layer to match that of rural
          residents and setting the impedance transformation for the demand
          points in urban areas to match that of urbanites.
      impedance_parameter {Double}:
          Provides a parameter value to the equations specified in the Impedance
          transformation parameter. The parameter value is ignored when the
          impedance transformation is of type LINEAR. For POWER and EXPONENTIAL
          impedance transformations, the value should be nonzero.Demand points
          have an ImpedanceParameter property, which, if set,
          overrides the Impedance Parameter property of the analysis layer. You
          might determine that the impedance parameter should be different for
          urban and rural residents. You can model this by setting the impedance
          transformation for the analysis layer to match that of rural residents
          and setting the impedance transformation for the demand points in
          urban areas to match that of urbanites.
      target_market_share {Double}:
          Specifies the target market share in percentage to solve for when the
          Location-Allocation Problem Type parameter is set to
          TARGET_MARKET_SHARE . It is the percentage of the total demand weight
          that you want your solution facilities to capture. The solver chooses
          the minimum number of facilities required to capture the target market
          share specified by this numeric value.
      accumulate_attribute_name {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulation attributes are purely for reference; the solver only uses
          the cost attribute specified by the Impedance Attribute parameter to
          calculate the route.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is added to the routes that are output by the solver.
      UTurn_policy {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges connect to the junction,
          which is known as junction valency. The acceptable values for this
          parameter are listed below; each is followed by a description of its
          meaning in terms of junction valency.

          * ALLOW_UTURNS-U-turns are permitted at junctions with any number of
          connected edges. This is the default value.

          * NO_UTURNS-U-turns are prohibited at all junctions, regardless of
          junction valency. Note, however, that U-turns are still permitted at
          network locations even when this setting is chosen; however, you can
          set the individual network locations' CurbApproach property to
          prohibit U-turns there as well.

          * ALLOW_DEAD_ENDS_ONLY-U-turns are prohibited at all junctions, except
          those that have only one adjacent edge (a dead end).

          * ALLOW_DEAD_ENDS_AND_INTERSECTIONS_ONLY-U-turns are prohibited at
          junctions where exactly two adjacent edges meet but are permitted at
          intersections (junctions with three or more adjacent edges) and dead
          ends (junctions with exactly one adjacent edge). Often, networks have
          extraneous junctions in the middle of road segments. This option
          prevents vehicles from making U-turns at these locations.
          If you need a more precisely defined U-turn policy, consider adding a
          global turn delay evaluator to a network cost attribute, or adjusting
          its settings if one exists, and pay particular attention to the
          configuration of reverse turns. Also, look at setting the CurbApproach
          property of your network locations.
      restriction_attribute_name {String}:
          List of restriction attributes to apply during the analysis.
      hierarchy {Boolean}:
          * USE_HIERARCHY-Use the hierarchy attribute for the analysis. Using a
          hierarchy results in the solver preferring higher-order edges to
          lower-order edges. Hierarchical solves are faster, and they can be
          used to simulate the preference of a driver who chooses to travel on
          freeways over local roads when possible-even if that means a longer
          trip. This option is valid only if the input network dataset has a
          hierarchy attribute.

          * NO_HIERARCHY-Do not use the hierarchy attribute for the analysis.
          Not using a hierarchy yields an exact route for the network dataset.
          The parameter is not used if a hierarchy attribute is not defined on
          the network dataset used to perform the analysis. In such cases, use
          "#" as the parameter value.
      output_path_shape {String}:
          * NO_LINES-No shape will be generated for the output of the analysis.

          * STRAIGHT_LINES-The output line shapes will be straight lines
          connecting the solution facilities to their allocated demand points.
      default_capacity {Double}:
          Specifies the default capacity of facilities when the
          loc_alloc_problem_type parameter is set to
          MAXIMIZE_CAPACITATED_COVERAGE. This parameter is ignored for all other
          problem types.Facilities have a Capacity property, which, if set to a
          nonnull value,
          overrides the default_capacity parameter for that facility.
      time_of_day {Date}:
          Indicates the time and date of departure. The departure time can be
          from facilities or demand points, depending on whether travel is from
          demand to facility or facility to demand.If you have chosen a traffic-
          based impedance attribute, the solution
          will be generated given dynamic traffic conditions at the time of day
          specified here. A date and time can be specified as 5/14/2012 10:30
          AM. Instead of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeLocationAllocationLayer_na(*gp_fixargs((in_network_dataset, out_network_analysis_layer, impedance_attribute, loc_alloc_from_to, loc_alloc_problem_type, number_facilities_to_find, impedance_cutoff, impedance_transformation, impedance_parameter, target_market_share, accumulate_attribute_name, UTurn_policy, restriction_attribute_name, hierarchy, output_path_shape, default_capacity, time_of_day), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeODCostMatrixAnalysisLayer_na', None)
def MakeODCostMatrixAnalysisLayer(network_data_source=None, layer_name=None, travel_mode=None, cutoff=None, number_of_destinations_to_find=None, time_of_day=None, time_zone=None, line_shape=None, accumulate_attributes=None):
    """MakeODCostMatrixAnalysisLayer_na(network_data_source, {layer_name}, {travel_mode}, {cutoff}, {number_of_destinations_to_find}, {time_of_day}, {time_zone}, {line_shape}, {accumulate_attributes;accumulate_attributes...})

        Makes an origin-destination (OD) cost matrix network analysis layer
        and sets its analysis properties. An OD cost matrix analysis layer is
        useful for representing a matrix of costs going from a set of origin
        locations to a set of destination locations. The layer can be created
        using a local network dataset or using a service hosted online or in a
        portal.

     INPUTS:
      network_data_source (Network Dataset Layer / String):
          The network dataset or service on which the network analysis will be
          performed. Use the portal URL for a service.
      layer_name {String}:
          Name of the network analysis layer to create.
      travel_mode {String}:
          Name of the travel mode to use in the analysis. The travel mode
          represents a collection of network settings, such as travel
          restrictions and U-turn policies, that determine how a pedestrian,
          car, truck, or other medium of transportation moves through the
          network. Travel modes are defined on your network data source.
      cutoff {Double}:
          The impedance value at which to stop searching for destinations for a
          given origin in the units of the impedance attribute used by your
          chosen Travel Mode. No destinations beyond this limit will be found.
          This cutoff can be overridden on a per-origin basis by specifying
          individual cutoff values in the origins sublayer. By default, no
          cutoff is used for the analysis.
      number_of_destinations_to_find {Long}:
          The number of destinations to find per origin. This default can be
          overridden by specifying an individual value for the
          TargetDestinationCount property in the origins sublayer. By default,
          no limit is used, and all destinations are found.
      time_of_day {Date}:
          Indicates the departure time from origins.If you have chosen a
          traffic-based impedance attribute, the solution
          will be generated given dynamic traffic conditions at the time of day
          specified here. A date and time can be specified as 5/14/2012 10:30
          AM. Instead of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM.
      time_zone {String}:
          Specifies the time zone of the Time of Day parameter.

          * LOCAL_TIME_AT_LOCATIONS-The Time of Day parameter refers to the time
          zone in which the origins are located. This is the default.

          * UTC-The Time of Day parameter refers to Coordinated Universal Time
          (UTC). Choose this option if you want to calculate your OD cost matrix
          for a specific time, such as now, but aren't certain in which time
          zone the origins will be located.
      line_shape {String}:
          * NO_LINES-No shape will be generated for the output origin-
          destination route pair. This is useful when you have a large number of
          origins and destinations and are interested only in the impedance
          costs in the OD cost matrix table but not interested in visualizing
          your OD cost matrix in a map.

          * STRAIGHT_LINES-The output route shape will be a single straight line
          between each of the origin-destination pairs. This is the default.
          No matter which output shape type is chosen, the best route is always
          determined by the network impedance, never Euclidean distance. This
          means only the route shapes are different, not the underlying
          traversal of the network.
      accumulate_attributes {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulated attributes are purely for reference; the solver only uses
          the cost attribute used by your designated travel mode when solving
          your analysis.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is populated in the network analysis output features.This
          parameter is not available if the network data source is a
          service."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeODCostMatrixAnalysisLayer_na(*gp_fixargs((network_data_source, layer_name, travel_mode, cutoff, number_of_destinations_to_find, time_of_day, time_zone, line_shape, accumulate_attributes), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeODCostMatrixLayer_na', None)
def MakeODCostMatrixLayer(in_network_dataset=None, out_network_analysis_layer=None, impedance_attribute=None, default_cutoff=None, default_number_destinations_to_find=None, accumulate_attribute_name=None, UTurn_policy=None, restriction_attribute_name=None, hierarchy=None, hierarchy_settings=None, output_path_shape=None, time_of_day=None):
    """MakeODCostMatrixLayer_na(in_network_dataset, out_network_analysis_layer, impedance_attribute, {default_cutoff}, {default_number_destinations_to_find}, {accumulate_attribute_name;accumulate_attribute_name...}, {UTurn_policy}, {restriction_attribute_name;restriction_attribute_name...}, {hierarchy}, {hierarchy_settings}, {output_path_shape}, {time_of_day})

        Makes an origin-destination (OD) cost matrix network analysis layer
        and sets its analysis properties. An OD cost matrix analysis layer is
        useful for representing a matrix of costs going from a set of origin
        locations to a set of destination locations.This is a deprecated tool.
        This functionality has been replaced by the
        Make OD Cost Matrix Analysis Layer tool.

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset on which the OD cost matrix analysis will be
          performed.
      out_network_analysis_layer (String):
          Name of the OD cost matrix network analysis layer to create.
      impedance_attribute (String):
          The cost attribute to be used as impedance in the analysis.
      default_cutoff {Double}:
          Default impedance value at which to cut off searching for destinations
          for a given origin. If the accumulated impedance becomes higher than
          the cutoff value, the traversal stops. The default can be overridden
          by specifying the cutoff value on the origins.
      default_number_destinations_to_find {Long}:
          Default number of destinations to find for each origin. The default
          can be overridden by specifying a value for the TargetDestinationCount
          property on the origins.
      accumulate_attribute_name {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulation attributes are purely for reference; the solver only uses
          the cost attribute specified by the Impedance Attribute parameter to
          calculate the route.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is added to the routes that are output by the solver.
      UTurn_policy {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges connect to the junction,
          which is known as junction valency. The acceptable values for this
          parameter are listed below; each is followed by a description of its
          meaning in terms of junction valency.

          * ALLOW_UTURNS-U-turns are permitted at junctions with any number of
          connected edges. This is the default value.

          * NO_UTURNS-U-turns are prohibited at all junctions, regardless of
          junction valency. Note, however, that U-turns are still permitted at
          network locations even when this setting is chosen; however, you can
          set the individual network locations' CurbApproach property to
          prohibit U-turns there as well.

          * ALLOW_DEAD_ENDS_ONLY-U-turns are prohibited at all junctions, except
          those that have only one adjacent edge (a dead end).

          * ALLOW_DEAD_ENDS_AND_INTERSECTIONS_ONLY-U-turns are prohibited at
          junctions where exactly two adjacent edges meet but are permitted at
          intersections (junctions with three or more adjacent edges) and dead
          ends (junctions with exactly one adjacent edge). Often, networks have
          extraneous junctions in the middle of road segments. This option
          prevents vehicles from making U-turns at these locations.
          If you need a more precisely defined U-turn policy, consider adding a
          global turn delay evaluator to a network cost attribute, or adjusting
          its settings if one exists, and pay particular attention to the
          configuration of reverse turns. Also, look at setting the CurbApproach
          property of your network locations.
      restriction_attribute_name {String}:
          List of restriction attributes to apply during the analysis.
      hierarchy {Boolean}:
          * USE_HIERARCHY-Use the hierarchy attribute for the analysis. Using a
          hierarchy results in the solver preferring higher-order edges to
          lower-order edges. Hierarchical solves are faster, and they can be
          used to simulate the preference of a driver who chooses to travel on
          freeways over local roads when possible-even if that means a longer
          trip. This option is valid only if the input network dataset has a
          hierarchy attribute.

          * NO_HIERARCHY-Do not use the hierarchy attribute for the analysis.
          Not using a hierarchy yields an exact route for the network dataset.
          The parameter is not used if a hierarchy attribute is not defined on
          the network dataset used to perform the analysis. In such cases, use
          "#" as the parameter value.
      hierarchy_settings {Network Analyst Hierarchy Settings}:
          Prior to version 10, this parameter allowed you to change the
          hierarchy ranges for your analysis from the default hierarchy ranges
          established in the network dataset. At version 10, this parameter is
          no longer supported and should be specified as an empty string. If you
          wish to change the hierarchy ranges for your analysis, update the
          default hierarchy ranges in the network dataset.
      output_path_shape {String}:
          * NO_LINES-No shape will be generated for the output routes. This is
          useful when you have large number of origins and destinations and are
          interested only in the OD cost matrix table (and not the output line
          shapes).

          * STRAIGHT_LINES-The output route shape will be a single straight line
          between each of the origin-destination pairs.
          No matter which output shape type is chosen, the best route is always
          determined by the network impedance, never Euclidean distance. This
          means only the route shapes are different, not the underlying
          traversal of the network.
      time_of_day {Date}:
          Indicates the departure time from origins.If you have chosen a
          traffic-based impedance attribute, the solution
          will be generated given dynamic traffic conditions at the time of day
          specified here. A date and time can be specified as 5/14/2012 10:30
          AM. Instead of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeODCostMatrixLayer_na(*gp_fixargs((in_network_dataset, out_network_analysis_layer, impedance_attribute, default_cutoff, default_number_destinations_to_find, accumulate_attribute_name, UTurn_policy, restriction_attribute_name, hierarchy, hierarchy_settings, output_path_shape, time_of_day), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeRouteAnalysisLayer_na', None)
def MakeRouteAnalysisLayer(network_data_source=None, layer_name=None, travel_mode=None, sequence=None, time_of_day=None, time_zone=None, line_shape=None, accumulate_attributes=None):
    """MakeRouteAnalysisLayer_na(network_data_source, {layer_name}, {travel_mode}, {sequence}, {time_of_day}, {time_zone}, {line_shape}, {accumulate_attributes;accumulate_attributes...})

        Makes a route network analysis layer and sets its analysis
        properties. A route analysis layer is useful for determining the best
        route between a set of network locations based on a specified network
        cost. The layer can be created using a local network dataset or using
        a routing service hosted online or in a portal.

     INPUTS:
      network_data_source (Network Dataset Layer / String):
          The network dataset or service on which the network analysis will be
          performed. Use the portal URL for a service.
      layer_name {String}:
          Name of the network analysis layer to create.
      travel_mode {String}:
          Name of the travel mode to use in the analysis. The travel mode
          represents a collection of network settings, such as travel
          restrictions and U-turn policies, that determine how a pedestrian,
          car, truck, or other medium of transportation moves through the
          network. Travel modes are defined on your network data source.
      sequence {String}:
          Specifies whether the input stops must be visited in a particular
          order when calculating the optimal route. This option changes the
          route analysis from a shortest-path problem to a traveling salesperson
          problem (TSP).

          * USE_CURRENT_ORDER-The stops will be visited in the input order. This
          is the default.

          * FIND_BEST_ORDER-The stops will be reordered to find the optimal
          route. This option changes the route analysis from a shortest-path
          problem to a traveling salesperson problem (TSP).

          * PRESERVE_BOTH-Preserve the first and last stops by input order. The
          rest will be reordered to find the optimal route.

          * PRESERVE_FIRST-Preserve the first stop by input order. The rest will
          be reordered to find the optimal route.

          * PRESERVE_LAST-Preserve the last stop by input order. The rest will
          be reordered to find the optimal route.
      time_of_day {Date}:
          Specifies a start date and time for the route. Route start time is
          mostly used to find routes based on the impedance attribute that
          varies with the time of the day. For example, a start time of 7 a.m.
          could be used to find a route that considers the rush hour traffic.
          The default value for this parameter is 8:00 a.m. A date and time can
          be specified as 10/21/05 10:30 AM. If the route spans multiple days,
          and only the start time is specified, then the current date is used.
          Instead of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM. After the
          solve, the start and end time of the route are populated in
          the output routes. These start and end times are also used when
          directions are generated.
      time_zone {String}:
          Specifies the time zone of the time_of_day parameter.

          * LOCAL_TIME_AT_LOCATIONS      -The time_of_day parameter refers to
          the time zone in which the first stop of a route is located. This is
          the default.If you are generating many routes that start in multiple
          times zones, the start times are staggered in Coordinated Universal
          Time (UTC). For example, a time_of_day value of 10:00 a.m., 2 January,
          would mean a start time of 10:00 a.m. Eastern Standard Time (3:00 p.m.
          UTC) for routes beginning in the Eastern Time Zone and 10:00 a.m.
          Central Standard Time (4:00 p.m. UTC) for routes beginning in the
          Central Time Zone. The start times are offset by one hour in UTC.The
          arrival and departure times and dates recorded in the output Stops
          feature class will refer to the local time zone of the first stop for
          each route.

          * UTC-The time_of_day parameter refers to Coordinated Universal Time
          (UTC). Choose this option if you want to generate a route for a
          specific time, such as now, but aren't certain in which time zone the
          first stop will be located.If you are generating many routes spanning
          multiple times zones, the start times in UTC are simultaneous. For
          example, a time_of_day value of 10:00 a.m., 2 January, would mean a
          start time of 5:00 a.m. Eastern Standard Time (5:00 a.m. UTC) for
          routes beginning in the Eastern Time Zone and 4:00 a.m. Central
          Standard Time (6:00 a.m. UTC) for routes beginning in the Central Time
          Zone. Both routes would start at 10:00 a.m. UTC.The arrival and
          departure times and dates recorded in the output Stops feature class
          will refer to UTC.
      line_shape {String}:
          Specifies the shape type for the route features that are output by the
          analysis.

          * ALONG_NETWORK-The output routes will have the exact shape of the
          underlying network sources. Furthermore, the output includes route
          measurements for linear referencing. The measurements increase from
          the first stop and record the cumulative impedance to reach a given
          position.

          * NO_LINES-No shape will be generated for the output routes.

          * STRAIGHT_LINES-The output route shape will be a single straight line
          between the stops.
          No matter which output shape type is chosen, the best route is always
          determined by the network impedance, never Euclidean distance. This
          means only the route shapes are different, not the underlying
          traversal of the network.
      accumulate_attributes {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulated attributes are purely for reference; the solver only uses
          the cost attribute used by your designated travel mode when solving
          your analysis.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is populated in the network analysis output features.This
          parameter is not available if the network data source is a
          service."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeRouteAnalysisLayer_na(*gp_fixargs((network_data_source, layer_name, travel_mode, sequence, time_of_day, time_zone, line_shape, accumulate_attributes), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeRouteLayer_na', None)
def MakeRouteLayer(in_network_dataset=None, out_network_analysis_layer=None, impedance_attribute=None, find_best_order=None, ordering_type=None, time_windows=None, accumulate_attribute_name=None, UTurn_policy=None, restriction_attribute_name=None, hierarchy=None, hierarchy_settings=None, output_path_shape=None, start_date_time=None):
    """MakeRouteLayer_na(in_network_dataset, out_network_analysis_layer, impedance_attribute, {find_best_order}, {ordering_type}, {time_windows}, {accumulate_attribute_name;accumulate_attribute_name...}, {UTurn_policy}, {restriction_attribute_name;restriction_attribute_name...}, {hierarchy}, {hierarchy_settings}, {output_path_shape}, {start_date_time})

        Makes a route network analysis layer and sets its analysis properties.
        A route analysis layer is useful for determining the best route
        between a set of network locations based on a specified network
        cost.This is a deprecated tool. This functionality has been replaced
        by the
        Make Route Analysis Layer tool.

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset on which the route analysis will be performed.
      out_network_analysis_layer (String):
          Name of the route network analysis layer to create.
      impedance_attribute (String):
          The cost attribute to be used as impedance in the analysis.
      find_best_order {Boolean}:
          * FIND_BEST_ORDER-The stops will be reordered to find the optimal
          route. This option changes the route analysis from a shortest-path
          problem to a traveling salesperson problem (TSP).

          * USE_INPUT_ORDER-The stops will be visited in the input order. This
          is the default.
      ordering_type {String}:
          Specifies the ordering of stops when FIND_BEST_ORDER is used.

          * PRESERVE_BOTH-Preserves the first and last stops by input order as
          the first and last stops in the route.

          * PRESERVE_FIRST-Preserves the first stop by input order as the first
          stop in the route, but the last stop is free to be reordered.

          * PRESERVE_LAST-Preserves the last stop by input order as the last
          stop in the route, but the first stop is free to be reordered.

          * PRESERVE_NONE-Frees both the first and last stop to be reordered.
      time_windows {Boolean}:
          Specifies whether time windows will be used at the stops.

          * USE_TIMEWINDOWS-The route will consider time windows on the stops.
          If a stop is arrived at before its time window, there will be wait
          time until the time window starts. If a stop is arrived at after its
          time window, there will be a time window violation. Total time window
          violation is balanced against minimum impedance when computing the
          route. This is a valid option only when the impedance is in time
          units.

          * NO_TIMEWINDOWS-The route will ignore time windows on the stops. This
          is the default.
      accumulate_attribute_name {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulation attributes are purely for reference; the solver only uses
          the cost attribute specified by the Impedance Attribute parameter to
          calculate the route.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is added to the routes that are output by the solver.
      UTurn_policy {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges connect to the junction,
          which is known as junction valency. The acceptable values for this
          parameter are listed below; each is followed by a description of its
          meaning in terms of junction valency.

          * ALLOW_UTURNS-U-turns are permitted at junctions with any number of
          connected edges. This is the default value.

          * NO_UTURNS-U-turns are prohibited at all junctions, regardless of
          junction valency. Note, however, that U-turns are still permitted at
          network locations even when this setting is chosen; however, you can
          set the individual network locations' CurbApproach property to
          prohibit U-turns there as well.

          * ALLOW_DEAD_ENDS_ONLY-U-turns are prohibited at all junctions, except
          those that have only one adjacent edge (a dead end).

          * ALLOW_DEAD_ENDS_AND_INTERSECTIONS_ONLY-U-turns are prohibited at
          junctions where exactly two adjacent edges meet but are permitted at
          intersections (junctions with three or more adjacent edges) and dead
          ends (junctions with exactly one adjacent edge). Often, networks have
          extraneous junctions in the middle of road segments. This option
          prevents vehicles from making U-turns at these locations.
          If you need a more precisely defined U-turn policy, consider adding a
          global turn delay evaluator to a network cost attribute, or adjusting
          its settings if one exists, and pay particular attention to the
          configuration of reverse turns. Also, look at setting the CurbApproach
          property of your network locations.
      restriction_attribute_name {String}:
          List of restriction attributes to apply during the analysis.
      hierarchy {Boolean}:
          * USE_HIERARCHY-Use the hierarchy attribute for the analysis. Using a
          hierarchy results in the solver preferring higher-order edges to
          lower-order edges. Hierarchical solves are faster, and they can be
          used to simulate the preference of a driver who chooses to travel on
          freeways over local roads when possible-even if that means a longer
          trip. This option is valid only if the input network dataset has a
          hierarchy attribute.

          * NO_HIERARCHY-Do not use the hierarchy attribute for the analysis.
          Not using a hierarchy yields an exact route for the network dataset.
          The parameter is not used if a hierarchy attribute is not defined on
          the network dataset used to perform the analysis. In such cases, use
          "#" as the parameter value.
      hierarchy_settings {Network Analyst Hierarchy Settings}:
          Prior to version 10, this parameter allowed you to change the
          hierarchy ranges for your analysis from the default hierarchy ranges
          established in the network dataset. At version 10, this parameter is
          no longer supported and should be specified as an empty string. If you
          wish to change the hierarchy ranges for your analysis, update the
          default hierarchy ranges in the network dataset.
      output_path_shape {String}:
          Specifies the shape type for the route features that are output by the
          analysis.

          * TRUE_LINES_WITH_MEASURES-The output routes will have the exact shape
          of the underlying network sources. Furthermore, the output includes
          route measurements for linear referencing. The measurements increase
          from the first stop and record the cumulative impedance to reach a
          given position.

          * TRUE_LINES_WITHOUT_MEASURES-The output routes will have the exact
          shape of the underlying network sources.

          * STRAIGHT_LINES-The output route shape will be a single straight line
          between the stops.

          * NO_LINES-No shape will be generated for the output routes.
          No matter which output shape type is chosen, the best route is always
          determined by the network impedance, never Euclidean distance. This
          means only the route shapes are different, not the underlying
          traversal of the network.
      start_date_time {Date}:
          Specifies a start date and time for the route. Route start time is
          mostly used to find routes based on the impedance attribute that
          varies with the time of the day. For example, a start time of 7 a.m.
          could be used to find a route that considers the rush hour traffic.
          The default value for this parameter is 8:00 a.m. A date and time can
          be specified as 10/21/05 10:30 AM. If the route spans multiple days,
          and only the start time is specified, then the current date is used.
          Instead of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM. After the
          solve, the start and end time of the route are populated in
          the output routes. These start and end times are also used when
          directions are generated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeRouteLayer_na(*gp_fixargs((in_network_dataset, out_network_analysis_layer, impedance_attribute, find_best_order, ordering_type, time_windows, accumulate_attribute_name, UTurn_policy, restriction_attribute_name, hierarchy, hierarchy_settings, output_path_shape, start_date_time), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeServiceAreaAnalysisLayer_na', None)
def MakeServiceAreaAnalysisLayer(network_data_source=None, layer_name=None, travel_mode=None, travel_direction=None, cutoffs=None, time_of_day=None, time_zone=None, output_type=None, polygon_detail=None, geometry_at_overlaps=None, geometry_at_cutoffs=None, polygon_trim_distance=None, exclude_sources_from_polygon_generation=None, accumulate_attributes=None):
    """MakeServiceAreaAnalysisLayer_na(network_data_source, {layer_name}, {travel_mode}, {travel_direction}, {cutoffs;cutoffs...}, {time_of_day}, {time_zone}, {output_type}, {polygon_detail}, {geometry_at_overlaps}, {geometry_at_cutoffs}, {polygon_trim_distance}, {exclude_sources_from_polygon_generation;exclude_sources_from_polygon_generation...}, {accumulate_attributes;accumulate_attributes...})

        Makes a service area network analysis layer and sets its analysis
        properties. A service area analysis layer is useful in determining the
        area of accessibility within a given cutoff cost from a facility
        location. The layer can be created using a local network dataset or
        using a routing service hosted online or in a portal.

     INPUTS:
      network_data_source (Network Dataset Layer / String):
          The network dataset or service on which the network analysis will be
          performed. Use the portal URL for a service.
      layer_name {String}:
          Name of the network analysis layer to create.
      travel_mode {String}:
          Name of the travel mode to use in the analysis. The travel mode
          represents a collection of network settings, such as travel
          restrictions and U-turn policies, that determine how a pedestrian,
          car, truck, or other medium of transportation moves through the
          network. Travel modes are defined on your network data source.
      travel_direction {String}:
          Specifies the direction of travel to or from the facilities.

          * FROM_FACILITIES-The service area represents traveling away from the
          facilities. This is the default.

          * TO_FACILITIES-The service area represents traveling towards the
          facilities.
          Using this option can result in different service areas on a network
          with one-way restrictions and having different impedances based on
          direction of travel. The service area for a pizza delivery store, for
          example, should be created away from the facility, whereas the service
          area of a hospital should be created toward the facility.
      cutoffs {Double}:
          The extent of the service area to be calculated in the units of the
          impedance attribute used by your selected travel mode. For example,
          when analyzing driving time, a cutoff value of 10 means that the
          resulting service area will represent the area reachable within a
          10-minute drive time.Multiple cutoffs can be set in order to create
          concentric service
          areas. For instance, to find 2-, 3-, and 5-minute service areas for
          the same facility, specify 2, 3, and 5 as the values for this
          parameter.This default cutoff value can be overridden on a per-
          facility basis by
          specifying individual break values in the facilities sublayer.
      time_of_day {Date}:
          The time to depart from or arrive at the facilities of the service
          area layer. The interpretation of this value as a departure or arrival
          time depends on whether travel is away from or toward the facilities.

          * It represents the departure time if
          travel_direction='FROM_FACILITIES' .

          * It represents the arrival time if travel_direction='TO_FACILITIES'.
           The time_of_day parameter is most useful for finding the roads that
          can be reached based on a travel_mode that uses an impedance attribute
          that varies with the time of the day, such as one based on dynamic
          traffic conditions. Solving the same analysis using different
          time_of_day values allows you to see how a facility's reach changes
          over time. For instance, the five-minute service area around a fire
          station may start out large in the early morning, diminish during the
          morning rush hour, grow in the late morning, and so on throughout the
          day.A date and time can be specified as 10/21/2015 10:30 AM. Instead
          of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM.
      time_zone {String}:
          Specifies the time zone of the time of day parameter.

          * LOCAL_TIME_AT_LOCATIONS-The time of day parameter refers to the time
          zone or zones in which the facilities are located. Therefore, the
          start or end times of the service areas are staggered by time zone.
          This is the default.For example, setting time of day to 9:00 a.m.
          causes service areas to be generated for 9:00 a.m. Eastern Time for
          any facilities in the Eastern Time Zone, 9:00 a.m. Central Time for
          facilities in the Central Time Zone, 9:00 a.m. Mountain Time for
          facilities in the Mountain Time Zone, and so on. If stores in a chain
          that span the U.S. open at 9:00 a.m. local time, this parameter value
          could be chosen to find market territories at opening time for all
          stores in one solve. First, the stores in the Eastern Time Zone open
          and a polygon is generated, then an hour later, stores open in Central
          Time, and so on. Nine o'clock is always in local time but staggered in
          real time.

          * UTC-The time of day parameter refers to Coordinated Universal Time
          (UTC). Therefore, all facilities are reached or departed from
          simultaneously, regardless of the time zone or zones they are
          in.Setting time of day to 2:00 p.m. causes service areas to be
          generated for 9:00 a.m. Eastern Standard Time for any facilities in
          the Eastern Time Zone, 8:00 a.m. Central Standard Time for facilities
          in the Central Time Zone, 7:00 a.m. Mountain Standard Time for
          facilities in the Mountain Time Zone, and so on. The scenario above
          assumes standard time. During daylight saving time,
          the Eastern, Central, and Mountain Times would each be one hour ahead
          (that is, 10:00, 9:00, and 8:00 a.m., respectively). One of the cases
          in which the UTC option is useful is to visualize emergency response
          coverage for a jurisdiction that is split into two time zones. The
          emergency vehicles are loaded as facilities. Time of day is set to now
          in UTC. (You need to determine what the current time and date are in
          terms of UTC to correctly use this option.) Other properties are set
          and the analysis is solved. Even though a time-zone boundary divides
          the vehicles, the results show areas that can be reached given current
          traffic conditions. This same process can be used for other times as
          well, not just for now.
      output_type {String}:
          Specifies the type of output to be generated. Service area output can
          be line features representing the roads reachable before the cutoffs
          are exceeded or the polygon features encompassing these lines
          (representing the reachable area).

          * POLYGONS-The service area output will contain polygons only. This is
          the default. This is the only choice if the network data source is a
          service.

          * LINES-The service area output will contain lines only.

          * POLYGONS_AND_LINES-The service area output will contain both
          polygons and lines.
      polygon_detail {String}:
          Specifies the level of detail of the output polygons.

          * STANDARD-Creates polygons with a standard level of detail. This is
          the default.

          * GENERALIZED-Creates generalized polygons using the hierarchy present
          in the network data source in order to produce results quickly.

          * HIGH-Creates polygons with a higher level of detail for applications
          in which very precise results are important.
          If your analysis covers an urban area with a grid-like street network,
          the difference between generalized and standard polygons will be
          minimal. However, for mountain and rural roads, the standard and
          detailed polygons may present significantly more accurate results than
          generalized polygons,
      geometry_at_overlaps {String}:
          Specifies the behavior of service-area output from multiple
          facilities in relation to one another.

          * OVERLAP-Creates individual polygons or sets of lines for each
          facility. The polygons or lines can overlap each other. This is the
          default.

          * DISSOLVE-Joins the polygons of multiple facilities that have the
          same cutoff value into a single polygon. This setting does not apply
          to line output.

          * SPLIT-Area is assigned to the closest facility so polygons or lines
          do not overlap each other.
      geometry_at_cutoffs {String}:
          Specifies the behavior of service area output for a single facility
          when multiple cutoff values are specified. This parameter does not
          apply to line output.

          * RINGS-Each polygon includes only the area between consecutive cutoff
          values. It does not include the area between the facility and any
          smaller cutoffs. For instance, If you create 5- and 10-minute service
          areas, then the 5-minute service area polygon will include the area
          reachable in 0-5 minutes, and the 10-minute service area polygon will
          include the area reachable between 5 and 10 minutes. This is the
          default.

          * DISKS-Each polygon includes the area reachable from the facility up
          to the cutoff value, including the area reachable within smaller
          cutoff values. For instance, If you create 5- and 10-minute service
          areas, then the 10-minute service area polygon will include the area
          under the 5-minute service area polygon.
      polygon_trim_distance {Linear Unit}:
          Specifies the service area polygon trim distance. The polygon trim
          refers to the distance from the road the service area polygon should
          extend when no other reachable roads are nearby, similar to a line
          buffer size. This is useful if the network is very sparse and you
          don't want the service area to cover large areas where there are no
          features. The parameter includes a value and units for the distance.
          The
          default value is 100 meters.
      exclude_sources_from_polygon_generation {String}:
          Specifies the list of network sources to be excluded when generating
          the polygons. The geometry of traversed elements from the excluded
          sources will be omitted from all polygons.This is useful if you have
          some network sources that you don't want to
          be included in the polygon generation because they create less
          accurate polygons or are inconsequential for the service area
          analysis. For example, while creating a walk-time service area in a
          multimodal network that includes streets and metro lines, you should
          choose to exclude the metro lines from polygon generation. Although
          the traveler can use the metro lines, they cannot stop partway along a
          metro line and enter a nearby building. Instead, they must travel the
          full length of the metro line, exit the metro system at a station, and
          then use the streets to walk to the building. It would be inaccurate
          to generate a polygon feature around a metro line.Excluding a network
          source from service area polygons does not prevent
          those sources from being traversed. Excluding sources from service
          area polygons only influences the polygon shape of the service areas.
          If you want to prevent traversal of a given network source, you must
          create an appropriate restriction when defining your network
          dataset.This parameter is not available if the network data source is
          a
          service.
      accumulate_attributes {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulated attributes are purely for reference; the solver only uses
          the cost attribute used by your designated travel mode when solving
          your analysis.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is populated in the network analysis output features.This
          parameter is not available if the network data source is a
          service."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeServiceAreaAnalysisLayer_na(*gp_fixargs((network_data_source, layer_name, travel_mode, travel_direction, cutoffs, time_of_day, time_zone, output_type, polygon_detail, geometry_at_overlaps, geometry_at_cutoffs, polygon_trim_distance, exclude_sources_from_polygon_generation, accumulate_attributes), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('MakeServiceAreaLayer_na', None)
def MakeServiceAreaLayer(in_network_dataset=None, out_network_analysis_layer=None, impedance_attribute=None, travel_from_to=None, default_break_values=None, polygon_type=None, merge=None, nesting_type=None, line_type=None, overlap=None, split=None, excluded_source_name=None, accumulate_attribute_name=None, UTurn_policy=None, restriction_attribute_name=None, polygon_trim=None, poly_trim_value=None, lines_source_fields=None, hierarchy=None, time_of_day=None):
    """MakeServiceAreaLayer_na(in_network_dataset, out_network_analysis_layer, impedance_attribute, {travel_from_to}, {default_break_values}, {polygon_type}, {merge}, {nesting_type}, {line_type}, {overlap}, {split}, {excluded_source_name;excluded_source_name...}, {accumulate_attribute_name;accumulate_attribute_name...}, {UTurn_policy}, {restriction_attribute_name;restriction_attribute_name...}, {polygon_trim}, {poly_trim_value}, {lines_source_fields}, {hierarchy}, {time_of_day})

        Makes a service area network analysis layer and sets its analysis
        properties. A service area analysis layer is useful in determining the
        area of accessibility within a given cutoff cost from a facility
        location.This is a deprecated tool. This functionality has been
        replaced by the
        Make Service Area Analysis Layer tool.

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset on which the service area analysis will be
          performed.
      out_network_analysis_layer (String):
          Name of the service area network analysis layer to create.
      impedance_attribute (String):
          The cost attribute to be used as impedance in the analysis.
      travel_from_to {String}:
          Specifies the direction of travel to or from the facilities.

          * TRAVEL_FROM-The service area is created in the direction away from
          the facilities.

          * TRAVEL_TO-The service area is created in the direction towards the
          facilities.
           Using this option can result in different service areas on a network
          with one-way restrictions and having different impedances based on
          direction of travel. The service area for a pizza delivery store, for
          example, should be created away from the facility, whereas the service
          area of a hospital should be created toward the facility.
      default_break_values {String}:
          Default impedance values indicating the extent of the service area to
          be calculated. The default can be overridden by specifying the break
          value on the facilities.Multiple polygon breaks can be set to create
          concentric service areas.
          For instance, to find 2-, 3-, and 5-minute service areas for the same
          facility, specify "2 3 5" as the value for the Default break values
          parameter (the numbers 2, 3, and 5 should be separated by a space).
      polygon_type {String}:
          Specifies the type of polygons to be generated.

          * SIMPLE_POLYS-Creates generalized polygons, which are generated
          quickly and are fairly accurate, except on the fringes. This is the
          default.

          * DETAILED_POLYS-Creates detailed polygons, which accurately model the
          service area lines and may contain islands of unreached areas. This
          option is slower than generating generalized polygons.

          * NO_POLYS-Turns off polygon generation for the case in which only
          service area lines are desired.
          If your data is of an urban area with a gridlike network, the
          difference between generalized and detailed polygons would be minimal.
          However, for mountain and rural roads, the detailed polygons may
          present significantly more accurate results than generalized polygons.
      merge {String}:
          Specifies the options to merge polygons that share similar break
          values. This option is applicable only when generating polygons for
          multiple facilities.

          * NO_MERGE-Creates individual polygons for each facility. The polygons
          can overlap each other.

          * NO_OVERLAP-Creates individual polygons that are closest for each
          facility. The polygons do not overlap each other.

          * MERGE-Joins the polygons of multiple facilities that have the same
          break value.
      nesting_type {String}:
          Specifies the option to create concentric service area polygons as
          disks or rings. This option is applicable only when multiple break
          values are specified for the facilities.

          * RINGS-Do not include the area of the smaller breaks. This creates
          polygons going between consecutive breaks. Use this option if you want
          to find the area from one break to another.

          * DISKS-Creates the polygons going from the facility to the break.
          For instance, If you create 5- and 10-minute service areas, then the
          10-minute service area polygon will include the area under the
          5-minute service area polygon. Use this option if you want to find the
          entire area from the facility to the break for each break.
      line_type {String}:
          Specifies the type of lines to be generated based on the service area
          analysis. Selecting the TRUE_LINES or TRUE_LINES_WITH_MEASURES option
          for large service areas will increase the amount of memory consumed by
          the analysis.

          * NO_LINES-Do not generate lines. This is the default.

          * TRUE_LINES-Lines are generated without measures.

          * TRUE_LINES_WITH_MEASURES-Lines are generated with measures. The
          measure values are generated based on the impedance value on each end
          of the edge with the intermediate vertices interpolated. Do not use
          this option if faster performance is desired.
      overlap {Boolean}:
          Determines if overlapping lines are generated when the service area
          lines are computed.

          * OVERLAP-Include a separate line feature for each facility when the
          facilities have service area lines that are coincident.

          * NON_OVERLAP-Include each service area line at most once and
          associate it with its closest (least impedance) facility.
      split {Boolean}:
          * SPLIT-Split every line between two breaks into two lines, each lying
          within its break. This is useful if you want to symbolize the service
          area lines by break. Otherwise, use the NO_SPLIT option for optimal
          performance.

          * NO_SPLIT-The lines are not split at the boundaries of the breaks.
          This is the default.
      excluded_source_name {String}:
          Specifies the list of network sources to be excluded when generating
          the polygons. The geometry of traversed elements from the excluded
          sources will be omitted from all polygons.This is useful if you have
          some network sources that you don't want to
          be included in the polygon generation because they create less
          accurate polygons or are inconsequential for the service area
          analysis. For example, while creating a drive time service area in a
          multimodal network of streets and rails, you should choose to exclude
          the rail lines from polygon generation so as to correctly model where
          a vehicle could travel.Excluding a network source from service area
          polygons does not prevent
          those sources from being traversed. Excluding sources from service
          area polygons only influences the polygon shape of the service areas.
          If you want to prevent traversal of a given network source, you must
          create an appropriate restriction when defining your network dataset.
      accumulate_attribute_name {String}:
          List of cost attributes to be accumulated during analysis. These
          accumulation attributes are purely for reference; the solver only uses
          the cost attribute specified by the Impedance Attribute parameter to
          calculate the route.For each cost attribute that is accumulated, a
          Total_[Impedance]
          property is added to the routes that are output by the solver.
      UTurn_policy {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges connect to the junction,
          which is known as junction valency. The acceptable values for this
          parameter are listed below; each is followed by a description of its
          meaning in terms of junction valency.

          * ALLOW_UTURNS-U-turns are permitted at junctions with any number of
          connected edges. This is the default value.

          * NO_UTURNS-U-turns are prohibited at all junctions, regardless of
          junction valency. Note, however, that U-turns are still permitted at
          network locations even when this setting is chosen; however, you can
          set the individual network locations' CurbApproach property to
          prohibit U-turns there as well.

          * ALLOW_DEAD_ENDS_ONLY-U-turns are prohibited at all junctions, except
          those that have only one adjacent edge (a dead end).

          * ALLOW_DEAD_ENDS_AND_INTERSECTIONS_ONLY-U-turns are prohibited at
          junctions where exactly two adjacent edges meet but are permitted at
          intersections (junctions with three or more adjacent edges) and dead
          ends (junctions with exactly one adjacent edge). Often, networks have
          extraneous junctions in the middle of road segments. This option
          prevents vehicles from making U-turns at these locations.
          If you need a more precisely defined U-turn policy, consider adding a
          global turn delay evaluator to a network cost attribute, or adjusting
          its settings if one exists, and pay particular attention to the
          configuration of reverse turns. Also, look at setting the CurbApproach
          property of your network locations.
      restriction_attribute_name {String}:
          List of restriction attributes to apply during the analysis.
      polygon_trim {Boolean}:
          * TRIM_POLYS-Trims the polygons containing the edges at the periphery
          of the service area to be within the specified distance of these outer
          edges. This is useful if the network is very sparse and you don't want
          the service area to cover large areas where there are no features.

          * NO_TRIM_POLYS-Do not trim polygons.
      poly_trim_value {Linear Unit}:
          Specifies the distance within which the service area polygons are
          trimmed. The parameter includes a value and units for the distance.
          The default value is 100 meters.
      lines_source_fields {Boolean}:
          * LINES_SOURCE_FIELDS-Add the SourceID, SourceOID, FromPosition, and
          ToPosition fields to the service area lines to hold information about
          the underlying source features traversed during the analysis. This can
          be useful to join the results of the service area lines to the
          original source data.

          * NO_LINES_SOURCE_FIELDS-Do not add the source fields (SourceID,
          SourceOID, FromPosition, and ToPosition) to the service area lines.
      hierarchy {Boolean}:
          * USE_HIERARCHY-Use the hierarchy attribute for the analysis. Using a
          hierarchy results in the solver preferring higher-order edges to
          lower-order edges. Hierarchical solves are faster, and they can be
          used to simulate the preference of a driver who chooses to travel on
          freeways over local roads when possible-even if that means a longer
          trip. This option is valid only if the input network dataset has a
          hierarchy attribute.

          * NO_HIERARCHY-Do not use the hierarchy attribute for the analysis.
          Not using a hierarchy yields a service area measured along all edges
          of the network dataset regardless of hierarchy level.
          The parameter is not used if a hierarchy attribute is not defined on
          the network dataset used to perform the analysis. In such cases, use
          "#" as the parameter value.
      time_of_day {Date}:
          The time to depart from or arrive at the facilities of the service
          area layer. The interpretation of this value as a depart or arrive
          time depends on whether travel is away from or toward the facilities.

          * It represents the departure time if Travel From or To Facility is
          set to TRAVEL_FROM.

          * It represents the arrival time if Travel From or To Facility is set
          to TRAVEL_TO.
          If you have chosen a traffic-based impedance attribute, the solution
          will be generated given dynamic traffic conditions at the time of day
          specified here. A date and time can be specified as 5/14/2012 10:30
          AM. Instead of using a particular date, a day of the week can be
          specified using the following dates.

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM.Repeatedly
          solving the same analysis, but using different Time of Day
          values, allows you to see how a facility's reach changes over time.
          For instance, the five-minute service area around a fire station may
          start out large in the early morning, diminish during the morning rush
          hour, grow in the late morning, and so on throughout the day."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeServiceAreaLayer_na(*gp_fixargs((in_network_dataset, out_network_analysis_layer, impedance_attribute, travel_from_to, default_break_values, polygon_type, merge, nesting_type, line_type, overlap, split, excluded_source_name, accumulate_attribute_name, UTurn_policy, restriction_attribute_name, polygon_trim, poly_trim_value, lines_source_fields, hierarchy, time_of_day), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('Solve_na', None)
def Solve(in_network_analysis_layer=None, ignore_invalids=None, terminate_on_solve_error=None, simplification_tolerance=None, overrides=None):
    """Solve_na(in_network_analysis_layer, {ignore_invalids}, {terminate_on_solve_error}, {simplification_tolerance}, {overrides})

        Solves the network analysis layer problem based on its network
        locations and properties.

     INPUTS:
      in_network_analysis_layer (Network Analyst Layer):
          The network analysis layer on which the analysis will be computed.
      ignore_invalids {Boolean}:
          * SKIP-The solver will skip over network locations that are unlocated
          and solve the analysis layer from valid network locations only. It
          will also continue solving if locations are on nontraversable elements
          or have other errors. This is useful if you know your network
          locations are not all correct, but you want to solve with the network
          locations that are valid.

          * HALT-Do not solve if there are invalid locations. You can then
          correct these and rerun the analysis.
      terminate_on_solve_error {Boolean}:
          * TERMINATE-The tool will fail to execute when the solver encounters
          an error. This is the default. When you use this option, the Result
          object is not created when the tool fails to execute due to a solver
          error. You should obtain the geoprocessing messages from the ArcPy
          object.

          * CONTINUE-The tool will not fail and continue execution even when the
          solver encounters an error. All of the error messages returned by the
          solver will be converted to warning messages. When you use this
          option, the Result object is always created and the maxSeverity
          property of the Result object is set to 1 even when the solver
          encounters an error. Use the getOutput method of the Result object
          with an index value of 1 to determine if the solve was successful.
      simplification_tolerance {Linear Unit}:
          The tolerance that determines the degree of simplification for the
          output geometry. If a tolerance is specified, it must be greater than
          zero. You can choose a preferred unit; the default unit is decimal
          degrees.Specifying a simplification tolerance tends to reduce the time
          it
          takes to render routes or service areas. The drawback, however, is
          that simplifying geometry removes vertices, which may lessen the
          spatial accuracy of the output at larger scales.Because a line with
          only two vertices cannot be simplified any
          further, this parameter has no effect on drawing times for single-
          segment output, such as straight-line routes,  OD cost matrix lines,
          and location-allocation lines.
      overrides {String}:
          Specify additional settings that can influence the behavior of the
          solver when finding solutions for the network analysis problems. The
          value for this parameter needs to be specified in JavaScript
          Object Notation (JSON). For example, a valid value is of the following
          form {"overrideSetting1" : "value1", "overrideSetting2" : "value2"}.
          The override setting name is always enclosed in double quotation
          marks. The values can be either a number, Boolean, or a string. The
          default value for this parameter is no value, which indicates not
          to override any solver settings. Overrides are advanced settings that
          should be used only after
          careful analysis of the results obtained before and after applying the
          settings. A list of supported override settings for each solver and
          their acceptable values can be obtained by contacting Esri Technical
          Support."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Solve_na(*gp_fixargs((in_network_analysis_layer, ignore_invalids, terminate_on_solve_error, simplification_tolerance, overrides), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('SolveVehicleRoutingProblem_na', None)
def SolveVehicleRoutingProblem(orders=None, depots=None, routes=None, breaks=None, time_units=None, distance_units=None, network_dataset=None, output_workspace_location=None, output_unassigned_stops_name=None, output_stops_name=None, output_routes_name=None, output_directions_name=None, default_date=None, uturn_policy=None, time_window_factor=None, spatially_cluster_routes=None, route_zones=None, route_renewals=None, order_pairs=None, excess_transit_factor=None, point_barriers=None, line_barriers=None, polygon_barriers=None, time_attribute=None, distance_attribute=None, use_hierarchy_in_analysis=None, restrictions=None, attribute_parameter_values=None, maximum_snap_tolerance=None, exclude_restricted_portions_of_the_network=None, feature_locator_where_clause=None, populate_route_lines=None, route_line_simplification_tolerance=None, populate_directions=None, directions_language=None, directions_style_name=None, save_output_layer=None, service_capabilities=None, ignore_invalid_order_locations=None, travel_mode=None, ignore_network_location_fields=None, time_zone_usage_for_time_fields=None, overrides=None, save_route_data=None):
    """SolveVehicleRoutingProblem_na(orders, depots, routes, breaks, time_units, distance_units, network_dataset, output_workspace_location, output_unassigned_stops_name, output_stops_name, output_routes_name, output_directions_name, {default_date}, {uturn_policy}, {time_window_factor}, {spatially_cluster_routes}, {route_zones}, {route_renewals}, {order_pairs}, {excess_transit_factor}, {point_barriers}, {line_barriers}, {polygon_barriers}, {time_attribute}, {distance_attribute}, {use_hierarchy_in_analysis}, {restrictions;restrictions...}, {attribute_parameter_values}, {maximum_snap_tolerance}, {exclude_restricted_portions_of_the_network}, {feature_locator_where_clause;feature_locator_where_clause...}, {populate_route_lines}, {route_line_simplification_tolerance}, {populate_directions}, {directions_language}, {directions_style_name}, {save_output_layer}, {service_capabilities;service_capabilities...}, {ignore_invalid_order_locations}, {travel_mode}, {ignore_network_location_fields}, {time_zone_usage_for_time_fields}, {overrides}, {save_route_data})

        Creates a vehicle routing problem (VRP) network analysis layer, sets
        the analysis properties, and solves the analysis, which is ideal for
        setting up a VRP web service. A vehicle routing problem analysis layer
        finds the best routes for a fleet of vehicles.

     INPUTS:
      orders (Feature Set):
          The orders that the routes of the VRP analysis should visit. An order
          can represent a delivery (for example, furniture delivery), a pickup
          (such as an airport shuttle bus picking up a passenger), or some type
          of service or inspection (a tree trimming job or building inspection,
          for instance).The orders feature set has an associated attribute
          table. The fields
          in the attribute table are listed below and described. ObjectID:The
          system-managed ID field. Shape:The geometry field indicating the
          geographic location of the network
          analysis object. Name:The name of the order. The name must be unique.
          If the name is left
          null, a name is automatically generated at solve time. ServiceTime:
          This property specifies how much time will be spent at the network
          location when the route visits it; that is, it stores the impedance
          value for the network location. A zero or null value indicates the
          network location requires no service time.The unit for this field
          value is specified by the Time Field Units
          parameter (time_units in Python). TimeWindowStart1:The beginning time
          of the first time window for the network location.
          This field can contain a null value; a null value indicates no
          beginning time.

          *  A time window only states when a vehicle can arrive at an order; it
          doesn't state when the service time must be completed. To account for
          service time and leave before the time window is over, subtract
          ServiceTime from the TimeWindowEnd1 field.

          *  The time window fields can contain a time-only value or a date and
          time value. If a time field such as TimeWindowStart1 has a time-only
          value (for example, 8:00 AM), the date is assumed to be the date
          specified by the Default Date property of the analysis layer. Using
          date and time values (for example, 7/11/2010 8:00 AM) allows you to
          set time windows that span multiple days.

          * The default date is ignored when any time window field includes a
          date
          with the time. To avoid an error in this situation, format all time
          windows in Depots, Routes, Orders, and Breaks to also include the date
          with the time.

          *  If you're using traffic data, the time-of-day fields for the
          network
          location always reference the same time zone as the edge on which the
          network location is located.
           TimeWindowEnd1: The ending time of the first window for the network
          location. This
          field can contain a null value; a null value indicates no ending time.
          TimeWindowStart2:The beginning time of the second time window for the
          network location.
          This field can contain a null value; a null value indicates that there
          is no second time window.If the first time window is null as specified
          by the TimeWindowStart1
          and TimeWindowEnd1 fields, the second time window must also be null.If
          both time windows are nonnull, they can't overlap. Also, the second
          time window must occur after the first. TimeWindowEnd2: The ending
          time of the second time window for the network location.
          This field can contain a null value.When TimeWindowStart2 and
          TimeWindowEnd2 are both null, there is no
          second time window.When TimeWindowStart2 is not null but
          TimeWindowEnd2 is null, there is
          a second time window that has a starting time but no ending time. This
          is valid. MaxViolationTime1: A time window is considered violated if
          the arrival time occurs after
          the time window has ended. This field specifies the maximum allowable
          violation time for the first time window of the order. It can contain
          a zero value but can't contain negative values. A zero value indicates
          that a time window violation at the first time window of the order is
          unacceptable; that is, the first time window is hard. On the other
          hand, a null value indicates that there is no limit on the allowable
          violation time. A nonzero value specifies the maximum amount of
          lateness; for example, a route can arrive at an order up to 30 minutes
          beyond the end of its first time window.The unit for this field value
          is specified by the Time Field Units
          parameter (time_units in Python).Time window violations can be tracked
          and weighted by the solver.
          Because of this, you can direct the VRP solver to take one of three
          approaches:

          * Minimize the overall violation time, regardless of the increase in
          travel cost for the fleet.

          * Find a solution that balances overall violation time and travel
          cost.

          * Ignore the overall violation time; instead, minimize the travel cost
          for the fleet.
          By assigning an importance level for the Time Window Violation
          Importance parameter (time_window_factor for Python), you are
          essentially choosing one of these three approaches. In any case,
          however, the solver will return an error if the value set for
          MaxViolationTime1 is surpassed. MaxViolationTime2: The maximum
          allowable violation time for the second time window of
          the order. This field is analogous to the MaxViolationTime1
          field.InboundArriveTime:Defines when the item to be delivered to the
          order will be ready at
          the starting depot.The order can be assigned to a route only if the
          inbound arrive time
          precedes the route's latest start time value; this way, the route
          cannot leave the depot before the item is ready to be loaded onto
          it.This field can help model scenarios involving inbound-wave
          transshipments. For example, a job at an order requires special
          materials that are not currently available at the depot. The materials
          are being shipped from another location and will arrive at the depot
          at 11:00 a.m. To ensure a route that leaves before the shipment
          arrives isn't assigned to the order, the order's inbound arrive time
          is set to 11:00 a.m. The special materials arrive at 11:00 a.m., they
          are loaded onto the vehicle, and the vehicle departs from the depot to
          visit its assigned orders.

          * The route's start time, which includes service times, must occur
          after
          the inbound arrive time. If a route begins before an order's inbound
          arrive time, the order cannot be assigned to the route. The assignment
          is invalid even if the route has a start-depot service time that lasts
          until after the inbound arrive time.

          * This time field can contain a time-only value or a date and time
          value. If a time-only value is set (for example, 11:00 AM), the date
          is assumed to be the date specified by the Default Date property of
          the analysis layer. The default date is ignored, however, when any
          time field in Depots, Routes, Orders, or Breaks includes a date with
          the time. In that case, specify all such fields with a date and time
          (for example, 7/11/2015 11:00 AM).

          * The VRP solver honors InboundArriveTime regardless of the
          DeliveryQuantities value.

          * If an outbound depart time is also specified, its time value must
          occur after the inbound arrive time.
          OutboundDepartTime:Defines when the item to be picked up at the order
          must arrive at the
          ending depot.The order can be assigned to a route only if the route
          can visit the
          order and reach its end depot before the specified outbound depart
          time.This field can help model scenarios involving outbound-wave
          transshipments. For instance, a shipping company sends out delivery
          trucks to pick up packages from orders and bring them into a depot
          where they are forwarded on to other facilities, en route to their
          final destination. At 3:00 p.m. every day, a semitrailer stops at the
          depot to pick up the high-priority packages and take them directly to
          a central processing station. To avoid delaying the high-priority
          packages until the next day's 3:00 p.m. trip, the shipping company
          tries to have delivery trucks pick up the high-priority packages from
          orders and bring them to the depot before the 3:00 p.m. deadline. This
          is done by setting the outbound depart time to 3:00 p.m.

          * The route's end time, including service times, must occur before the
          outbound depart time. If a route reaches a depot but doesn't complete
          its end-depot service time prior to the order's outbound depart time,
          the order cannot be assigned to the route.

          * This time field can contain a time-only value or a date and time
          value. If a time-only value is set (for example, 11:00 AM), the date
          is assumed to be the date specified by the Default Date property of
          the analysis layer. The default date is ignored, however, when any
          time field in Depots, Routes, Orders, or Breaks includes a date with
          the time. In that case, specify all such fields with a date and time
          (for example, 7/11/2015 11:00 AM).

          * The VRP solver honors OutboundDepartTime regardless of the
          PickupQuantities value.

          * If an inbound arrive time is also specified, its time value must
          occur
          before the outbound depart time.
           DeliveryQuantities:The size of the delivery. You can specify size in
          any dimension you
          want, such as weight, volume, or quantity. You can even specify
          multiple dimensions, for example, weight and volume.Enter delivery
          quantities without indicating units. For example, if a
          300-pound object needs to be delivered to an order, enter 300. You
          will need to remember that the value is in pounds.If you are tracking
          multiple dimensions, separate the numeric values
          with a space. For instance, if you are recording the weight and volume
          of a delivery that weighs 2,000 pounds and has a volume of 100 cubic
          feet, enter 2000 100. Again, you need to remember the units-in this
          case, pounds and cubic feet. You also need to remember the sequence in
          which the values and their corresponding units are entered.Make sure
          that Capacities for Routes and DeliveryQuantities and
          PickupQuantities for Orders are specified in the same manner; that is,
          the values need to be in the same units, and if you are using multiple
          dimensions, the dimensions need to be listed in the same sequence for
          all parameters. So if you specify weight in pounds, followed by volume
          in cubic feet for DeliveryQuantities, the capacity of your routes and
          the pickup quantities of your orders need to be specified the same
          way: weight in pounds, then volume in cubic feet. If you mix units or
          change the sequence, you will get unwanted results without receiving
          any warning messages.An empty string or null value is equivalent to
          all dimensions being
          zero. If the string has an insufficient number of values in relation
          to the capacity count, or dimensions being tracked, the remaining
          values are treated as zeros. Delivery quantities can't be negative.
          PickupQuantities:The size of the pickup. You can specify size in any
          dimension you
          want, such as weight, volume, or quantity. You can even specify
          multiple dimensions, for example, weight and volume. You cannot,
          however, use negative values. This field is analogous to the
          DeliveryQuantities field of Orders.In the case of an exchange visit,
          an order can have both delivery and pickup quantities.  Revenue:The
          income generated if the order is included in a solution. This
          field can contain a null value-a null value indicates zero revenue-but
          it can't have a negative value.Revenue is included in optimizing the
          objective function value but is
          not part of the solution's operating cost. That is, the TotalCost
          field in the route class never includes revenue in its output;
          however, revenue weights the relative importance of servicing orders.
          SpecialtyNames: A space-separated string containing the names of the
          specialties
          required by the order. A null value indicates that the order doesn't
          require specialties.The spelling of any specialties listed in the
          Orders and Routes
          classes must match exactly so the VRP solver can link them together.To
          illustrate what specialties are and how they work, assume a lawn
          care and tree trimming company has a portion of its orders that
          requires a bucket truck to trim tall trees. The company would enter
          BucketTruck in the SpecialtyNames field for these orders to indicate
          their special need. SpecialtyNames would be left as null for the other
          orders. Similarly, the company would also enter BucketTruck in the
          SpecialtyNames field of routes that are driven by trucks with
          hydraulic booms. It would leave the field null for the other routes.
          At solve time, the VRP solver assigns orders without special needs to
          any route, but it only assigns orders that need bucket trucks to
          routes that have them. AssignmentRule: This field specifies the rule
          for assigning the order to a route. It
          is constrained by a domain of values, which are listed below (their
          coded values are shown in parentheses).

          * Exclude  (0)-The order is to be excluded from the subsequent solve
          operation.

          * Preserve route and relative sequence  (1)-The solver must always
          assign the order to the preassigned route and at the preassigned
          relative sequence during the solve operation. If this assignment rule
          can't be followed, it results in an order violation. With this
          setting, only the relative sequence is maintained, not the
          absolute sequence. To illustrate what this means, imagine there are
          two orders: A and B. They have sequence values of 2 and 3,
          respectively. If you set their AssignmentRule field values to Preserve
          route and relative sequence, A's and B's actual sequence values may
          change after solving because other orders, breaks, and depot visits
          could still be sequenced before, between, or after A and B. However, B
          cannot be sequenced before A.

          * Preserve route  (2)-The solver must always assign the order to the
          preassigned route during the solve operation. A valid sequence must
          also be set even though the sequence may or may not be preserved. If
          the order can't be assigned to the specified route, it results in an
          order violation.

          * Override  (3)-The solver ignores the route and sequence
          preassignment (if any) for the order during the solve operation. It
          assigns a route and sequence to the order so as to minimize the
          overall value of the objective function. This is the default value.

          *  Anchor first  (4)-The solver ignores the route and sequence
          preassignment (if any) for the order during the solve operation. It
          assigns a route to the order, and makes it the first order on that
          route, so as to minimize the overall value of the objective function.

          *  Anchor last  (5)- The solver ignores the route and sequence
          preassignment (if any) for the order during the solve operation. It
          assigns a route to the order, and makes it the last order on that
          route, so as to minimize the overall value of the objective function.
          This field can't contain a null value. CurbApproach:The CurbApproach
          property specifies the direction a vehicle may arrive
          at and depart from the network location. There are four choices (their
          coded values are shown in parentheses):

          * Either side of vehicle  (0)-The vehicle can approach and depart the
          network location in either direction. U-turns are allowed. You should
          choose this setting if your vehicle can make a U-turn at the stop or
          if it can pull into a driveway or parking lot and turn around.

          * Right side of vehicle  (1)-When the vehicle approaches and departs
          the network location, the curb must be on the right side of the
          vehicle. A U-turn is prohibited.

          * Left side of vehicle  (2)-When the vehicle approaches and departs
          the network location, the curb must be on the left side of the
          vehicle. A U-turn is prohibited.

          * No U-Turn  (3)-When the vehicle approaches the network location, the
          curb can be on either side of the vehicle; however, the vehicle must
          depart without turning around.
           RouteName: The name of the route to which the order is assigned.As an
          input field, this field is used to preassign an order to a
          specific route. It can contain a null value, indicating that the order
          is not preassigned to any route, and the solver determines the best
          possible route assignment for the order. If this is set to null, the
          sequence field must also be set to null.After a solve operation, if
          the order is routed, the RouteName field
          contains the name of the route that the order is assigned to.
          Sequence: This indicates the sequence of the order on its assigned
          route.As an input field, this field is used to specify the relative
          sequence
          for an order on the route. This field can contain a null value
          specifying that the order can be placed anywhere along the route. A
          null value can only occur together with a null RouteName value. The
          input sequence values are non-negative and unique for each route
          (shared across depot visits, orders, and breaks), but do not need to
          start from 0 or be contiguous.After a solve operation, the Sequence
          field contains the sequence
          value of the order on its assigned route. Output sequence values for a
          route are shared across depot visits, orders, and breaks; start from 1
          (at the starting depot); and are consecutive. So the smallest possible
          output sequence value for a routed order is 2, since a route always
          begins at a depot.
      depots (Feature Set):
          A depot is a location that a vehicle departs from at the beginning of
          the workday and returns to at the end of the workday. Vehicles are
          loaded (for deliveries) or unloaded (for pickups) at depots at the
          start of the route. In some cases, a depot can also act as a renewal
          location whereby the vehicle can unload or reload and continue
          performing deliveries and pickups. A depot has open and close times,
          as specified by a hard time window. Vehicles can't arrive at a depot
          outside of this time window.The depots feature set has an associated
          attribute table. The fields
          in the attribute table are listed below and described. ObjectID:The
          system-managed ID field. Shape:The geometry field indicating the
          geographic location of the network
          analysis object. Name:The name of the depot. The StartDepotName and
          EndDepotName fields of
          the Routes record set reference the names you specify here. It is also
          referenced by the Route Renewals record set, when used. Depot names
          are case insensitive and have to be nonempty and unique.
          TimeWindowStart1:The beginning time of the first time window for the
          network location.
          This field can contain a null value; a null value indicates no
          beginning time.

          *  Time window fields can contain a time-only value or a date and time
          value. If a time field has a time-only value (for example, 8:00 AM),
          the date is assumed to be the date specified by the Default Date
          parameter of the analysis layer. Using date and time values (for
          example, 7/11/2010 8:00 a.m.) allows you to set time windows that span
          multiple days.

          * The default date is ignored when any time window field includes a
          date
          with the time. To avoid an error in this situation, format all time
          windows in Depots, Routes, Orders, and Breaks to also include the date
          with the time.

          *  If you're using traffic data, the time-of-day fields for the
          network
          location always reference the same time zone as the edge on which the
          network location is located.
           TimeWindowEnd1: The ending time of the first window for the network
          location. This
          field can contain a null value; a null value indicates no ending time.
          TimeWindowStart2:The beginning time of the second time window for the
          network location.
          This field can contain a null value; a null value indicates that there
          is no second time window.If the first time window is null as specified
          by the TimeWindowStart1
          and TimeWindowEnd1 fields, the second time window must also be null.If
          both time windows are nonnull, they can't overlap. Also, the second
          time window must occur after the first. TimeWindowEnd2: The ending
          time of the second time window for the network location.
          This field can contain a null value.When TimeWindowStart2 and
          TimeWindowEnd2 are both null, there is no
          second time window.When TimeWindowStart2 is not null but
          TimeWindowEnd2 is null, there is
          a second time window that has a starting time but no ending time. This
          is valid. CurbApproach:The CurbApproach property specifies the
          direction a vehicle may arrive
          at and depart from the network location. There are four choices (their
          coded values are shown in parentheses):

          * Either side of vehicle  (0)-The vehicle can approach and depart the
          network location in either direction. U-turns are allowed. You should
          choose this setting if your vehicle can make a U-turn at the stop or
          if it can pull into a driveway or parking lot and turn around.

          * Right side of vehicle  (1)-When the vehicle approaches and departs
          the network location, the curb must be on the right side of the
          vehicle. A U-turn is prohibited.

          * Left side of vehicle  (2)-When the vehicle approaches and departs
          the network location, the curb must be on the left side of the
          vehicle. A U-turn is prohibited.

          * No U-Turn  (3)-When the vehicle approaches the network location, the
          curb can be on either side of the vehicle; however, the vehicle must
          depart without turning around.
          Bearing:The direction in which a point is moving. The units are
          degrees and
          are measured in a clockwise fashion from true north. This field is
          used in conjunction with the BearingTol field.Bearing data is usually
          sent automatically from a mobile device that
          is equipped with a GPS receiver. Try to include bearing data if you
          are loading an order that is moving, such as a pedestrian or a
          vehicle.Using this field tends to prevent adding locations to the
          wrong edges,
          which can occur when a vehicle is near an intersection or an overpass,
          for example. Bearing also helps Network Analyst determine which side
          of the street the point is on.For more information, see Bearing and
          BearingTol.BearingTol:The bearing tolerance value creates a range of
          acceptable bearing
          values when locating moving points on an edge using the Bearing field.
          If the value from the Bearing field is within the range of acceptable
          values that are generated from the bearing tolerance on an edge, the
          point can be added as a network location there; otherwise, the closest
          point on the next-nearest edge is evaluated.The units are in degrees,
          and the default value is 30. Values must be
          greater than zero and less than 180.A value of 30 means that when
          Network Analyst attempts to add a
          network location on an edge, a range of acceptable bearing values is
          generated 15º to either side of the edge (left and right) and in both
          digitized directions of the edge.For more information, see Bearing and
          BearingTol.NavLatency:This field is only used in the solve process if
          Bearing and BearingTol
          also have values; however, entering a NavLatency value is optional,
          even when values are present in Bearing and BearingTol. NavLatency
          indicates how much time is expected to elapse from the moment GPS
          information is sent from a moving vehicle to a server and the moment
          the processed route is received by the vehicle's navigation device.
          The time units of NavLatency are the same as the units of the cost
          attribute specified by the Time Attribute parameter.
      routes (Record Set):
          The routes that are available for the given vehicle routing problem. A
          route specifies vehicle and driver characteristics; after solving, it
          also represents the path between depots and orders.A route can have
          start and end depot service times, a fixed or
          flexible starting time, time-based operating costs, distance-based
          operating costs, multiple capacities, various constraints on a
          driver's workday, and so on.The routes record set has several
          attributes. The fields in the
          attribute table are listed below and described. Name:The name of the
          route. The name must be unique.Network Analyst generates a unique name
          at solve time if the field
          value is null. Therefore, entering a value is optional in most cases.
          However, you must enter a name if your analysis includes breaks, route
          renewals, route zones, or orders that are preassigned to a route
          because the route name is used as a foreign key in these cases. Note
          that route names are case insensitive. StartDepotName: The name of the
          starting depot for the route. This field is a foreign
          key to the Name field in Depots.If the StartDepotName value is null,
          the route will begin from the
          first order assigned. Omitting the start depot is useful when the
          vehicle's starting location is unknown or irrelevant to your problem.
          However, when StartDepotName is null, EndDepotName cannot also be
          null.Virtual start depots are not allowed if orders or depots are in
          multiple time zones.If the route is making deliveries and
          StartDepotName is null, it is
          assumed the cargo is loaded on the vehicle at a virtual depot before
          the route begins. For a route that has no renewal visits, its delivery
          orders (those with nonzero DeliveryQuantities values in the Orders
          class) are loaded at the start depot or virtual depot. For a route
          that has renewal visits, only the delivery orders before the first
          renewal visit are loaded at the start depot or virtual depot.
          EndDepotName: The name of the ending depot for the route. This field
          is a foreign
          key to the Name field in the Depots class. StartDepotServiceTime: The
          service time at the starting depot. This can be used to model the
          time spent for loading the vehicle. This field can contain a null
          value; a null value indicates zero service time.The unit for this
          field value is specified by the Time Field Units
          parameter (time_units in Python).The service times at the start and
          end depots are fixed values (given
          by the StartDepotServiceTime and EndDepotServiceTime field values) and
          do not take into account the actual load for a route. For example, the
          time taken to load a vehicle at the starting depot may depend on the
          size of the orders. As such, the depot service times could be given
          values corresponding to a full truckload or an average truckload, or
          you could make your own time estimate. EndDepotServiceTime: The
          service time at the ending depot. This can be used to model the
          time spent for unloading the vehicle. This field can contain a null
          value; a null value indicates zero service time.The unit for this
          field value is specified by the Time Field Units
          parameter (time_units in Python).The service times at the start and
          end depots are fixed values (given
          by the StartDepotServiceTime and EndDepotServiceTime field values) and
          do not take into account the actual load for a route. For example, the
          time taken to load a vehicle at the starting depot may depend on the
          size of the orders. As such, the depot service times could be given
          values corresponding to a full truckload or an average truckload, or
          you could make your own time estimate. EarliestStartTime: The earliest
          allowable starting time for the route. This is used by
          the solver in conjunction with the time window of the starting depot
          for determining feasible route start times.This field can't contain
          null values and has a default time-only value
          of 8:00 a.m.; the default value is interpreted as 8:00 a.m. on the
          date given by the Default Date parameter (default_date for Python).The
          default date is ignored when any time window field includes a date
          with the time. To avoid an error in this situation, format all time
          windows in Depots, Routes, Orders, and Breaks to also include the date
          with the time.When using network datasets with traffic data across
          multiple time
          zones, the time zone for EarliestStartTime is the same as the time
          zone of the edge or junction on which the starting depot is located.
          LatestStartTime: The latest allowable starting time for the route.
          This field can't
          contain null values and has a default time-only value of 10:00 AM; the
          default value is interpreted as 10:00 a.m. on the date given by the
          Default Date property of the analysis layer.When using network
          datasets with traffic data across multiple time
          zones, the time zone for LatestStartTime is the same as the time zone
          of the edge or junction on which the starting depot is
          located.ArriveDepartDelayThis field stores the amount of travel time
          needed to accelerate the
          vehicle to normal travel speeds, decelerate it to a stop, and move it
          off and on the network (for example, in and out of parking). By
          including an ArriveDepartDelay value, the VRP solver is deterred from
          sending many routes to service physically coincident orders.The cost
          for this property is incurred between visits to noncoincident
          orders, depots, and route renewals. For example, when a route starts
          from a depot and visits the first order, the total arrive/depart delay
          is added to the travel time. The same is true when traveling from the
          first order to the second order. If the second and third orders are
          coincident, the ArriveDepartDelay value is not added between them
          since the vehicle doesn't need to move. If the route travels to a
          route renewal, the value is added to the travel time again.Although a
          vehicle needs to slow down and stop for a break and
          accelerate afterwards, the VRP solver cannot add the ArriveDepartDelay
          value for breaks. This means that if a route leaves an order, stops
          for a break, and continues to the next order, the arrive/depart delay
          is added only once, not twice.To illustrate, assume there are five
          coincident orders in a high-rise
          building, and they are serviced by three different routes. This means
          three arrive/depart delays would be incurred; that is, three drivers
          would need to separately find parking places and enter the same
          building. However, if the orders could be serviced by just one route
          instead, only one driver would need to park and enter the
          building-only one arrive/depart delay would be incurred. Since the VRP
          solver tries to minimize cost, it will try to limit the arrive/depart
          delays and thus choose the single-route option. (Note that multiple
          routes may need to be sent when other constraints-such as specialties,
          time windows, or capacities-require it.)The unit for this field value
          is specified by the Time Field Units
          parameter (time_units in Python). Capacities: The maximum capacity of
          the vehicle. You can specify capacity in any
          dimension you want, such as weight, volume, or quantity. You can even
          specify multiple dimensions, for example, weight and volume.Enter
          capacities without indicating units. For example, assume your
          vehicle can carry a maximum of 40,000 pounds; you would enter 40000.
          You need to remember for future reference that the value is in
          pounds.If you are tracking multiple dimensions, separate the numeric
          values
          with a space. For instance, if you are recording both weight and
          volume and your vehicle can carry a maximum weight of 40,000 pounds
          and a maximum volume of 2,000 cubic feet, Capacities should be entered
          as 40000 2000. Again, you need to remember the units. You also need to
          remember the sequence the values and their corresponding units are
          entered in (pounds followed by cubic feet in this case).Remembering
          the units and the unit sequence is important for a couple
          of reasons: one, so you can reinterpret the information later; two, so
          you can properly enter values for the DeliveryQuantities and
          PickupQuantities fields for Orders. To elaborate on the second point,
          note that the VRP solver simultaneously refers to Capacities,
          DeliveryQuantities, and PickupQuantities to make sure that a route
          doesn't become overloaded. Since units can't be entered in the field,
          Network Analyst can't make unit conversions, so you need to enter the
          values for the three fields using the same units and the same unit
          sequence to ensure the values are correctly interpreted. If you mix
          units or change the sequence in any of the three fields, you will get
          unwanted results without receiving any warning messages. Thus, it is a
          good idea to set up a unit and unit-sequence standard beforehand and
          continually refer to it whenever entering values for these three
          fields.An empty string or null value is equivalent to all values being
          zero.
          Capacity values can't be negative.If the Capacities string has an
          insufficient number of values in
          relation to the DeliveryQuantities or PickupQuantities fields for
          orders, the remaining values are treated as zero.The VRP solver only
          performs a simple Boolean test to determine
          whether capacities are exceeded. If a route's capacity value is
          greater than or equal to the total quantity being carried, the VRP
          solver will assume the cargo fits in the vehicle. This could be
          incorrect, depending on the actual shape of the cargo and the vehicle.
          For example, the VRP solver allows you to fit a 1,000-cubic-foot
          sphere into a 1,000-cubic-foot truck that is 8 feet wide. In reality,
          however, since the sphere is 12.6 feet in diameter, it won't fit in
          the 8-foot wide truck. FixedCost: A fixed monetary cost that is
          incurred only if the route is used in a
          solution (that is, it has orders assigned to it). This field can
          contain null values; a null value indicates zero fixed cost. This cost
          is part of the total route operating cost. CostPerUnitTime: The
          monetary cost incurred-per unit of work time-for the total route
          duration, including travel times as well as service times and wait
          times at orders, depots, and breaks. This field can't contain a null
          value and has a default value of 1.0.The unit for this field value is
          specified by the Time Field Units
          parameter (time_units in Python). CostPerUnitDistance: The monetary
          cost incurred-per unit of distance traveled-for the
          route length (total travel distance). This field can contain null
          values; a null value indicates zero cost.The unit for this field value
          is specified by the Distance Field Units
          parameter (distance_units for Python). OvertimeStartTime: The duration
          of regular work time before overtime computation begins.
          This field can contain null values; a null value indicates that
          overtime does not apply.The unit for this field value is specified by
          the Time Field Units
          parameter (time_units in Python).For example, if the driver is to be
          paid overtime when the total route
          duration extends beyond eight hours, OvertimeStartTime is specified as
          480 (8 hours * 60 minutes/hour), given the Time Field Units parameter
          is set to Minutes.CostPerUnitOvertime: The monetary cost incurred per
          time unit of overtime work. This field
          can contain null values; a null value indicates that the
          CostPerUnitOvertime value is the same as the CostPerUnitTime value.
          MaxOrderCount: The maximum allowable number of orders on the route.
          This field can't
          contain null values and has a default value of 30. MaxTotalTime: The
          maximum allowable route duration. The route duration includes
          travel times as well as service and wait times at orders, depots, and
          breaks. This field can contain null values; a null value indicates
          that there is no constraint on the route duration.The unit for this
          field value is specified by the Time Field Units
          parameter (time_units in Python). MaxTotalTravelTime: The maximum
          allowable travel time for the route. The travel time
          includes only the time spent driving on the network and does not
          include service or wait times. This field can contain null values; a
          null value indicates there is
          no constraint on the maximum allowable travel time. This field value
          can't be larger than the MaxTotalTime field value.The unit for this
          field value is specified by the Time Field Units
          parameter (time_units in Python). MaxTotalDistance: The maximum
          allowable travel distance for the route.The unit for this field value
          is specified by the Distance Field Units
          parameter (distance_units for Python).This field can contain null
          values; a null value indicates that there
          is no constraint on the maximum allowable travel distance.
          SpecialtyNames: A space-separated string containing the names of the
          specialties
          supported by the route. A null value indicates that the route does not
          support any specialties.This field is a foreign key to the
          SpecialtyNames field in the Orders
          class.To illustrate what specialties are and how they work, assume a
          lawn
          care and tree trimming company has a portion of its orders that
          requires a bucket truck to trim tall trees. The company would enter
          BucketTruck in the SpecialtyNames field for these orders to indicate
          their special need. SpecialtyNames would be left as null for the other
          orders. Similarly, the company would also enter BucketTruck in the
          SpecialtyNames field of routes that are driven by trucks with
          hydraulic booms. It would leave the field null for the other routes.
          At solve time, the VRP solver assigns orders without special needs to
          any route, but it only assigns orders that need bucket trucks to
          routes that have them. AssignmentRule: This specifies whether or not
          the route can be used when solving the
          problem. This field is constrained by a domain of values, and the
          possible values are the following:

          * Include-The route is included in the solve operation. This is the
          default value.

          * Exclude-The route is excluded from the solve operation.
      breaks (Record Set):
          The rest periods, or breaks, for the routes in a given vehicle routing
          problem. A break is associated with exactly one route, and it can be
          taken after completing an order, while en route to an order, or prior
          to servicing an order. It has a start time and a duration, for which
          the driver may or may not be paid. There are three options for
          establishing when a break begins: using a time window, a maximum
          travel time, or a maximum work time.The breaks record set has
          associated attributes. The fields in the
          attribute table are listed below and described. ObjectID:The system-
          managed ID field. RouteName: The name of the route that the break
          applies to. Although a break is
          assigned to exactly one route, many breaks can be assigned to the same
          route.This field is a foreign key to the Name field in the Routes
          class and
          can't have a null value. Precedence:Precedence values sequence the
          breaks of a given route. Breaks with a
          precedence value of 1 occur before those with a value of 2, and so
          on.All breaks must have a precedence value, regardless of whether they
          are time-window, maximum-travel-time, or maximum-work-time breaks.
          ServiceTime The duration of the break. This field can contain null
          values; a null
          value indicates no service time.The unit for this field value is
          specified by the Time Field Units
          parameter (time_units in Python). TimeWindowStart: The starting time
          of the break's time window.If this field is null and TimeWindowEnd has
          a valid time-of-day value,
          the break is allowed to start anytime before the TimeWindowEnd
          value.If this field has a value, MaxTravelTimeBetweenBreaks and
          MaxCumulWorkTime must be null; moreover, all other breaks in the
          analysis layer must have null values for MaxTravelTimeBetweenBreaks
          and MaxCumulWorkTime.An error will occur at solve time if a route has
          multiple breaks with
          overlapping time windows.The time window fields in breaks can contain
          a time-only value or a
          date and time value. If a time field, such as TimeWindowStart, has a
          time-only value (for example, 12:00 p.m.), the date is assumed to be
          the date specified by the Default Date parameter (default_date for
          Python). Using date and time values (for example, 7/11/2012 12:00
          p.m.) allows you to specify time windows that span two or more days.
          This is especially beneficial when a break should be taken sometime
          before and after midnight.The default date is ignored when any time
          window field includes a date
          with the time. To avoid an error in this situation, format all time
          windows in Depots, Routes, Orders, and Breaks to also include the date
          with the time. TimeWindowEnd: The ending time of the break's time
          window.If this field is null and TimeWindowStart has a valid time-of-
          day
          value, the break is allowed to start anytime after the TimeWindowStart
          value.If this field has a value, MaxTravelTimeBetweenBreaks and
          MaxCumulWorkTime must be null; moreover, all other breaks in the
          analysis layer must have null values for MaxTravelTimeBetweenBreaks
          and MaxCumulWorkTime. MaxViolationTime: This field specifies the
          maximum allowable violation time for a time-
          window break. A time window is considered violated if the arrival time
          falls outside the time range.A zero value indicates the time window
          cannot be violated; that is,
          the time window is hard. A nonzero value specifies the maximum amount
          of lateness; for example, the break can begin up to 30 minutes beyond
          the end of its time window, but the lateness is penalized as per the
          Time Window Violation Importance parameter (time_window_factor for
          Python).This property can be null; a null value with TimeWindowStart
          and
          TimeWindowEnd values indicates that there is no limit on the allowable
          violation time. If MaxTravelTimeBetweenBreaks or MaxCumulWorkTime has
          a value, MaxViolationTime must be null.The unit for this field value
          is specified by the Time Field Units
          parameter (time_units in Python). MaxTravelTimeBetweenBreaks:The
          maximum amount of travel time that can be accumulated before the
          break is taken. The travel time is accumulated either from the end of
          the previous break or, if a break has not yet been taken, from the
          start of the route.If this is the route's final break,
          MaxTravelTimeBetweenBreaks also
          indicates the maximum travel time that can be accumulated from the
          final break to the end depot.This field is designed to limit how long
          a person can drive until a
          break is required. For instance, if the Time Field Units parameter
          (time_units for Python) of the analysis is set to Minutes, and
          MaxTravelTimeBetweenBreaks has a value of 120, the driver will get a
          break after  two hours of driving. To assign a second break after two
          more hours of driving, the second break's MaxTravelTimeBetweenBreaks
          property should be 120.If this field has a value, TimeWindowStart,
          TimeWindowEnd,
          MaxViolationTime, and MaxCumulWorkTime must be null for an analysis to
          solve successfully.The unit for this field value is specified by the
          Time Field Units
          parameter (time_units in Python). MaxCumulWorkTime:The maximum amount
          of work time that can be accumulated before the
          break is taken. Work time is always accumulated from the beginning of
          the route.Work time is the sum of travel time and service times at
          orders,
          depots, and breaks. Note, however, that this excludes wait time, which
          is the time a route (or driver) spends waiting at an order or depot
          for a time window to begin.This field is designed to limit how long a
          person can work until a
          break is required. For instance, if the Time Field Units property
          (time_units for Python) is set to Minutes, MaxCumulWorkTime has a
          value of 120, and ServiceTime has a value of 15, the driver will get a
          15-minute break after  two hours of work.Continuing with the last
          example, assume a second break is needed
          after three more hours of work. To specify this break, you would enter
          315 (five hours and 15 minutes) as the second break's MaxCumulWorkTime
          value. This number includes the MaxCumulWorkTime and ServiceTime
          values of the preceding break, along with the three additional hours
          of work time before granting the second break. To avoid taking
          maximum-work-time breaks prematurely, remember that they accumulate
          work time from the beginning of the route and that work time includes
          the service time at previously visited depots, orders, and breaks.If
          this field has a value, TimeWindowStart, TimeWindowEnd,
          MaxViolationTime, and MaxTravelTimeBetweenBreaks must be null for an
          analysis to solve successfully.The unit for this field value is
          specified by the Time Field Units
          parameter (time_units in Python). IsPaid: A Boolean value indicating
          whether the break is paid or unpaid. A
          True value indicates that the time spent at the break is included in
          the route cost computation and overtime determination. A False value
          indicates otherwise. The default value is True. Sequence: As an input
          field, this indicates the sequence of the break on its
          route. This field can contain null values. The input sequence values
          are positive and unique for each route (shared across renewal depot
          visits, orders, and breaks) but need not start from 1 or be
          contiguous.The solver modifies the sequence field. After solving, this
          field
          contains the sequence value of the break on its route. Output sequence
          values for a route are shared across depot visits, orders, and breaks;
          start from 1 (at the starting depot); and are consecutive.
      time_units (String):
          The time units for all time-based field values in the analysis.

          * Seconds

          * Minutes

          * Hours

          * Days
          Many features and records in a VRP analysis have fields for storing
          time values, such as ServiceTime for Orders and CostPerUnitTime for
          Routes. To minimize data entry requirements, these field values don't
          include units. Instead, all distance-based field values must be
          entered in the same units, and this parameter is used to specify the
          units of those values.Note that output time-based fields use the same
          units specified by
          this parameter.This time unit doesn't need to match the time unit of
          the network Time
          Attribute parameter (time_attribute in Python).
      distance_units (String):
          The distance units for all distance-based field values in the
          analysis.

          * Miles

          * Kilometers

          * Feet

          * Yards

          * Meters

          * NauticalMiles
          Many features and records in a VRP analysis have fields for storing
          distance values, such as MaxTotalDistance and CostPerUnitDistance for
          Routes. To minimize data entry requirements, these field values don't
          include units. Instead, all distance-based field values must be
          entered in the same units, and this parameter is used to specify the
          units of those values.Note that output distance-based fields use the
          same units specified by
          this parameter. This distance unit doesn't need to match the distance
          unit of the
          network Distance Attribute (distance attribute in Python).
      network_dataset (Network Dataset Layer):
          The network dataset on which the vehicle routing problem analysis
          will be performed. The network dataset must have a time-based cost
          attribute since the VRP solver minimizes time.
      output_workspace_location (Workspace):
          The enterprise geodatabase, file geodatabase, or in-memory workspace
          in which the output feature classes will be created. This workspace
          must already exist. The default output workspace is in memory.
      output_unassigned_stops_name (String):
          The name of the output feature class that will contain any
          unreachable depots or unassigned orders.
      output_stops_name (String):
          The name of the feature class that will contain the stops visited by
          routes. This feature class includes stops at depots, orders, and
          breaks.
      output_routes_name (String):
          The name of the feature class that will contain the routes of the
          analysis.
      output_directions_name (String):
          The name of the feature class that will contain the directions for
          the routes.
      default_date {Date}:
          The default date for time field values that specify a time of day
          without including a date.
      uturn_policy {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges connect to the junction,
          which is known as junction valency. The acceptable values for this
          parameter are listed below; each is followed by a description of its
          meaning in terms of junction valency.

          * ALLOW_UTURNS-U-turns are permitted at junctions with any number of
          connected edges. This is the default value.

          * NO_UTURNS-U-turns are prohibited at all junctions, regardless of
          junction valency. Note, however, that U-turns are still permitted at
          network locations even when this setting is chosen; however, you can
          set the individual network locations' CurbApproach property to
          prohibit U-turns there as well.

          * ALLOW_DEAD_ENDS_ONLY-U-turns are prohibited at all junctions, except
          those that have only one adjacent edge (a dead end).

          * ALLOW_DEAD_ENDS_AND_INTERSECTIONS_ONLY-U-turns are prohibited at
          junctions where exactly two adjacent edges meet but are permitted at
          intersections (junctions with three or more adjacent edges) and dead
          ends (junctions with exactly one adjacent edge). Often, networks have
          extraneous junctions in the middle of road segments. This option
          prevents vehicles from making U-turns at these locations.
          If you need a more precisely defined U-turn policy, consider adding a
          global turn delay evaluator to a network cost attribute, or adjusting
          its settings if one exists, and pay particular attention to the
          configuration of reverse turns. Also, look at setting the CurbApproach
          property of your network locations.The value of this parameter is
          overridden when Travel Mode
          (travel_mode in Python) is set to any value other than custom.
      time_window_factor {String}:
          Rates the importance of honoring time windows. There are three
          options, which are listed and described below.

          * Low-Places more importance on minimizing drive times and less on
          arriving at stops on time. You may want to use this setting if you
          have a growing backlog of service requests. For the purpose of
          servicing more orders in a day and reducing the backlog, you can
          choose this setting even though customers might be inconvenienced with
          your late arrivals.

          * Medium-This is the default value. Balances the importance of
          minimizing drive times and arriving within time windows.

          * High-Places more importance on arriving at stops on time than on
          minimizing drive times. Organizations that make time-critical
          deliveries or that are very concerned with customer service would
          choose this setting.
      spatially_cluster_routes {Boolean}:
          * CLUSTER-Dynamic seed points are created for all routes
          automatically and the orders assigned to an individual route are
          spatially clustered. Clustering orders tends to keep routes in smaller
          areas and reduce how often different route lines intersect one
          another; yet, clustering also tends to increase overall travel times.

          * NO_CLUSTER-Dynamic seed points aren't created. Choose this option
          if route zones are specified.
      route_zones {Feature Set}:
          Delineates work territories for given routes. A route zone is a
          polygon feature and is used to constrain routes to servicing only
          those orders that fall within or near the specified area. Here are
          some examples of when route zones may be useful:

          *  Some of your employees don't have the required permits to perform
          work in certain states or communities. You can create a hard route
          zone so they only visit orders in areas where they meet the
          requirements.

          * One of your vehicles breaks down frequently, so you want to minimize
          response time by having it only visit orders that are close to your
          maintenance garage. You can create a soft or hard route zone to keep
          the vehicle nearby.
          The route zones feature set has an associated attribute table. The
          fields in the attribute table are listed below and described.
          ObjectID:The system-managed ID field. Shape:The geometry field
          indicating the geographic location of the network
          analysis object. RouteName: The name of the route to which this zone
          applies. A route zone can
          have a maximum of one associated route. This field can't contain null
          values, and it is a foreign key to the Name field in the Routes
          feature layer. IsHardZone: A Boolean value indicating a hard or soft
          route zone. A True value
          indicates that the route zone is hard; that is, an order that falls
          outside the route zone polygon can't be assigned to the route. The
          default value is True (1). A False value (0) indicates that such
          orders can still be assigned, but the cost of servicing the order is
          weighted by a function that is based on the Euclidean distance from
          the route zone. Basically, this means that as the straight-line
          distance from the soft zone to the order increases, the likelihood of
          the order being assigned to the route decreases.
      route_renewals {Record Set}:
          Specifies the intermediate depots that routes can visit to reload or
          unload the cargo they are delivering or picking up. Specifically, a
          route renewal links a route to a depot. The relationship indicates the
          route can renew (reload or unload while en route) at the associated
          depot.Route renewals can be used to model scenarios in which a vehicle
          picks
          up a full load of deliveries at the starting depot, services the
          orders, returns to the depot to renew its load of deliveries, and
          continues servicing more orders. For example, in propane gas delivery,
          the vehicle may make several deliveries until its tank is nearly or
          completely depleted, visit a refueling point, and make more
          deliveries.Here are a few rules and options to consider when also
          working with
          route seed points:

          * The reload/unload point, or renewal location, can be different from
          the start or end depot.

          * Each route can have one or many predetermined renewal locations.

          * A renewal location may be used more than once by a single route.

          * In some cases where there may be several potential renewal locations
          for a route, the closest available renewal location is chosen by the
          solver.
          The route renewals record set has associated attributes. The fields in
          the attribute table are listed below and described. ObjectID:The
          system-managed ID field. DepotName: The name of the depot where this
          renewal takes place. This field
          can't contain a null value and is a foreign key to the Name field in
          the Depots feature layer. RouteName: The name of the route that this
          renewal applies to. This field can't
          contain a null value and is a foreign key to the Name field in the
          Routes feature layer. ServiceTime: The service time for the renewal.
          This field can contain a null
          value; a null value indicates zero service time. The unit for this
          field value is specified by the Time Field Units
          property of the analysis layer.The time taken to load a vehicle at a
          renewal depot may depend on the
          size of the vehicle and how full or empty the vehicle is. However, the
          service time for a route renewal is a fixed value and does not take
          into account the actual load. As such, the renewal service time should
          be given a value corresponding to a full truckload, an average
          truckload, or another time estimate of your choice.
      order_pairs {Record Set}:
          Pairs pickup and delivery orders so they are serviced by the same
          route. Sometimes it is required that the pickup and delivery for
          orders be
          paired. For example, a courier company might need to have a route pick
          up a high-priority package from one order and deliver it to another
          without returning to a depot, or sorting station, to minimize delivery
          time. These related orders can be assigned to the same route with the
          appropriate sequence by using order pairs. Moreover, restrictions on
          how long the package can stay in the vehicle can also be assigned; for
          example, the package might be a blood sample that has to be
          transported from the doctor's office to the lab within two hours.The
          order pairs record set has associated attributes. The fields in
          the attribute table are listed below and described. ObjectID:The
          system-managed ID field. FirstOrderName: The name of the first order
          of the pair. This field is a foreign key
          to the Name field in the Orders feature layer. SecondOrderName: The
          name of the second order of the pair. This field is a foreign key
          to the Name field in the Orders feature layer.The first order in the
          pair must be a pickup order; that is, the value
          for its DeliveryQuantities field is null. The second order in the pair
          must be a delivery order; that is, the value for its PickupQuantities
          field is null. The quantity that is picked up at the first order must
          agree with the quantity that is delivered at the second order. As a
          special case, both orders may have zero quantities for scenarios where
          capacities are not used.The order quantities are not loaded or
          unloaded at depots. MaxTransitTime: The maximum transit time for the
          pair. The transit time is the
          duration from the departure time of the first order to the arrival
          time at the second order. This constraint limits the time-on-vehicle,
          or ride time, between the two orders. When a vehicle is carrying
          people or perishable goods, the ride time is typically shorter than
          that of a vehicle carrying packages or nonperishable goods. This field
          can contain null values; a null value indicates that there is no
          constraint on the ride time. The unit for this field value is
          specified by the Time Field Units
          property of the analysis layer.Excess transit time (measured with
          respect to the direct travel time
          between order pairs) can be tracked and weighted by the solver.
          Because of this, you can direct the VRP solver to take one of three
          approaches: (1) minimize the overall excess transit time, regardless
          of the increase in travel cost for the fleet; (2) find a solution that
          balances overall violation time and travel cost; and (3) ignore the
          overall excess transit time and, instead, minimize the travel cost for
          the fleet. By assigning an importance level for the Excess Transit
          Time Importance parameter (excess_transit_factor for Python), you are
          in effect choosing one of these three approaches. Regardless of the
          importance level, the solver will always return an error if the
          MaxTransitTime value is surpassed.
      excess_transit_factor {String}:
          Rates the importance of reducing excess transit time of order pairs.
          Excess transit time is the amount of time exceeding the time required
          to travel directly between the paired orders. Excess time can be
          caused by driver breaks or travel to intermediate orders and depots.
          Listed below are the three values from which you can choose.

          * Low-The solver tries to find a solution that minimizes overall
          solution cost, regardless of excess transit time. This setting is
          commonly used with courier services. Since couriers transport packages
          as opposed to people, they don't need to worry about ride time. Using
          this setting allows the couriers to service paired orders in the
          proper sequence and minimize the overall solution cost.

          * Medium-This is the default setting. The solver looks for a balance
          between reducing excess transit time and reducing the overall solution
          cost.

          * High-The solver tries to find a solution with the least excess
          transit time between paired orders at the expense of increasing the
          overall travel costs. It makes sense to use this setting if you are
          transporting people between paired orders and you want to shorten
          their ride time. This is characteristic of taxi services.
      point_barriers {Feature Set}:
          Specifies point barriers, which are split into two types: restriction
          and added cost point barriers. They temporarily restrict traversal
          across or add impedance to points on the network. The point barriers
          are defined by a feature set, and the attribute values you specify for
          the point features determine whether they are restriction or added
          cost barriers. The fields in the attribute table are listed and
          described below. ObjectID:The system-managed ID field. Shape:The
          geometry field indicating the geographic location of the network
          analysis object.Name:The name of the barrier.BarrierType: Specifies
          whether the barrier restricts travel completely or adds
          cost when traveling through it. There are two options:

          * Restriction  (0)-Prohibits traversing through the barrier. This is
          the default value.

          * Added Cost  (2)-Traversing through the barrier increases the network
          cost by the amount specified in the Additional_Time and
          Additional_Distance fields.
          Additional_Time:If BarrierType is set to added cost, the value of the
          Additional_Time
          field indicates how much time is added to a route when the route
          passes through the barrier. The unit for this field value is specified
          by the Time Field Units
          property of the analysis layer.Additional_Distance:If BarrierType is
          set to added cost, the value of the
          Additional_Distance field indicates how much impedance is added to a
          route when the route passes through the barrier.The unit for this
          field value is specified by the Distance Field Units
          parameter.
      line_barriers {Feature Set}:
          Specifies line barriers, which temporarily restrict traversal across
          them. The line barriers are defined by a feature set. The fields in
          the attribute table are listed and described below. ObjectID:The
          system-managed ID field.Shape:The geometry field indicating the
          geographic location of the network
          analysis object. Name:The name of the barrier.
      polygon_barriers {Feature Set}:
          Specifies polygon barriers, which are split into two types:
          restriction and scaled cost polygon barriers. They temporarily
          restrict traversal or scale impedance on the parts of the network they
          cover. The polygon barriers are defined by a feature set, and the
          attribute values you specify for the polygon features determine
          whether they are restriction or scaled cost barriers. The fields in
          the attribute table are listed and described below. ObjectID:The
          system-managed ID field. Shape:The geometry field indicating the
          geographic location of the network
          analysis object. Name:The name of the barrier. BarrierType: Specifies
          whether the barrier restricts travel completely or scales
          the cost of traveling through it. There are two options:

          * Restriction  (0)-Prohibits traversing through any part of the
          barrier. This is the default value.

          * Scaled Cost  (1)-Scales the impedance of underlying edges by
          multiplying them by the value of the Attr_[Impedance] property. If
          edges are partially covered by the barrier, the impedance is
          apportioned and multiplied.
          Scaled_Time:The time-based impedance values of the edges underlying
          the barrier
          are multiplied by the value set in this field. This field is only
          relevant when the barrier is a scaled cost barrier.Scaled_Distance:The
          distance-based impedance values of the edges underlying the
          barrier are multiplied by the value set in this field. This field is
          only relevant when the barrier is a scaled cost barrier.
      time_attribute {String}:
          Defines the network cost attribute to use when determining the travel
          time of network elements.The value of this parameter is overridden
          when Travel Mode
          (travel_mode in Python) is set to any value other than custom.
      distance_attribute {String}:
          Defines the network cost attribute to use when determining the
          distance of network elements.The value of this parameter is overridden
          when Travel Mode
          (travel_mode in Python) is set to any value other than custom.
      use_hierarchy_in_analysis {Boolean}:
          * USE_HIERARCHY-Use the hierarchy attribute for the analysis. Using a
          hierarchy results in the solver preferring higher-order edges to
          lower-order edges. Hierarchical solves are faster, and they can be
          used to simulate the preference of a driver who chooses to travel on
          freeways over local roads when possible-even if that means a longer
          trip. This option is valid only if the input network dataset has a
          hierarchy attribute.

          * NO_HIERARCHY-Do not use the hierarchy attribute for the analysis.
          Not using a hierarchy yields an exact route for the network dataset.
          The parameter is not used if a hierarchy attribute is not defined on
          the network dataset used to perform the analysis. In such cases, use
          "#" as the parameter value.The value of this parameter is overridden
          when Travel Mode
          (travel_mode in Python) is set to any value other than custom.
      restrictions {String}:
          Indicates which network restriction attributes are respected during
          solve time.The value of this parameter is overridden when Travel Mode
          (travel_mode in Python) is set to any value other than custom.
      attribute_parameter_values {Record Set}:
          Specifies the parameter values for network attributes that have
          parameters. The record set has two columns that work together to
          uniquely identify parameters and another column that specifies the
          parameter value.The value of this parameter is overridden when Travel
          Mode
          (travel_mode in Python) is set to any value other than custom.The
          attribute parameter values record set has associated attributes.
          The fields in the attribute table are listed below and described.
          ObjectID:The system-managed ID field.AttributeName:The name of the
          network attribute whose attribute parameter is set by
          the table row.ParameterName:The name of the attribute parameter whose
          value is set by the table
          row. (Object type parameters cannot be updated using this
          tool.)ParameterValue:The value you want for the attribute parameter.
          If a value is not
          specified, the attribute parameter is set to null.
      maximum_snap_tolerance {Linear Unit}:
          The maximum snap tolerance is the furthest distance that Network
          Analyst searches when locating or relocating a point onto the network.
          The search looks for suitable edges or junctions and snaps the point
          to the nearest one. If a suitable location isn't found within the
          maximum snap tolerance, the object is marked as unlocated.
      exclude_restricted_portions_of_the_network {Boolean}:
          * EXCLUDE-Specifies that the network locations are only placed on
          traversable portions of the network. This prevents placing network
          locations on elements that you can't reach due to restrictions or
          barriers. Before adding your network locations using this option, make
          sure that you have already added all the restriction barriers to the
          input network analysis layer to get expected results. This parameter
          is not applicable when adding barrier objects. In such cases, use "#"
          as the parameter value.

          * INCLUDE-Specifies that the network locations are placed on all the
          elements of the network. The network locations that are added with
          this option may be unreachable during the solve process if they are
          placed on restricted elements.
      feature_locator_where_clause {Value Table}:
          An SQL expression used to select a subset of source features that
          limits on which network elements orders and depots can be located. For
          example, to ensure orders and depots are not located on limited-access
          highways, write an SQL expression that excludes those source features.
          Note that the other network analysis objects, such as barriers, ignore
          the feature locator WHERE clause when loading.For more information on
          SQL syntax and how it differs between data
          sources, see SQL reference for query expressions used in ArcGIS.
      populate_route_lines {Boolean}:
          Choose whether you want to generate lines that show the true shape of
          the routes.

          * NO_ROUTE_LINES-No shape is generated for the output routes. You
          won't be able to generate driving directions if route lines aren't
          created.

          * ROUTE_LINES-The output routes will have the exact shape of the
          underlying network sources.
      route_line_simplification_tolerance {Linear Unit}:
          Specify by how much you want to simplify the route
          geometry.Simplification maintains critical points on a route, such as
          turns at
          intersections, to define the essential shape of the route and removes
          other points. The simplification distance you specify is the maximum
          allowable offset that the simplified line can deviate from the
          original line. Simplifying a line reduces the number of vertices and
          tends to reduce drawing times.The value of this parameter is
          overridden when Travel Mode
          (travel_mode in Python) is set to any value other than custom.
      populate_directions {Boolean}:
          Choose whether to generate driving directions.

          * DIRECTIONS-The feature class specified in the output_directions_name
          parameter is populated with turn-by-turn instructions for each route.
          The network dataset must support driving directions; otherwise, an
          error occurs when solving with directions.

          * NO_DIRECTIONS-Directions aren't generated.
      directions_language {String}:
          Choose a language in which to generate driving directions. The
          languages available in the drop-down list depend on what ArcGIS
          language packs are installed on your computer.Note that if you are
          going to publish this tool as part of a service
          on a separate server, the ArcGIS language pack that corresponds with
          the language you choose must be installed on that server for the tool
          to function properly. Also, if a language pack isn't installed on your
          computer, the language won't appear in the drop-down list; however,
          you can type a language code instead.
      directions_style_name {String}:
          The name of the formatting style of directions.

          * NA Desktop-Printable turn-by-turn directions

          * NA Navigation-Turn-by-turn directions designed for an in-vehicle
          navigation device

          * NA Campus-Turn-by-turn walking directions, which are designed for
          pedestrian routes
      save_output_layer {Boolean}:
          * NO_SAVE_OUTPUT_LAYER-A network analysis layer isn't included in the
          output.

          * SAVE_OUTPUT_LAYER-The output includes a network analysis layer of
          the results.
          In either case, stand-alone tables and feature classes are returned.
          However, a server administrator may want to choose to output a network
          analysis layer as well so the setup and results of the tool can be
          debugged using the Network Analyst controls in the ArcGIS Desktop
          environment. This can make the debugging process much easier.In ArcGIS
          Desktop, the default output location for the network
          analysis layer is in the scratch workspace, at the same level as the
          scratch geodatabase; that is, it is stored as a sibling of the scratch
          geodatabase. The output network analysis layer is stored as an LYR
          file whose name starts with _ags_gpna and is followed by an
          alphanumeric GUID.
      service_capabilities {Value Table}:
          This property helps you govern the maximum amount of computer
          processing that occurs when running this tool as a geoprocessing
          service. You might want to do this for one of two reasons: one, to
          avoid letting your server solve problems that require more resources
          or processing time than you want to allow; two, to create multiple
          services with different VRP capabilities to support a business model.
          For example, if you have a tiered-service business model, you might
          want to provide a free VRP service that supports a maximum of five
          routes per solve and another service that is fee-based and supports
          more than five routes per solve.Along with limiting the maximum number
          of routes, you can limit how
          many orders or point barriers can be added to the analysis. Another
          way to govern problem sizes is by setting a maximum number of
          features-usually street features-that line or polygon barriers can
          intersect. The last method is to force a hierarchical solve, even if
          the user chooses not to use a hierarchy, when orders are
          geographically dispersed beyond a given straight-line distance.

          * MAXIMUM POINT BARRIERS-The maximum number of point barriers allowed.
          An error is returned if this limit is exceeded. A null value indicates
          there is no limit.

          * MAXIMUM FEATURES INTERSECTING LINE BARRIERS-The maximum number of
          source features that can be intersected by all line barriers in the
          analysis. An error is returned if this limit is exceeded. A null value
          indicates there is no limit.

          * MAXIMUM FEATURES INTERSECTING POLYGON BARRIERS-The maximum number of
          source features that can be intersected by all polygon barriers in the
          analysis. An error is returned if this limit is exceeded. A null value
          indicates there is no limit.

          * MAXIMUM ORDERS-The maximum number of orders allowed in the analysis.
          An error is returned if this limit is exceeded. A null value indicates
          there is no limit.

          * MAXIMUM ROUTES-The maximum number of routes allowed in the analysis.
          An error is returned if this limit is exceeded. A null value indicates
          there is no limit.

          * FORCE HIERARCHY BEYOND DISTANCE-The maximum straight-line distance
          between orders before the vehicle routing problem is solved using the
          network's hierarchy. The units for this value are the same as those
          specified in the Distance Field Units parameter.If the network doesn't
          have a hierarchy attribute, this constraint is ignored. If Use
          Hierarchy in Analysis is checked, hierarchy is always used. If the Use
          Hierarchy in Analysis parameter is unchecked and this constraint has a
          null value, hierarchy is not forced.

          * MAXIMUM ORDERS PER ROUTE-The maximum number of orders that can be
          assigned to each route. An error is returned if this limit is
          exceeded. A null value indicates there is no limit.
      ignore_invalid_order_locations {Boolean}:
          Choose whether invalid orders should be ignored when solving the
          vehicle routing problem.

          * HALT-The solve operation fails when any invalid orders are
          encountered. An invalid order is an order that the VRP solver can't
          reach. An order may be unreachable for a variety of reasons, including
          the following: it is located on a prohibited network element, it isn't
          located on the network at all, and it is located on a disconnected
          portion of the network. This is the default value.

          * SKIP-The solve operation skips any invalid orders and returns a
          solution, given it didn't encounter any other errors.If you need to
          generate routes and deliver them to drivers immediately, you may be
          able to skip invalid orders, solve, and distribute the routes to your
          drivers. Next, resolve any invalid orders from the last solve and
          include them in the VRP analysis for the next workday or work shift.
      travel_mode {String}:
          Choose the mode of transportation for the analysis. CUSTOM is always a
          choice. For other travel mode names to appear, they must be present in
          the network dataset specified in the Network_Dataset parameter. (The
          arcpy.na.GetTravelModes function provides a dictionary of the travel
          mode objects configured on a network dataset, and the name property
          returns the name of a travel mode object.) A travel mode is defined on
          a network dataset and provides override
          values for parameters that, together, model car, truck, pedestrian, or
          other modes of travel. By choosing a travel mode here, you don't need
          to provide values for the following parameters, which are overridden
          by values specified in the network dataset:

          * uturn_policy

          * time_attribute

          * distance_attribute

          * use_hierarchy_in_analysis

          * restrictions

          * attribute_parameter_values

          * route_line_simplification_tolerance

          * CUSTOM-Define a travel mode that fits your specific needs. When
          CUSTOM is chosen, the tool does not override the travel mode
          parameters listed above. This is the default value.
      ignore_network_location_fields {Boolean}:
          * IGNORE-Specifies that the network location fields will not be
          considered when locating the inputs on the network. Instead, the
          inputs will always be located by performing a spatial search.

          * HONOR-Specifies that the network location fields will be considered
          when locating the inputs on the network. This is the default value.
      time_zone_usage_for_time_fields {String}:
          Specifies the time zone for the input date-time fields supported by
          the tool. This parameter specifies the time zone for the following
          fields: TimeWindowStart1, TimeWindowEnd1, TimeWindowStart2,
          TimeWindowEnd2, InboundArriveTime, and OutboundDepartTime on orders;
          TimeWindowStart1, TimeWindowEnd1, TimeWindowStart2, and TimeWindowEnd2
          on depots; EarliestStartTime and LatestStartTime on routes; and
          TimeWindowStart and TimeWindowEnd on breaks.

          * GEO_LOCAL-The date-time values associated with the orders or depots
          are in the time zone in which the orders and depots are located. For
          routes, the date-time values are based on the time zone in which the
          starting depot for the route is located. If a route does not have a
          starting depot, all orders and depots across all the routes must be in
          a single time zone. For breaks, the date-time values are based on the
          time zone of the routes. For example, if your depot is located in an
          area that follows Eastern Standard Time and has the first time window
          values (specified as TimeWindowStart1 and TimeWindowEnd1) of 8 a.m.
          and 5 p.m., the time window values will be treated as 8 a.m. and 5
          p.m. in Eastern Standard Time.

          * UTC-The date-time values associated with the orders or depots are
          in the in the Coordinated Universal Time (UTC) and are not based on
          the time zone in which the orders or depots are located. For example,
          if your depot is located in an area that follows Eastern Standard Time
          and has the first time window values (specified as TimeWindowStart1
          and TimeWindowEnd1) of 8 a.m. and 5 p.m., the time window values will
          be treated as 12 p.m. and 9 p.m. in Eastern Standard Time, assuming
          the Eastern Standard Time is obeying the Daylight Saving Time.
           Specifying the date-time values in UTC is useful if you do not know
          the time zone in which the orders or depots are located or when you
          have orders and depots in multiple time zones and you want all the
          date-time values to start simultaneously. The UTC option is applicable
          only when your network dataset defines a time zone attribute.
          Otherwise, all the date-time values are always treated as GEO_LOCAL.
      overrides {String}:
          Specify additional settings that can influence the behavior of the
          solver when finding solutions for the network analysis problems. The
          value for this parameter needs to be specified in JavaScript
          Object Notation (JSON). For example, a valid value is of the following
          form {"overrideSetting1" : "value1", "overrideSetting2" : "value2"}.
          The override setting name is always enclosed in double quotes. The
          values can be either a number, Boolean, or a string. The default value
          for this parameter is no value, which indicates not
          to override any solver settings. Overrides are advanced settings that
          should be used only after
          careful analysis of the results obtained before and after applying the
          settings. A list of supported override settings for each solver and
          their acceptable values can be obtained by contacting Esri Technical
          Support.
      save_route_data {Boolean}:
          Choose whether to save a .zip file that contains a file geodatabase
          holding the inputs and outputs of the analysis in a format that can be
          used to share route layers with ArcGIS Online or Portal for ArcGIS. In
          ArcGIS Desktop, the default output location for this output file
          is in the scratch folder. You can determine the location of the
          scratch folder using arcpy.env.scratchFolder.

          *  SAVE_ROUTE_DATA-The tool writes out a .zip archive containing a
          file geodatabase workspace that contains the inputs and outputs of the
          analysis.

          *  NO_SAVE_ROUTE_DATA-Route data is not saved. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SolveVehicleRoutingProblem_na(*gp_fixargs((orders, depots, routes, breaks, time_units, distance_units, network_dataset, output_workspace_location, output_unassigned_stops_name, output_stops_name, output_routes_name, output_directions_name, default_date, uturn_policy, time_window_factor, spatially_cluster_routes, route_zones, route_renewals, order_pairs, excess_transit_factor, point_barriers, line_barriers, polygon_barriers, time_attribute, distance_attribute, use_hierarchy_in_analysis, restrictions, attribute_parameter_values, maximum_snap_tolerance, exclude_restricted_portions_of_the_network, feature_locator_where_clause, populate_route_lines, route_line_simplification_tolerance, populate_directions, directions_language, directions_style_name, save_output_layer, service_capabilities, ignore_invalid_order_locations, travel_mode, ignore_network_location_fields, time_zone_usage_for_time_fields, overrides, save_route_data), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('UpdateAnalysisLayerAttributeParameter_na', None)
def UpdateAnalysisLayerAttributeParameter(in_network_analysis_layer=None, parameterized_attribute=None, attribute_parameter_name=None, attribute_parameter_value=None):
    """UpdateAnalysisLayerAttributeParameter_na(in_network_analysis_layer, parameterized_attribute, attribute_parameter_name, {attribute_parameter_value})

        Updates the network attribute parameter value for a network analysis
        layer. The tool should be used to update the value of an attribute
        parameter for a network analysis layer prior to solving with the Solve
        tool. This ensures that the solve operation uses the specified value
        of the attribute parameter to produce appropriate results.This is a
        deprecated tool. Instead of updating your network analysis
        layer's attribute parameter values individually at analysis time, you
        should instead set attribute parameter values in advance by
        configuring travel modes on your network data source. At analysis
        time, simply choose the correct travel mode.

     INPUTS:
      in_network_analysis_layer (Network Analyst Layer):
          Network analysis layer for which the attribute parameter value will be
          updated.
      parameterized_attribute (String):
          The network attribute whose attribute parameter will be updated.
      attribute_parameter_name (String):
          The parameter of the network attribute that will be updated. The
          parameters of type Object cannot be updated using the tool.
      attribute_parameter_value {String}:
          The value that will be set for the attribute parameter. It can be a
          string, number, date, or Boolean (True, False). If the value is not
          specified, then the attribute parameter value is set to Null.If the
          attribute parameter has a restriction usage type, the value can
          be specified as a string keyword or a numeric value. The string
          keyword or the numeric value determines whether the restriction
          attribute prohibits, avoids, or prefers the network elements it is
          associated with. Furthermore, the degree to which network elements are
          avoided or preferred can be defined by choosing HIGH, MEDIUM, or LOW
          keywords. The following keywords are supported:

          * PROHIBITED

          * AVOID_HIGH

          * AVOID_MEDIUM

          * AVOID_LOW

          * PREFER_LOW

          * PREFER_MEDIUM

          * PREFER_HIGH
          Numeric values that are greater than one cause restricted elements to
          be avoided; the larger the number, the more the elements are avoided.
          Numeric values between zero and one cause restricted elements to be
          preferred; the smaller the number, the more restricted elements are
          preferred. Negative numbers prohibit restricted elements. If the
          parameter value holds an array, separate the items in the
          array with the localized separator character. For example, in the
          U.S., you would most likely use the comma character to separate the
          items. So representing an array of three numbers might look like the
          following: "5,10,15"."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateAnalysisLayerAttributeParameter_na(*gp_fixargs((in_network_analysis_layer, parameterized_attribute, attribute_parameter_name, attribute_parameter_value), True)))
        return retval
    except Exception as e:
        raise e


# Network Dataset toolset
@gptoolnotsupported
@gptooldoc('BuildNetwork_na', None)
def BuildNetwork(in_network_dataset=None):
    """BuildNetwork_na(in_network_dataset)

        Reconstructs the network connectivity and attribute information of a
        network dataset. The network dataset needs to be rebuilt after making
        edits to the attributes or the features of a participating source
        feature class. After the source features are edited, the tool
        establishes the network connectivity only in the areas that have been
        edited to speed up the build process; however, when the network
        attributes are edited, the entire extent of the network dataset is
        rebuilt. This may be a slow operation on a large network dataset.

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset to be built."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.BuildNetwork_na(*gp_fixargs((in_network_dataset,), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('CreateNetworkDatasetFromTemplate_na', None)
def CreateNetworkDatasetFromTemplate(network_dataset_template=None, output_feature_dataset=None):
    """CreateNetworkDatasetFromTemplate_na(network_dataset_template, output_feature_dataset)

        Creates a new network dataset with the schema contained in the input
        template file (.xml). All the feature classes and input tables
        required for creating the network dataset must already exist before
        this tool is executed.

     INPUTS:
      network_dataset_template (File):
          The template file (.xml) created by the Create Template From Network
          Dataset tool containing the schema of the output network dataset to be
          created.
      output_feature_dataset (Feature Dataset):
          The feature dataset containing the feature classes that will take
          part in the network dataset being created. The network will be created
          in this dataset using the name specified in the network dataset
          template."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateNetworkDatasetFromTemplate_na(*gp_fixargs((network_dataset_template, output_feature_dataset), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('CreateTemplateFromNetworkDataset_na', None)
def CreateTemplateFromNetworkDataset(network_dataset=None, output_network_dataset_template=None):
    """CreateTemplateFromNetworkDataset_na(network_dataset, output_network_dataset_template)

        Creates a file containing the schema of an existing network dataset.
        This template file can then be used to create a new network dataset
        with the same schema.

     INPUTS:
      network_dataset (Network Dataset Layer):
          The network dataset whose schema will be written to the output
          template file.

     OUTPUTS:
      output_network_dataset_template (File):
          The output file (.xml) that will contain the schema of the input
          network dataset."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateTemplateFromNetworkDataset_na(*gp_fixargs((network_dataset, output_network_dataset_template), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('DissolveNetwork_na', None)
def DissolveNetwork(in_network_dataset=None, out_workspace_location=None):
    """DissolveNetwork_na(in_network_dataset, out_workspace_location)

        Creates a network dataset that minimizes the number of line features
        required to correctly model the input network dataset. The more
        efficient output network dataset reduces the time required to solve
        analyses, draw results, and generate driving directions. This tool
        outputs a new network dataset and source feature classes; the input
        network dataset and its source features remain unchanged. Learn more
        about how Dissolve Network works

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset to be dissolved. The input network dataset must
          be a file or personal geodatabase
          network dataset with exactly one edge source. Any number of junction
          sources and turn sources is allowed. The edge source must have:

          * End point connectivity policy

          * An elevation policy of either None or Elevation Fields
           The input network dataset must be built before it can be used in this
          tool.
      out_workspace_location (Workspace):
          The geodatabase workspace in which to create the dissolved network
          dataset. The workspace must be an ArcGIS 10 geodatabase or later, and
          it must be a different geodatabase than the one where the input
          network dataset resides."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DissolveNetwork_na(*gp_fixargs((in_network_dataset, out_workspace_location), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('UpgradeNetwork_na', None)
def UpgradeNetwork(in_network_dataset=None):
    """UpgradeNetwork_na(in_network_dataset)

        Upgrades the schema of the network dataset. Upgrading the network
        dataset allows the network dataset to make use of the new
        functionality available in the current software release. This is a
        deprecated tool. To learn more about how this tool works,
        view the archived documentation. This functionality has been replaced
        by the Upgrade Dataset tool in the Geodatabase Administration toolset.
        Upgrade Dataset has the ability to upgrade network datasets as well as
        other types of datasets, such as parcel fabrics, to the current ArcGIS
        release.

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset to be upgraded. The network dataset must be a
          geodatabase-based network dataset."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpgradeNetwork_na(*gp_fixargs((in_network_dataset,), True)))
        return retval
    except Exception as e:
        raise e


# Turn Feature Class toolset
@gptoolnotsupported
@gptooldoc('CreateTurnFeatureClass_na', None)
def CreateTurnFeatureClass(out_location=None, out_feature_class_name=None, maximum_edges=None, in_network_dataset=None, in_template_feature_class=None, spatial_reference=None, config_keyword=None, spatial_grid_1=None, spatial_grid_2=None, spatial_grid_3=None, has_z=None):
    """CreateTurnFeatureClass_na(out_location, out_feature_class_name, {maximum_edges}, {in_network_dataset}, {in_template_feature_class}, {spatial_reference}, {config_keyword}, {spatial_grid_1}, {spatial_grid_2}, {spatial_grid_3}, {has_z})

        Creates a new turn feature class to store turn features that model
        turning movements in a network dataset.

     INPUTS:
      out_location (Workspace / Feature Dataset):
          The file, personal, workgroup, or enterprise geodatabase, or the
          folder in which the output turn feature class will be created. This
          workspace must already exist.
      out_feature_class_name (String):
          The name of the turn feature class to be created.
      maximum_edges {Long}:
          The maximum number of edges that turns in the new turn feature class
          can model. The default value is 5. The maximum value is 50.
      in_network_dataset {Network Dataset Layer}:
          The network dataset in which the turn feature class will participate.
          The resulting turn feature class will be added as a turn source to the
          network dataset. If no network dataset is specified, the turn feature
          class will be created as not participating in a network dataset.
      in_template_feature_class {Feature Layer}:
          The feature class used as a template to define the attribute schema of
          the new turn feature class.If the template feature class has the
          following fields, they are not
          created on the output turn feature class; NODE_, NODE#, JUNCTION,
          F_EDGE, T_EDGE, F-EDGE, T-EDGE, ARC1_, ARC2_, ARC1#, ARC2#, ARC1-ID,
          ARC2-ID, AZIMUTH, ANGLE.
      spatial_reference {Spatial Reference}:
          The spatial reference to be applied to the output turn feature class.
          This parameter is ignored if the output location is a geodatabase
          feature dataset as the output turn feature class will inherit the
          spatial reference of the feature dataset.If you want to import the
          spatial reference from an existing feature
          class, specify its path as the parameter value.
      config_keyword {String}:
          Specifies the configuration keyword that determines the storage
          parameters of the new turn feature class. This parameter is used only
          if the output location is an workgroup or enterprise geodatabase
      spatial_grid_1 {Double}:
          This parameter has been deprecated in ArcGIS Pro. Any value you enter
          is ignored.
      spatial_grid_2 {Double}:
          This parameter has been deprecated in ArcGIS Pro. Any value you enter
          is ignored.
      spatial_grid_3 {Double}:
          This parameter has been deprecated in ArcGIS Pro. Any value you enter
          is ignored.
      has_z {Boolean}:
          * ENABLED-The coordinates in the new turn feature class will have
          elevation (Z) values. This value should be used if the input network
          dataset is specified and it supports connectivity based on z
          coordinate values of the network sources.

          * DISABLED-The coordinates in the new turn feature class will not have
          elevation (Z) values."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateTurnFeatureClass_na(*gp_fixargs((out_location, out_feature_class_name, maximum_edges, in_network_dataset, in_template_feature_class, spatial_reference, config_keyword, spatial_grid_1, spatial_grid_2, spatial_grid_3, has_z), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('IncreaseMaximumEdges_na', None)
def IncreaseMaximumEdges(in_turn_features=None, maximum_edges=None):
    """IncreaseMaximumEdges_na(in_turn_features, maximum_edges)

        Increases the maximum number of edges per turn in a turn feature
        class.

     INPUTS:
      in_turn_features (Feature Layer):
          The turn feature class that is having its maximum number of edges
          raised.
      maximum_edges (Long):
          The new maximum number of edges in the input turn feature class. The
          value must be at least one higher than the existing maximum number of
          edges and cannot be greater than 50."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.IncreaseMaximumEdges_na(*gp_fixargs((in_turn_features, maximum_edges), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('PopulateAlternateIDFields_na', None)
def PopulateAlternateIDFields(in_network_dataset=None, alternate_ID_field_name=None):
    """PopulateAlternateIDFields_na(in_network_dataset, alternate_ID_field_name)

        Creates and populates additional fields on the turn feature classes
        that reference the edges by alternate IDs. The alternate IDs allow for
        another set of IDs that can help maintain the integrity of the turn
        features in case the source edges are being edited.

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset whose turn feature classes are to receive
          alternate ID fields. The fields will be created on all of the turn
          feature classes added as a turn source to the network dataset.
      alternate_ID_field_name (String):
          The name of the alternate ID field on the edge feature sources of the
          network dataset. All edge feature sources referenced by turns must
          have the same name for the alternate ID field."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PopulateAlternateIDFields_na(*gp_fixargs((in_network_dataset, alternate_ID_field_name), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('TurnTableToTurnFeatureClass_na', None)
def TurnTableToTurnFeatureClass(in_turn_table=None, reference_line_features=None, out_feature_class_name=None, reference_nodes_table=None, maximum_edges=None, config_keyword=None, spatial_grid_1=None, spatial_grid_2=None, spatial_grid_3=None):
    """TurnTableToTurnFeatureClass_na(in_turn_table, reference_line_features, out_feature_class_name, {reference_nodes_table}, {maximum_edges}, {config_keyword}, {spatial_grid_1}, {spatial_grid_2}, {spatial_grid_3})

        Converts an ArcView turn table or ArcInfo Workstation coverage turn
        table to an ArcGIS turn feature class.

     INPUTS:
      in_turn_table (Table View):
          The .dbf or INFO turn table from which the new turn feature class is
          being created.INFO tables do not support mixed case path names on
          Linux and Solaris.
      reference_line_features (Feature Class):
          The line feature class to which the input turn table refers. The
          feature class must be a source in a network dataset.
      out_feature_class_name (String):
          The name of the new turn feature class to create.
      reference_nodes_table {dBASE Table}:
          The nodes.dbf table in the .nws folder containing the original ArcView
          GIS network in which the input turn table participated.This parameter
          is ignored if the input turn table is an INFO table.If the input turn
          table is a .dbf table and this parameter is omitted,
          then U-turns and turns that traverse between edges connected to each
          other at both ends will not be created in the output turn feature
          class.Errors will be reported in an error file written to the
          directory
          defined by the TEMP system variable. The full path name to the error
          file is reported as a warning message.
      maximum_edges {Long}:
          The maximum number of edges per turn in the new turn feature class.
          The default value is 5. The maximum value is 50.
      config_keyword {String}:
          Specifies the configuration keyword that determines the storage
          parameters of the output turn feature class. This parameter is used
          only if the output turn feature class is created in a workgroup or
          enterprise geodatabase.
      spatial_grid_1 {Double}:
          This parameter has been deprecated in ArcGIS Pro. Any value you enter
          is ignored.
      spatial_grid_2 {Double}:
          This parameter has been deprecated in ArcGIS Pro. Any value you enter
          is ignored.
      spatial_grid_3 {Double}:
          This parameter has been deprecated in ArcGIS Pro. Any value you enter
          is ignored."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TurnTableToTurnFeatureClass_na(*gp_fixargs((in_turn_table, reference_line_features, out_feature_class_name, reference_nodes_table, maximum_edges, config_keyword, spatial_grid_1, spatial_grid_2, spatial_grid_3), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('UpdateByAlternateIDFields_na', None)
def UpdateByAlternateIDFields(in_network_dataset=None, alternate_ID_field_name=None):
    """UpdateByAlternateIDFields_na(in_network_dataset, alternate_ID_field_name)

        Updates all the edge references in turn feature classes using an
        alternate ID field. This tool should be used after making edits to the
        input line features that are referenced by the turn features to
        synchronize the turn features based on the alternate ID fields.

     INPUTS:
      in_network_dataset (Network Dataset Layer):
          The network dataset whose turn feature classes are being updated by
          their alternate ID fields.
      alternate_ID_field_name (String):
          The name of the alternate ID field on the edge feature sources of the
          network dataset. All edge feature sources referenced by turns must
          have the same name for the alternate ID field."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateByAlternateIDFields_na(*gp_fixargs((in_network_dataset, alternate_ID_field_name), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('UpdateByGeometry_na', None)
def UpdateByGeometry(in_turn_features=None):
    """UpdateByGeometry_na(in_turn_features)

        Updates all the edge references in the turn feature class using the
        geometry of the turn features. This tool is useful when the IDs listed
        for the turn can no longer find the edges participating in the turn
        due to edits to the underlying edges.

     INPUTS:
      in_turn_features (Feature Layer):
          The turn feature class to be updated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateByGeometry_na(*gp_fixargs((in_turn_features,), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject, gptoolnotsupported