# -*- coding: utf-8 -*-
#COPYRIGHT 2016 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Raster Analysis toolbox contains a set of powerful tools for
performing raster analysis on data in your portal. By distributing the
processing between multiple server nodes, you can efficiently process
large datasets in less time than ever before."""
__all__ = ['CalculateDensity', 'ConvertFeatureToRaster',
           'ConvertRasterToFeature', 'CreateViewshed', 'InterpolatePoints',
           'SummarizeRasterWithin']
__alias__ = 'ra'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs, gptoolnotsupported
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Analyze Patterns toolset
@gptoolnotsupported
@gptooldoc('CalculateDensity_ra', None)
def CalculateDensity(inputPointOrLineFeatures=None, outputName=None, countField=None, searchDistance=None, outputAreaUnits=None, outputCellSize=None):
    """CalculateDensity_ra(inputPointOrLineFeatures, outputName, {countField}, {searchDistance}, {outputAreaUnits}, {outputCellSize})

        Creates a density map from point or line features by spreading known
        quantities of some phenomenon (represented as attributes of the points
        or lines) across the map. The result is a layer of areas classified
        from least dense to most dense.

     INPUTS:
      inputPointOrLineFeatures (Feature Set):
          The input point or line features that will be used to calculate the
          density raster.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be asked to provide another
          name.
      countField {Field}:
          Provide a field indicating the number of incidents at each location.
          For example, if you are making a population density raster, and the
          input points are cities, it would be appropriate to use the population
          of the city for the count field so cities with larger populations have
          more impact on the density calculations.
      searchDistance {Linear Unit}:
          Choose the search distance and units for the distance. When
          calculating the density at a cell, all features within this distance
          will be used in the density calculation for that cell.
      outputAreaUnits {String}:
          Choose the area units. Density is count divided by area, and this
          parameter sets the units of the area in the density calculation.

          * SQUARE_MILES-Calculate the density per square mile.

          * SQUARE_KILOMETERS-Calculate the density per square kilometer.

          * SQUARE_METERS-Calculate the density per square meter.

          * SQUARE_FEET-Calculate the density per square foot.
      outputCellSize {Linear Unit}:
          Set the cell size and units for the output raster."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateDensity_ra(*gp_fixargs((inputPointOrLineFeatures, outputName, countField, searchDistance, outputAreaUnits, outputCellSize), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('InterpolatePoints_ra', None)
def InterpolatePoints(inputPointFeatures=None, interpolateField=None, outputName=None, optimizeFor=None, transformData=None, sizeOfLocalModels=None, numberOfNeighbors=None, outputCellSize=None, outputPredictionError=None):
    """InterpolatePoints_ra(inputPointFeatures, interpolateField, outputName, {optimizeFor}, {transformData}, {sizeOfLocalModels}, {numberOfNeighbors}, {outputCellSize}, {outputPredictionError})

        Predict values at new locations based on measurements from a
        collection of points. The tool takes point data with values at each
        point and returns a raster of predicted values.

     INPUTS:
      inputPointFeatures (Feature Set):
          The input point features you want to interpolate.
      interpolateField (Field):
          The field containing the data values you want to interpolate.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be asked to provide another
          name.
      optimizeFor {String}:
          Choose your preference for speed versus accuracy. More accurate
          predictions will take longer to calculate.

          * SPEED-The operation is optimized for speed.

          * BALANCE-A balance between speed and accuracy. This is the default.

          * ACCURACY-The operation is optimized for accuracy.
      transformData {Boolean}:
          Choose whether to transform your data to a normal distribution before
          performing analysis. If your data values do not appear to be normally
          distributed (bell-shaped), it is recommended to perform a
          transformation.

          * NO_TRANSFORM-No transformation is applied. This is the default.

          * TRANSFORM-A transformation to the normal distribution is applied.
      sizeOfLocalModels {Long}:
          Choose the number of points in each of the local models. A larger
          value will make the interpolation more global and stable, but small-
          scale effects may be missed. Smaller values will make the
          interpolation more local, so small-scale effects are more likely to be
          captured, but the interpolation may be unstable.
      numberOfNeighbors {Long}:
          The number of neighbors to use when calculating the prediction at a
          particular cell.
      outputCellSize {Linear Unit}:
          Set the cell size and units of the output raster. If a prediction
          error raster is created, it will also use this cell size.
      outputPredictionError {Boolean}:
          Choose whether to output a raster of standard errors of the
          interpolated predictions.Standard errors are useful because they
          provide information about the
          reliability of the predicted values. A simple rule of thumb is that
          the true value will fall within two standard errors of the predicted
          value 95 percent of the time. For example, suppose a new location gets
          a predicted value of 50 with a standard error of 5. This means that
          this task's best guess is that the true value at that location is 50,
          but it reasonably could be as low as 40 or as high as 60. To calculate
          this range of reasonable values, multiply the standard error by 2, add
          this value to the predicted value to get the upper end of the range,
          and subtract it from the predicted value to get the lower end of the
          range.If a raster of standard errors for the interpolated predictions
          is
          requested, it will have the same name as the Result layer name but
          with Errors appended.

          * OUTPUT_ERROR-Create a prediction error raster.

          * NO_OUTPUT_ERROR-Do not create a prediction error raster."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.InterpolatePoints_ra(*gp_fixargs((inputPointFeatures, interpolateField, outputName, optimizeFor, transformData, sizeOfLocalModels, numberOfNeighbors, outputCellSize, outputPredictionError), True)))
        return retval
    except Exception as e:
        raise e


# Analyze Terrain toolset
@gptoolnotsupported
@gptooldoc('CreateViewshed_ra', None)
def CreateViewshed(inputElevationSurface=None, inputObserverFeatures=None, outputName=None, optimizeFor=None, maximumViewingDistanceType=None, maximumViewingDistance=None, maximumViewingDistanceField=None, minimumViewingDistanceType=None, minimumViewingDistance=None, minimumViewingDistanceField=None, viewingDistanceIs3D=None, observersElevationType=None, observersElevation=None, observersElevationField=None, observersHeightType=None, observersHeight=None, observersHeightField=None, targetHeightType=None, targetHeight=None, targetHeightField=None, aboveGroundLevelOutputName=None):
    """CreateViewshed_ra(inputElevationSurface, inputObserverFeatures, outputName, {optimizeFor}, {maximumViewingDistanceType}, {maximumViewingDistance}, {maximumViewingDistanceField}, {minimumViewingDistanceType}, {minimumViewingDistance}, {minimumViewingDistanceField}, {viewingDistanceIs3D}, {observersElevationType}, {observersElevation}, {observersElevationField}, {observersHeightType}, {observersHeight}, {observersHeightField}, {targetHeightType}, {targetHeight}, {targetHeightField}, {aboveGroundLevelOutputName})

        Creates areas where an observer can see objects on the ground. The
        input observer points can represent either observers (such as people
        on the ground or lookouts in a fire tower) or observed objects (such
        as wind turbines, water towers, vehicles, or other people).Both the
        observers and the observed objects can have a height above
        ground, and these heights are used to determine visibility. For
        example, a viewshed computed for 300-foot wind turbines and a 6-foot
        tall person standing on the ground will typically be larger than a
        viewshed computed for 200-foot turbines and a 5-foot tall person.The
        result layer records the number of times that each cell location
        in the input surface raster can be seen by the input observation
        points. Nonvisible cells are given NoData values.

     INPUTS:
      inputElevationSurface (Image Service / Raster Layer / String):
          The elevation surface to use for calculating the viewshed.If the
          vertical unit of the input surface is different from the
          horizontal unit, such as when the elevation values are represented in
          feet but the coordinate system is in meters, the surface must have a
          defined vertical coordinate system. The reason for this is that the
          tool uses the vertical (Z) and horizontal (XY) units to compute a
          z-factor for the viewshed analysis. Without a vertical coordinate
          system, and thus having no Z unit information available, the tool will
          assume that the Z unit is the same as the XY unit. The result of this
          is that an internal Z factor of 1.0 will be used for the analysis,
          which may give unexpected results.The elevation surface can be integer
          or floating point.
      inputObserverFeatures (Feature Set):
          The point features that represent the observer locations when
          calculating the viewsheds.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be asked to provide another
          name.
      optimizeFor {String}:
          The optimization method to use for calculating the viewshed.

          * SPEED-This method optimizes the processing speed, trading some
          accuracy in the result for higher performance. This is the default.

          * ACCURACY-This method is optimized for accuracy in the results, at
          the expense of a longer processing time.
      maximumViewingDistanceType {String}:
          The method by which the maximum viewing distance will be determined.

          * DISTANCE-The maximum distance is defined by a value you specify.
          This is the default method.

          * FIELD-The maximum distance for each observer location is determined
          by the values in a field you specify.
      maximumViewingDistance {Linear Unit}:
          This is a cutoff distance, where the computation of visible areas
          stops. Beyond this distance, it is unknown whether the observer points
          and the other objects can see each other.
      maximumViewingDistanceField {Field}:
          This is a field you can use to specify the maximum viewing distance
          for each observer. The values contained in the field must be in the
          same unit as the XY unit of the input elevation surface.The maximum
          viewing distance is a cutoff distance where the
          computation of visible areas stops. Beyond this distance, it is
          unknown whether the observer points and the other objects can see each
          other.
      minimumViewingDistanceType {String}:
          Choose the method by which the minimum visible distance will be
          determined.

          * DISTANCE-The minimum distance is defined by a value you specify.
          This is the default method.

          * FIELD-The minimum distance for each observer location is determined
          by the values in a field you specify.
      minimumViewingDistance {Linear Unit}:
          This is a distance where the computation of visible areas begins.
          Cells on the surface closer than this distance are not visible in the
          output but can still block visibility of the cells between the minimum
          and maximum viewing distance.
      minimumViewingDistanceField {Field}:
          This is a field you can use to specify the minimum viewing distance
          for each observer. The values contained in the field must be in the
          same unit as the XY unit of the input elevation surface.The minimum
          viewing distance defines where the computation of visible
          areas begins. Cells on the surface closer than this distance are not
          visible in the output but can still block visibility of the cells
          between the minimum and maximum viewing distance.
      viewingDistanceIs3D {Boolean}:
          Specify whether the minimum and maximum viewing distance parameters
          are measured in a three-dimensional way or a simpler, two-dimensional
          way. A 2D distance is the simple linear distance measured between an
          observer and the target using their projected locations at sea level.
          A 3D distance gives a more realistic value by taking their relative
          heights into consideration.

          * 2D-The viewing distance is measured in 2D distance. This is the
          default.

          * 3D-The viewing distance is measured in 3D distance.
      observersElevationType {String}:
          The method by which the elevation of the observers will be determined.

          * ELEVATION-The observer elevation is defined by a value you specify.
          This is the default method.

          * FIELD-The elevation for each observer location is determined by the
          values in a field you specify.
      observersElevation {Linear Unit}:
          This is the elevation of your observer locations.If this parameter is
          not specified, the observer elevation will be
          obtained from the surface raster using bilinear interpolation. If this
          parameter is set to a value, that value will be applied to all the
          observers. To specify different values for each observer, set this
          parameter to a field in the input observer features.
      observersElevationField {Field}:
          This is a field you can use to specify the elevation for the
          observers. The value contained in the field must be in the same unit
          as the Z unit of the input elevation surface.If this parameter is not
          specified, the observer elevation will be
          obtained from the surface raster using bilinear interpolation.
      observersHeightType {String}:
          The method by which the height of the observers will be determined.

          * HEIGHT-The observer height is obtained from the value you specify.
          This is the default method.

          * FIELD-The height for each observer location is determined by the
          values in a field you specify.
      observersHeight {Linear Unit}:
          This is the height used for your observer locations.
      observersHeightField {Field}:
          This is a field you can use to specify the height for the observers.
          The value contained in the field must be in the same unit as the Z
          unit of the input elevation surface.
      targetHeightType {String}:
          The method by which the height of the targets will be determined.

          * HEIGHT-The target height is obtained from the value you specify.
          This is the default method.

          * FIELD-The height for each target is determined by the values in a
          field you specify.
      targetHeight {Linear Unit}:
          This is the height of structures or people on the ground used to
          establish visibility. The result viewshed are those areas where an
          observer point can see these other objects. The converse is also true;
          the other objects can see an observer point.
      targetHeightField {Field}:
          This is a field used to specify the height for the targets. The value
          contained in the field must be in the same unit as the Z unit of the
          input elevation surface.
      aboveGroundLevelOutputName {String}:
          The name of the output aboveground-level (AGL) raster. The AGL result
          is a raster where each cell value is the minimum height that must be
          added to an otherwise nonvisible cell to make it visible by at least
          one observer. Cells that were already visible will be assigned 0 in
          this output raster."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateViewshed_ra(*gp_fixargs((inputElevationSurface, inputObserverFeatures, outputName, optimizeFor, maximumViewingDistanceType, maximumViewingDistance, maximumViewingDistanceField, minimumViewingDistanceType, minimumViewingDistance, minimumViewingDistanceField, viewingDistanceIs3D, observersElevationType, observersElevation, observersElevationField, observersHeightType, observersHeight, observersHeightField, targetHeightType, targetHeight, targetHeightField, aboveGroundLevelOutputName), True)))
        return retval
    except Exception as e:
        raise e


# Manage Data toolset
@gptoolnotsupported
@gptooldoc('ConvertFeatureToRaster_ra', None)
def ConvertFeatureToRaster(inputFeatures=None, valueField=None, outputName=None, outputCellSize=None):
    """ConvertFeatureToRaster_ra(inputFeatures, valueField, outputName, {outputCellSize})

        Converts features to a raster dataset.

     INPUTS:
      inputFeatures (Feature Set):
          The input feature layer.
      valueField (Field):
          Choose the field that will be used to assign values to the output
          raster.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be asked to provide another
          name.
      outputCellSize {Linear Unit}:
          Enter the cell size and unit for the output rasters.The available
          units are Feet, Miles, Meters, and Kilometers."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConvertFeatureToRaster_ra(*gp_fixargs((inputFeatures, valueField, outputName, outputCellSize), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('ConvertRasterToFeature_ra', None)
def ConvertRasterToFeature(inputRaster=None, field=None, outputType=None, simplifyLinesOrPolygons=None, outputName=None):
    """ConvertRasterToFeature_ra(inputRaster, {field}, {outputType}, {simplifyLinesOrPolygons}, outputName)

        Converts a raster to a feature dataset, as points, lines, or polygons.

     INPUTS:
      inputRaster (Image Service / Raster Layer / String):
          The input raster layer.
      field {String}:
          Provide a field that specifies which value will be used for the
          conversion.It can be any integer or text value.A field containing
          floating-point values can only be used if the
          output is to a point dataset.The default choice is to use the Value
          field, which contains the value
          in each raster cell.
      outputType {String}:
          Choose the output type between point, line, or polygon.

          * POINT-The raster will be converted to a point dataset.

          * LINE-The raster will be converted to a line feature dataset.

          * POLYGON-The raster will be converted to a polygon feature dataset.
      simplifyLinesOrPolygons {Boolean}:
          Set if lines should be simplified.

          * SIMPLIFY-The line or polygon features will be smoothed out to
          produce a more generalized result. This is the default.

          * NO_SIMPLIFY-The line or polygon features will follow the cell
          boundaries of the raster dataset.
      outputName (String):
          The output feature class that will contain the converted line or
          polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConvertRasterToFeature_ra(*gp_fixargs((inputRaster, field, outputType, simplifyLinesOrPolygons, outputName), True)))
        return retval
    except Exception as e:
        raise e


# Summarize Data toolset
@gptoolnotsupported
@gptooldoc('SummarizeRasterWithin_ra', None)
def SummarizeRasterWithin(inputZoneLayer=None, zoneField=None, inputRasterLayertoSummarize=None, outputName=None, statisticType=None, ignoreMissingValues=None):
    """SummarizeRasterWithin_ra(inputZoneLayer, zoneField, inputRasterLayertoSummarize, outputName, {statisticType}, {ignoreMissingValues})

        Summarizes a raster based on areas (zones) defined by the first input
        layer.

     INPUTS:
      inputZoneLayer (Image Service / Feature Layer / Raster Layer / String):
          The layer that defines the boundaries of the areas. Both raster and
          feature services can be used for the zone input.You specify a field to
          define the boundaries of the zones.
      zoneField (String):
          The field that defines each zone.It can be an integer or a string
          field of the zone dataset.
      inputRasterLayertoSummarize (Image Service / Raster Layer / String):
          Choose the raster layer you wish to summarize.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be asked to provide another
          name.
      statisticType {String}:
          Choose the statistic to calculate.The available options when the
          summarize raster is integer are
          Average, Maximum, Median, Minimum, Minority, Range, Standard
          deviation, Sum, and Variety.If the summarize raster is float, the
          options are Average, Maximum,
          Minimum, Range, Standard deviation, and Sum.

          * MEAN-Calculates the average of all cells in the raster layer to be
          summarized that belong to the same zone as the output cell. This is
          the default.

          * MAJORITY-Determines the value that occurs most often of all cells
          in the raster layer to be summarized that belong to the same zone as
          the output cell.

          * MAXIMUM-Determines the largest value of all cells in the raster
          layer to be summarized that belong to the same zone as the output
          cell.

          * MEDIAN-Determines the median value of all cells in the raster layer
          to be summarized that belong to the same zone as the output cell.

          * MINIMUM-Determines the smallest value of all cells in the raster
          layer to be summarized that belong to the same zone as the output
          cell.

          * MINORITY-Determines the value that occurs least often of all cells
          in the raster layer to be summarized that belong to the same zone as
          the output cell.

          * RANGE-Calculates the difference between the largest and smallest
          value of all cells in the raster layer to be summarized that belong to
          the same zone as the output cell.

          * STD-Calculates the standard deviation of all cells in the raster
          layer to be summarized that belong to the same zone as the output
          cell.

          * SUM-Calculates the total value of all cells in the raster layer to
          be summarized that belong to the same zone as the output cell.

          * VARIETY-Calculates the number of unique values for all cells in the
          raster layer to be summarized that belong to the same zone as the
          output cell.
      ignoreMissingValues {Boolean}:
          Specify whether missing values in the raster layer to summarize will
          influence the results of the areas they fall within.

          * DATA-Within any particular area, only cells that have a value in the
          raster layer being summarized will be used in determining the output
          value for that area. Any missing or NoData cells will be ignored in
          the statistic calculation. This is the default.

          * NODATA-Within any particular area, if any cells in the raster layer
          being summarized do not have a value, it is deemed that there is
          insufficient information to perform statistical calculations for all
          the cells in that zone; therefore, the entire zone will receive the
          NoData value on the output raster."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SummarizeRasterWithin_ra(*gp_fixargs((inputZoneLayer, zoneField, inputRasterLayertoSummarize, outputName, statisticType, ignoreMissingValues), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject, gptoolnotsupported